@@ -89,12 +89,12 @@ const GimpStringActionEntry dialogs_dockable_actions[] =
     "gimp-channel-list",
     GIMP_HELP_CHANNEL_DIALOG },
 
-  { "dialogs-vectors", GIMP_ICON_DIALOG_PATHS,
+  { "dialogs-paths", GIMP_ICON_DIALOG_PATHS,
     NC_("dialogs-action", "_Paths Dialog"),
     NC_("dialogs-action", "_Paths"),
     { NULL },
     NC_("dialogs-action", "Open the paths dialog"),
-    "gimp-vectors-list",
+    "gimp-path-list",
     GIMP_HELP_PATH_DIALOG },
 
   { "dialogs-indexed-palette", GIMP_ICON_COLORMAP,
@@ -307,8 +307,13 @@ gint n_dialogs_dockable_actions = G_N_ELEMENTS (dialogs_dockable_actions);
 static const GimpStringActionEntry dialogs_toplevel_actions[] =
 {
   { "dialogs-preferences", GIMP_ICON_PREFERENCES_SYSTEM,
+#if defined(PLATFORM_OSX)
+    NC_("dialogs-action", "_Settings..."),
+    NC_("dialogs-action", "_Settings..."),
+#else
     NC_("dialogs-action", "_Preferences"),
     NC_("dialogs-action", "_Preferences"),
+#endif
     { NULL },
     NC_("dialogs-action", "Open the preferences dialog"),
     "gimp-preferences-dialog",
@@ -372,12 +377,14 @@ static const GimpStringActionEntry dialogs_toplevel_actions[] =
     "gimp-action-search-dialog",
     GIMP_HELP_ACTION_SEARCH_DIALOG },
 
+#ifndef GIMP_RELEASE
   { "dialogs-extensions", GIMP_ICON_PLUGIN,
     NC_("dialogs-action", "Manage _Extensions"), NULL,
     { NULL },
     NC_("dialogs-action", "Manage Extensions: search, install, uninstall, update."),
     "gimp-extensions-dialog",
     GIMP_HELP_EXTENSIONS_DIALOG }
+#endif
 };
 
 
