@@ -30,8 +30,11 @@
 #include "core/gimp-filter-history.h"
 #include "core/gimpimage.h"
 #include "core/gimpgrouplayer.h"
+#include "core/gimplinklayer.h"
 #include "core/gimplayermask.h"
 
+#include "path/gimpvectorlayer.h"
+
 #include "pdb/gimpprocedure.h"
 
 #include "widgets/gimpaction.h"
@@ -751,10 +754,10 @@ static const GimpEnumActionEntry filters_repeat_actions[] =
 void
 filters_actions_setup (GimpActionGroup *group)
 {
-  static gboolean           first_setup = TRUE;
   GimpProcedureActionEntry *entries;
   gint                      n_entries;
   gint                      i;
+  GList                    *actions;
   GList                    *op_classes;
   GList                    *iter;
   GStrvBuilder             *gegl_actions;
@@ -780,23 +783,8 @@ filters_actions_setup (GimpActionGroup *group)
   filters_actions_set_tooltips (group, filters_interactive_actions,
                                 G_N_ELEMENTS (filters_interactive_actions));
 
-  /* XXX Hardcoded list to prevent expensive node/graph creation of a
-   * well-known list of operations.
-   * This whole code will disappear when we'll support filters with aux
-   * input non-destructively anyway.
-   */
-  if (first_setup)
-    {
-      actions_filter_set_aux ("filters-variable-blur");
-      actions_filter_set_aux ("filters-oilify");
-      actions_filter_set_aux ("filters-lens-blur");
-      actions_filter_set_aux ("filters-gaussian-blur-selective");
-      actions_filter_set_aux ("filters-displace");
-      actions_filter_set_aux ("filters-bump-map");
-    }
-
   gegl_actions = g_strv_builder_new ();
-  op_classes   = gimp_gegl_get_op_classes ();
+  op_classes   = gimp_gegl_get_op_classes (TRUE);
 
   for (iter = op_classes; iter; iter = iter->next)
     {
@@ -808,6 +796,9 @@ filters_actions_setup (GimpActionGroup *group)
       const gchar           *op_name;
       gchar                 *label;
 
+      if (filters_actions_gegl_op_blocklisted (op_class->name))
+        continue;
+
       formatted_op_name = g_strdup (op_class->name);
       gimp_make_valid_action_name (formatted_op_name);
       action_name = g_strdup_printf ("filters-%s", formatted_op_name);
@@ -877,23 +868,6 @@ filters_actions_setup (GimpActionGroup *group)
           g_free (short_label);
         }
 
-      /* Identify third-party filters based on operations with an
-       * auxiliary pad in first setup because of slowness on Windows.
-       * See #14781.
-       */
-      if (first_setup)
-        {
-          GeglNode *node = gegl_node_new ();
-
-          gegl_node_set (node,
-                         "operation", op_class->name,
-                         NULL);
-
-          if (gegl_node_has_pad (node, "aux"))
-            actions_filter_set_aux (action_name);
-
-          g_clear_object (&node);
-        }
       g_strv_builder_add (gegl_actions, action_name);
 
       g_free (label);
@@ -908,6 +882,40 @@ filters_actions_setup (GimpActionGroup *group)
   g_strv_builder_unref (gegl_actions);
   g_list_free (op_classes);
 
+  /* Identify all filters based on operations with an auxiliary pad in
+   * setup because of slowness on Windows. See #14781.
+   */
+  actions = gimp_action_group_list_actions (group);
+  for (iter = actions; iter; iter = iter->next)
+    {
+      GimpAction  *action = iter->data;
+      const gchar *action_name;
+
+      action_name = gimp_action_get_name (action);
+
+      if (! filters_is_non_interactive (action_name) && GIMP_IS_STRING_ACTION (action))
+        {
+          const gchar *opname;
+
+          opname = GIMP_STRING_ACTION (action)->value;
+
+          if (opname != NULL && g_strcmp0 (opname, "gegl:gegl") != 0 && gegl_has_operation (opname))
+            {
+              GeglNode *node = gegl_node_new ();
+
+              gegl_node_set (node,
+                             "operation", opname,
+                             NULL);
+
+              if (gegl_node_has_pad (node, "aux"))
+                g_object_set_data (G_OBJECT (action), "filters-action-has-pad", GINT_TO_POINTER (TRUE));
+
+              g_clear_object (&node);
+            }
+        }
+    }
+  g_list_free (actions);
+
   gimp_action_group_add_enum_actions (group, "filters-action",
                                       filters_repeat_actions,
                                       G_N_ELEMENTS (filters_repeat_actions),
@@ -943,8 +951,6 @@ filters_actions_setup (GimpActionGroup *group)
                            group, 0);
 
   filters_actions_history_changed (group->gimp, group);
-
-  first_setup = FALSE;
 }
 
 void
@@ -988,7 +994,9 @@ filters_actions_update (GimpActionGroup *group,
           if (gimp_viewable_get_children (GIMP_VIEWABLE (drawable)))
             is_group = TRUE;
 
-          if (GIMP_IS_GROUP_LAYER (drawable))
+          if (GIMP_IS_GROUP_LAYER (drawable)                   ||
+              gimp_item_is_vector_layer (GIMP_ITEM (drawable)) ||
+              gimp_item_is_link_layer (GIMP_ITEM (drawable)))
             force_nde = TRUE;
         }
 
@@ -1046,7 +1054,7 @@ filters_actions_update (GimpActionGroup *group,
                  * types of layers where filters can only be applied
                  * non-destructively.
                  */
-                sensitive = ! actions_filter_get_aux (action_name);
+                sensitive = ! GPOINTER_TO_INT (g_object_get_data (G_OBJECT (action), "filters-action-has-pad"));
 
               SET_SENSITIVE (gimp_action_get_name (action), sensitive);
             }
@@ -1112,6 +1120,36 @@ filters_actions_update (GimpActionGroup *group,
   }
 }
 
+gboolean
+filters_actions_gegl_op_blocklisted (const gchar *operation_name)
+{
+  for (gint i = 0; i < G_N_ELEMENTS (filters_actions); i++)
+    {
+      const GimpStringActionEntry *action_entry = &filters_actions[i];
+
+      if (g_strcmp0 (operation_name, action_entry->value) == 0)
+        return TRUE;
+    }
+
+  for (gint i = 0; i < G_N_ELEMENTS (filters_settings_actions); i++)
+    {
+      const GimpStringActionEntry *action_entry = &filters_settings_actions[i];
+
+      if (g_strcmp0 (operation_name, action_entry->value) == 0)
+        return TRUE;
+    }
+
+  for (gint i = 0; i < G_N_ELEMENTS (filters_interactive_actions); i++)
+    {
+      const GimpStringActionEntry *action_entry = &filters_interactive_actions[i];
+
+      if (g_strcmp0 (operation_name, action_entry->value) == 0)
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
 static void
 filters_actions_set_tooltips (GimpActionGroup             *group,
                               const GimpStringActionEntry *entries,
