@@ -30,9 +30,12 @@
 #include "core/gimpimage.h"
 #include "core/gimplayer.h"
 #include "core/gimplayer-floating-selection.h"
+#include "core/gimplinklayer.h"
 
 #include "text/gimptextlayer.h"
 
+#include "path/gimpvectorlayer.h"
+
 #include "widgets/gimphelp-ids.h"
 #include "widgets/gimpactiongroup.h"
 #include "widgets/gimpwidgets-utils.h"
@@ -60,6 +63,12 @@ static const GimpActionEntry layers_actions[] =
     layers_edit_text_cmd_callback,
     GIMP_HELP_LAYER_EDIT },
 
+  { "layers-edit-vector", GIMP_ICON_TOOL_PATH,
+    NC_("layers-action", "Path Tool"), NULL, { NULL },
+    NC_("layers-action", "Activate the path tool on this vector layer's path"),
+    layers_edit_vector_cmd_callback,
+    GIMP_HELP_TOOL_PATH },
+
   { "layers-edit-attributes", GIMP_ICON_EDIT,
     NC_("layers-action", "_Edit Layer Attributes..."), NULL, { NULL },
     NC_("layers-action", "Edit the layer's name"),
@@ -173,24 +182,48 @@ static const GimpActionEntry layers_actions[] =
     image_flatten_image_cmd_callback,
     GIMP_HELP_IMAGE_FLATTEN },
 
+  { "layers-link-discard", GIMP_ICON_TOOL_TEXT,
+    NC_("layers-action", "_Discard Link Information"), NULL, { NULL },
+    NC_("layers-action", "Turn this link layer into a normal layer"),
+    layers_link_discard_cmd_callback,
+    GIMP_HELP_LAYER_TEXT_DISCARD },
+
+  { "layers-link-monitor", GIMP_ICON_TOOL_TEXT,
+    NC_("layers-action", "_Monitor Linked Image"), NULL, { NULL },
+    NC_("layers-action", "Discard any transformation and monitor the linked file again"),
+    layers_link_monitor_cmd_callback,
+    GIMP_HELP_LAYER_TEXT_DISCARD },
+
   { "layers-text-discard", GIMP_ICON_TOOL_TEXT,
     NC_("layers-action", "_Discard Text Information"), NULL, { NULL },
     NC_("layers-action", "Turn these text layers into normal layers"),
     layers_text_discard_cmd_callback,
     GIMP_HELP_LAYER_TEXT_DISCARD },
 
-  { "layers-text-to-vectors", GIMP_ICON_TOOL_TEXT,
+  { "layers-text-to-path", GIMP_ICON_TOOL_TEXT,
     NC_("layers-action", "Text to _Path"), NULL, { NULL },
     NC_("layers-action", "Create paths from text layers"),
-    layers_text_to_vectors_cmd_callback,
+    layers_text_to_path_cmd_callback,
     GIMP_HELP_LAYER_TEXT_TO_PATH },
 
-  { "layers-text-along-vectors", GIMP_ICON_TOOL_TEXT,
+  { "layers-text-along-path", GIMP_ICON_TOOL_TEXT,
     NC_("layers-action", "Text alon_g Path"), NULL, { NULL },
     NC_("layers-action", "Warp this layer's text along the current path"),
-    layers_text_along_vectors_cmd_callback,
+    layers_text_along_path_cmd_callback,
     GIMP_HELP_LAYER_TEXT_ALONG_PATH },
 
+  { "layers-vector-fill-stroke", NULL,
+    NC_("layers-action", "Fill / Stroke..."), NULL, { NULL },
+    NC_("layers-action", "Edit the fill and stroke of this vector layer"),
+    layers_vector_fill_stroke_cmd_callback,
+    GIMP_HELP_LAYER_VECTOR_FILL_STROKE },
+
+  { "layers-vector-discard", NULL,
+    NC_("layers-action", "Discard Vector Information"), NULL, { NULL },
+    NC_("layers-action", "Turn this vector layer into a normal layer"),
+    layers_vector_discard_cmd_callback,
+    GIMP_HELP_LAYER_VECTOR_DISCARD },
+
   { "layers-resize", GIMP_ICON_OBJECT_RESIZE,
     NC_("layers-action", "Layer B_oundary Size..."), NULL, { NULL },
     NC_("layers-action", "Adjust the layer dimensions"),
@@ -757,6 +790,8 @@ layers_actions_update (GimpActionGroup *group,
   gboolean       lock_alpha     = TRUE;
   gboolean       can_lock_alpha = FALSE;
   gboolean       text_layer     = FALSE;
+  gboolean       vector_layer   = FALSE;
+  gboolean       link_layer     = FALSE;
   gboolean       bs_mutable     = FALSE; /* At least 1 selected layers' blend space is mutable.     */
   gboolean       cs_mutable     = FALSE; /* At least 1 selected layers' composite space is mutable. */
   gboolean       cm_mutable     = FALSE; /* At least 1 selected layers' composite mode is mutable.  */
@@ -977,7 +1012,10 @@ layers_actions_update (GimpActionGroup *group,
 
           gimp_action_group_set_action_active (group, action, TRUE);
 
-          text_layer = gimp_item_is_text_layer (GIMP_ITEM (layer));
+          text_layer   = gimp_item_is_text_layer (GIMP_ITEM (layer));
+          vector_layer = gimp_item_is_vector_layer (GIMP_ITEM (layer));
+          if (GIMP_IS_LINK_LAYER (layer))
+            link_layer = gimp_link_layer_is_monitored (GIMP_LINK_LAYER (layer));
         }
     }
 
@@ -993,6 +1031,7 @@ layers_actions_update (GimpActionGroup *group,
   SET_SENSITIVE ("layers-edit",             !ac && ((layer && !fs) || text_layer));
   SET_VISIBLE   ("layers-edit-text",        text_layer && !ac);
   SET_SENSITIVE ("layers-edit-text",        text_layer && !ac);
+  SET_VISIBLE   ("layers-edit-vector",      vector_layer && !ac);
   SET_SENSITIVE ("layers-edit-attributes",  layer && !fs && !ac);
 
   if (layer && gimp_layer_is_floating_sel (layer))
@@ -1038,9 +1077,15 @@ layers_actions_update (GimpActionGroup *group,
   SET_SENSITIVE ("layers-merge-layers",      n_selected_layers > 0 && !fs && !ac);
   SET_SENSITIVE ("layers-flatten-image",     !fs && !ac);
 
-  SET_VISIBLE   ("layers-text-discard",       n_text_layers > 0 && !ac);
-  SET_VISIBLE   ("layers-text-to-vectors",    n_text_layers > 0 && !ac);
-  SET_VISIBLE   ("layers-text-along-vectors", text_layer && !ac);
+  SET_VISIBLE   ("layers-text-discard",      n_text_layers > 0 && !ac);
+  SET_VISIBLE   ("layers-text-to-path",      n_text_layers > 0 && !ac);
+  SET_VISIBLE   ("layers-text-along-path",   text_layer && !ac);
+
+  SET_VISIBLE   ("layers-vector-fill-stroke", vector_layer && !ac);
+  SET_VISIBLE   ("layers-vector-discard",     vector_layer && !ac);
+
+  SET_VISIBLE   ("layers-link-discard",      link_layer && !ac);
+  SET_VISIBLE   ("layers-link-monitor",      GIMP_IS_LINK_LAYER (layer) && ! link_layer && !ac);
 
   SET_SENSITIVE ("layers-resize",          n_selected_layers == 1 && all_writable && all_movable && !ac);
   SET_SENSITIVE ("layers-resize-to-image", all_writable && all_movable && !ac);
