@@ -15,13 +15,9 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __LAYERS_ACTIONS_H__
-#define __LAYERS_ACTIONS_H__
+#pragma once
 
 
 void   layers_actions_setup  (GimpActionGroup *group);
 void   layers_actions_update (GimpActionGroup *group,
                               gpointer         data);
-
-
-#endif /* __LAYERS_ACTIONS_H__ */
