@@ -48,6 +48,8 @@
 #include "core/gimplayerpropundo.h"
 #include "core/gimplayer-floating-selection.h"
 #include "core/gimplayer-new.h"
+#include "core/gimplink.h"
+#include "core/gimplinklayer.h"
 #include "core/gimplist.h"
 #include "core/gimppickable.h"
 #include "core/gimppickable-auto-shrink.h"
@@ -55,23 +57,27 @@
 #include "core/gimpundostack.h"
 #include "core/gimpprogress.h"
 
+#include "path/gimppath.h"
+#include "path/gimppath-warp.h"
+#include "path/gimpstroke.h"
+#include "path/gimpvectorlayer.h"
+#include "path/gimpvectorlayeroptions.h"
+
 #include "text/gimptext.h"
 #include "text/gimptext-path.h"
 #include "text/gimptextlayer.h"
 
-#include "vectors/gimppath.h"
-#include "vectors/gimppath-warp.h"
-#include "vectors/gimpstroke.h"
-
 #include "widgets/gimpaction.h"
 #include "widgets/gimpdock.h"
 #include "widgets/gimphelp-ids.h"
+#include "widgets/gimpopendialog.h"
 #include "widgets/gimpprogressdialog.h"
 
 #include "display/gimpdisplay.h"
 #include "display/gimpdisplayshell.h"
 #include "display/gimpimagewindow.h"
 
+#include "tools/gimppathtool.h"
 #include "tools/gimptexttool.h"
 #include "tools/tool_manager.h"
 
@@ -80,6 +86,7 @@
 #include "dialogs/layer-options-dialog.h"
 #include "dialogs/resize-dialog.h"
 #include "dialogs/scale-dialog.h"
+#include "dialogs/vector-layer-options-dialog.h"
 
 #include "actions.h"
 #include "items-commands.h"
@@ -101,6 +108,7 @@ static void   layers_new_callback             (GtkWidget             *dialog,
                                                GimpLayerCompositeMode layer_composite_mode,
                                                gdouble                layer_opacity,
                                                GimpFillType           layer_fill_type,
+                                               GimpLink              *link,
                                                gint                   layer_width,
                                                gint                   layer_height,
                                                gint                   layer_offset_x,
@@ -124,6 +132,7 @@ static void   layers_edit_attributes_callback (GtkWidget             *dialog,
                                                GimpLayerCompositeMode layer_composite_mode,
                                                gdouble                layer_opacity,
                                                GimpFillType           layer_fill_type,
+                                               GimpLink              *link,
                                                gint                   layer_width,
                                                gint                   layer_height,
                                                gint                   layer_offset_x,
@@ -200,6 +209,10 @@ layers_edit_cmd_callback (GimpAction *action,
     {
       layers_edit_text_cmd_callback (action, value, data);
     }
+  else if (gimp_item_is_vector_layer (GIMP_ITEM (layers->data)))
+    {
+      layers_vector_fill_stroke_cmd_callback (action, value, data);
+    }
   else
     {
       layers_edit_attributes_cmd_callback (action, value, data);
@@ -251,6 +264,52 @@ layers_edit_text_cmd_callback (GimpAction *action,
     }
 }
 
+void
+layers_edit_vector_cmd_callback (GimpAction *action,
+                                 GVariant   *value,
+                                 gpointer    data)
+{
+  GimpImage *image;
+  GimpLayer *layer;
+  GList     *layers;
+  GtkWidget *widget;
+  GimpTool  *active_tool;
+  return_if_no_layers (image, layers, data);
+  return_if_no_widget (widget, data);
+
+  if (g_list_length (layers) != 1)
+    return;
+
+  layer = layers->data;
+
+  if (! gimp_item_is_vector_layer (GIMP_ITEM (layer)))
+    {
+      layers_edit_attributes_cmd_callback (action, value, data);
+      return;
+    }
+
+  active_tool = tool_manager_get_active (image->gimp);
+
+  if (! GIMP_IS_PATH_TOOL (active_tool))
+    {
+      GimpToolInfo *tool_info;
+
+      tool_info = (GimpToolInfo *)
+        gimp_container_get_child_by_name (image->gimp->tool_info_list,
+                                          "gimp-path-tool");
+
+      if (GIMP_IS_TOOL_INFO (tool_info))
+        {
+          gimp_context_set_tool (action_data_get_context (data), tool_info);
+          active_tool = tool_manager_get_active (image->gimp);
+        }
+    }
+
+  if (GIMP_IS_PATH_TOOL (active_tool))
+    gimp_path_tool_set_path (GIMP_PATH_TOOL (active_tool),
+                             GIMP_VECTOR_LAYER (layer)->options->path);
+}
+
 void
 layers_edit_attributes_cmd_callback (GimpAction *action,
                                      GVariant   *value,
@@ -1045,6 +1104,42 @@ layers_delete_cmd_callback (GimpAction *action,
   gimp_image_flush (image);
 }
 
+void
+layers_link_discard_cmd_callback (GimpAction *action,
+                                  GVariant   *value,
+                                  gpointer    data)
+{
+  GimpImage *image;
+  GList     *layers;
+  GList     *iter;
+  return_if_no_layers (image, layers, data);
+
+  gimp_image_undo_group_start (image, GIMP_UNDO_GROUP_ITEM_PROPERTIES,
+                               _("Discard Links"));
+  for (iter = layers; iter; iter = iter->next)
+    if (GIMP_IS_LINK_LAYER (iter->data))
+      gimp_link_layer_discard (GIMP_LINK_LAYER (iter->data));
+  gimp_image_undo_group_end (image);
+}
+
+void
+layers_link_monitor_cmd_callback (GimpAction *action,
+                                  GVariant   *value,
+                                  gpointer    data)
+{
+  GimpImage *image;
+  GList     *layers;
+  GList     *iter;
+  return_if_no_layers (image, layers, data);
+
+  gimp_image_undo_group_start (image, GIMP_UNDO_GROUP_ITEM_PROPERTIES,
+                               _("Monitor Links"));
+  for (iter = layers; iter; iter = iter->next)
+    if (GIMP_IS_LINK_LAYER (iter->data))
+      gimp_link_layer_monitor (GIMP_LINK_LAYER (iter->data));
+  gimp_image_undo_group_end (image);
+}
+
 void
 layers_text_discard_cmd_callback (GimpAction *action,
                                   GVariant   *value,
@@ -1064,9 +1159,9 @@ layers_text_discard_cmd_callback (GimpAction *action,
 }
 
 void
-layers_text_to_vectors_cmd_callback (GimpAction *action,
-                                     GVariant   *value,
-                                     gpointer    data)
+layers_text_to_path_cmd_callback (GimpAction *action,
+                                  GVariant   *value,
+                                  gpointer    data)
 {
   GimpImage *image;
   GList     *layers;
@@ -1105,9 +1200,9 @@ layers_text_to_vectors_cmd_callback (GimpAction *action,
 }
 
 void
-layers_text_along_vectors_cmd_callback (GimpAction *action,
-                                        GVariant   *value,
-                                        gpointer    data)
+layers_text_along_path_cmd_callback (GimpAction *action,
+                                     GVariant   *value,
+                                     gpointer    data)
 {
   GimpImage   *image;
   GList       *layers;
@@ -2263,6 +2358,7 @@ layers_new_callback (GtkWidget              *dialog,
                      GimpLayerCompositeMode  layer_composite_mode,
                      gdouble                 layer_opacity,
                      GimpFillType            layer_fill_type,
+                     GimpLink               *link,
                      gint                    layer_width,
                      gint                    layer_height,
                      gint                    layer_offset_x,
@@ -2283,6 +2379,8 @@ layers_new_callback (GtkWidget              *dialog,
   gint              n_layers   = g_list_length (layers);
   gboolean          run_once   = (n_layers == 0);
 
+  g_return_if_fail (link == NULL);
+
   g_object_set (config,
                 "layer-new-name",            layer_name,
                 "layer-new-mode",            layer_mode,
@@ -2379,6 +2477,7 @@ layers_edit_attributes_callback (GtkWidget              *dialog,
                                  GimpLayerCompositeMode  layer_composite_mode,
                                  gdouble                 layer_opacity,
                                  GimpFillType            unused1,
+                                 GimpLink               *link,
                                  gint                    unused2,
                                  gint                    unused3,
                                  gint                    layer_offset_x,
@@ -2407,7 +2506,8 @@ layers_edit_attributes_callback (GtkWidget              *dialog,
       layer_lock_pixels     != gimp_item_get_lock_content (item)      ||
       layer_lock_position   != gimp_item_get_lock_position (item)     ||
       layer_lock_visibility != gimp_item_get_lock_visibility (item)   ||
-      layer_lock_alpha      != gimp_layer_get_lock_alpha (layer))
+      layer_lock_alpha      != gimp_layer_get_lock_alpha (layer)      ||
+      link)
     {
       gimp_image_undo_group_start (image,
                                    GIMP_UNDO_GROUP_ITEM_PROPERTIES,
@@ -2468,6 +2568,9 @@ layers_edit_attributes_callback (GtkWidget              *dialog,
       if (layer_lock_alpha != gimp_layer_get_lock_alpha (layer))
         gimp_layer_set_lock_alpha (layer, layer_lock_alpha, TRUE);
 
+      if (GIMP_IS_LINK_LAYER (layer) && link)
+        gimp_link_layer_set_link (GIMP_LINK_LAYER (layer), link, TRUE);
+
       gimp_image_undo_group_end (image);
       gimp_image_flush (image);
     }
@@ -2591,6 +2694,56 @@ layers_scale_callback (GtkWidget             *dialog,
     }
 }
 
+void
+layers_vector_fill_stroke_cmd_callback (GimpAction *action,
+                                        GVariant   *value,
+                                        gpointer    data)
+{
+  GimpImage *image;
+  GimpLayer *layer;
+  GList     *layers;
+  GtkWidget *widget;
+  return_if_no_layers (image, layers, data);
+  return_if_no_widget (widget, data);
+
+  if (g_list_length (layers) != 1)
+    return;
+
+  layer = layers->data;
+
+  if (GIMP_IS_VECTOR_LAYER (layer))
+    {
+      GtkWidget *dialog;
+
+      dialog = vector_layer_options_dialog_new (GIMP_VECTOR_LAYER (layer),
+                                                action_data_get_context (data),
+                                                _("Fill / Stroke"),
+                                                "gimp-vector-layer-stroke",
+                                                GIMP_HELP_LAYER_VECTOR_FILL_STROKE,
+                                                widget);
+      gtk_widget_show (dialog);
+    }
+}
+
+void
+layers_vector_discard_cmd_callback (GimpAction *action,
+                                    GVariant   *value,
+                                    gpointer    data)
+{
+  GimpImage *image;
+  GimpLayer *layer;
+  GList     *layers;
+  return_if_no_layers (image, layers, data);
+
+  if (g_list_length (layers) != 1)
+    return;
+
+  layer = layers->data;
+
+  if (GIMP_IS_VECTOR_LAYER (layer))
+    gimp_vector_layer_discard (GIMP_VECTOR_LAYER (layer));
+}
+
 static void
 layers_resize_callback (GtkWidget    *dialog,
                         GimpViewable *viewable,
