@@ -44,9 +44,10 @@
 #include "pdb/gimppdb.h"
 #include "pdb/gimpprocedure.h"
 
-#include "vectors/gimppath.h"
-#include "vectors/gimppath-export.h"
-#include "vectors/gimppath-import.h"
+#include "path/gimppath.h"
+#include "path/gimppath-export.h"
+#include "path/gimppath-import.h"
+#include "path/gimpvectorlayer.h"
 
 #include "widgets/gimpaction.h"
 #include "widgets/gimpclipboard.h"
@@ -54,7 +55,7 @@
 
 #include "display/gimpdisplay.h"
 
-#include "tools/gimpvectortool.h"
+#include "tools/gimppathtool.h"
 #include "tools/tool_manager.h"
 
 #include "dialogs/dialogs.h"
@@ -125,10 +126,10 @@ paths_edit_cmd_callback (GimpAction *action,
 
   active_tool = tool_manager_get_active (image->gimp);
 
-  if (! GIMP_IS_VECTOR_TOOL (active_tool))
+  if (! GIMP_IS_PATH_TOOL (active_tool))
     {
-      GimpToolInfo  *tool_info = gimp_get_tool_info (image->gimp,
-                                                     "gimp-vector-tool");
+      GimpToolInfo *tool_info = gimp_get_tool_info (image->gimp,
+                                                    "gimp-path-tool");
 
       if (GIMP_IS_TOOL_INFO (tool_info))
         {
@@ -137,8 +138,8 @@ paths_edit_cmd_callback (GimpAction *action,
         }
     }
 
-  if (GIMP_IS_VECTOR_TOOL (active_tool))
-    gimp_vector_tool_set_vectors (GIMP_VECTOR_TOOL (active_tool), paths->data);
+  if (GIMP_IS_PATH_TOOL (active_tool))
+    gimp_path_tool_set_path (GIMP_PATH_TOOL (active_tool), paths->data);
 }
 
 void
@@ -469,6 +470,7 @@ paths_delete_cmd_callback (GimpAction *action,
 {
   GimpImage *image;
   GList     *paths;
+  gboolean   attached_to_vector_layer = FALSE;
   return_if_no_paths (image, paths, data);
 
   paths = g_list_copy (paths);
@@ -478,11 +480,21 @@ paths_delete_cmd_callback (GimpAction *action,
                                _("Remove Paths"));
 
   for (GList *iter = paths; iter; iter = iter->next)
-    gimp_image_remove_path (image, iter->data, TRUE, NULL);
+    {
+      /* Verify path is not attached to vector layer */
+      if (! gimp_path_attached_to_vector_layer (GIMP_PATH (iter->data), image))
+        gimp_image_remove_path (image, iter->data, TRUE, NULL);
+      else
+        attached_to_vector_layer = TRUE;
+    }
 
   gimp_image_undo_group_end (image);
   gimp_image_flush (image);
   g_list_free (paths);
+
+  if (attached_to_vector_layer)
+    gimp_message_literal (image->gimp, NULL, GIMP_MESSAGE_WARNING,
+                          _("Paths attached to vector layers weren't deleted"));
 }
 
 void
@@ -509,6 +521,28 @@ paths_merge_visible_cmd_callback (GimpAction *action,
   gimp_image_flush (image);
 }
 
+void
+path_to_vector_layer_cmd_callback (GimpAction *action,
+                                   GVariant   *value,
+                                   gpointer    data)
+{
+  GimpImage       *image;
+  GList           *paths;
+  GimpVectorLayer *layer;
+  return_if_no_paths (image, paths, data);
+
+  layer = gimp_vector_layer_new (image, paths->data,
+                                 gimp_get_user_context (image->gimp));
+  gimp_image_add_layer (image,
+                        GIMP_LAYER (layer),
+                        GIMP_IMAGE_ACTIVE_PARENT,
+                        -1,
+                        TRUE);
+  gimp_vector_layer_refresh (layer);
+
+  gimp_image_flush (image);
+}
+
 void
 paths_to_selection_cmd_callback (GimpAction *action,
                                  GVariant   *value,
@@ -924,8 +958,8 @@ paths_import_callback (GtkWidget *dialog,
                        GimpImage *image,
                        GFile     *file,
                        GFile     *import_folder,
-                       gboolean   merge_vectors,
-                       gboolean   scale_vectors,
+                       gboolean   merge_paths,
+                       gboolean   scale_paths,
                        gpointer   user_data)
 {
   GimpDialogConfig *config = GIMP_DIALOG_CONFIG (image->gimp->config);
@@ -937,8 +971,8 @@ paths_import_callback (GtkWidget *dialog,
 
   g_object_set (config,
                 "path-import-path",  path,
-                "path-import-merge", merge_vectors,
-                "path-import-scale", scale_vectors,
+                "path-import-merge", merge_paths,
+                "path-import-scale", scale_paths,
                 NULL);
 
   if (path)
