@@ -12,16 +12,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __PLUG_IN_ACTIONS_H__
-#define __PLUG_IN_ACTIONS_H__
+#pragma once
 
 
 void   plug_in_actions_setup  (GimpActionGroup *group);
 void   plug_in_actions_update (GimpActionGroup *group,
                                gpointer         data);
-
-
-#endif /* __PLUG_IN_ACTIONS_H__ */
