@@ -95,14 +95,14 @@ quick_mask_actions_update (GimpActionGroup *group,
   GimpImage *image               = action_data_get_image (data);
   gboolean   quick_mask_state    = FALSE;
   gboolean   quick_mask_inverted = FALSE;
-  GimpRGB    quick_mask_color;
+  GeglColor *quick_mask_color    = NULL;
 
   if (image)
     {
       quick_mask_state    = gimp_image_get_quick_mask_state (image);
       quick_mask_inverted = gimp_image_get_quick_mask_inverted (image);
 
-      gimp_image_get_quick_mask_color (image, &quick_mask_color);
+      quick_mask_color = gimp_image_get_quick_mask_color (image);
     }
 
 #define SET_SENSITIVE(action,sensitive) \
@@ -125,8 +125,8 @@ quick_mask_actions_update (GimpActionGroup *group,
 
   SET_SENSITIVE ("quick-mask-configure", image);
 
-  if (image)
-    SET_COLOR ("quick-mask-configure", &quick_mask_color);
+  if (quick_mask_color)
+    SET_COLOR ("quick-mask-configure", quick_mask_color);
 
 #undef SET_SENSITIVE
 #undef SET_ACTIVE
