@@ -15,13 +15,9 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __TOOL_PRESET_EDITOR_ACTIONS_H__
-#define __TOOL_PRESET_EDITOR_ACTIONS_H__
+#pragma once
 
 
 void   tool_preset_editor_actions_setup  (GimpActionGroup *group);
 void   tool_preset_editor_actions_update (GimpActionGroup *group,
                                           gpointer         data);
-
-
-#endif /* __TOOL_PRESET_EDITOR_ACTIONS_H__ */
