@@ -18,8 +18,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_DIALOG_CONFIG_H__
-#define __GIMP_DIALOG_CONFIG_H__
+#pragma once
 
 #include "config/gimpguiconfig.h"
 
@@ -119,6 +118,3 @@ struct _GimpDialogConfigClass
 
 
 GType  gimp_dialog_config_get_type (void) G_GNUC_CONST;
-
-
-#endif /* GIMP_DIALOG_CONFIG_H__ */
