@@ -1,8 +1,6 @@
 /*  gimprc-blurbs.h  --  descriptions for gimprc properties  */
 
-#ifndef __GIMP_RC_BLURBS_H__
-#define __GIMP_RC_BLURBS_H__
-
+#pragma once
 
 /*  Not all strings defined here are used in the user interface
  *  (the preferences dialog mainly) and only those that are should
@@ -259,6 +257,15 @@ _("Export XMP metadata by default.")
 #define EXPORT_METADATA_IPTC_BLURB \
 _("Export IPTC metadata by default.")
 
+/* Translators: tooltip for configuration option (checkbox).
+ * It determines what metadata is updated when exporting.
+ */
+#define EXPORT_UPDATE_METADATA_BLURB \
+_("When enabled, add and update metadata automatically. When disabled, " \
+  "only the minimum necessary metadata changes are made, without changing " \
+  "modification date, synchronizing tags, or updating the software and " \
+  "change history metadata.")
+
 #define GENERATE_BACKTRACE_BLURB \
 _("Try generating debug data for bug reporting when appropriate.")
 
@@ -512,6 +519,9 @@ _("Enable the Seamless Clone tool.")
 #define PLAYGROUND_PAINT_SELECT_TOOL_BLURB \
 _("Enable the Paint Select tool.")
 
+#define PLAYGROUND_USE_LIST_BOX_BLURB \
+_("Use the new GtkListBox widget for simple lists.")
+
 #define SPACE_BAR_ACTION_BLURB \
 _("What to do when the space bar is pressed in the image window.")
 
@@ -664,22 +674,22 @@ _("Sets the default channel name for the 'New Channel' dialog.")
 #define CHANNEL_NEW_COLOR_BLURB \
 _("Sets the default color and opacity for the 'New Channel' dialog.")
 
-#define VECTORS_NEW_NAME_BLURB \
+#define PATH_NEW_NAME_BLURB \
 _("Sets the default path name for the 'New Path' dialog.")
 
-#define VECTORS_EXPORT_PATH_BLURB \
+#define PATH_EXPORT_PATH_BLURB \
 _("Sets the default folder path for the 'Export Path' dialog.")
 
-#define VECTORS_EXPORT_ACTIVE_ONLY_BLURB \
+#define PATH_EXPORT_ACTIVE_ONLY_BLURB \
 _("Sets the default 'Export the selected paths' state for the 'Export Path' dialog.")
 
-#define VECTORS_IMPORT_PATH_BLURB \
+#define PATH_IMPORT_PATH_BLURB \
 _("Sets the default folder path for the 'Import Path' dialog.")
 
-#define VECTORS_IMPORT_MERGE_BLURB \
+#define PATH_IMPORT_MERGE_BLURB \
 _("Sets the default 'Merge imported paths' state for the 'Import Path' dialog.")
 
-#define VECTORS_IMPORT_SCALE_BLURB \
+#define PATH_IMPORT_SCALE_BLURB \
 _("Sets the default 'Scale imported paths to fit size' state for the 'Import Path' dialog.")
 
 #define SELECTION_FEATHER_RADIUS_BLURB \
@@ -799,6 +809,3 @@ _("When enabled, a search of actions will also return inactive actions.")
 
 #define ACTION_HISTORY_SIZE_BLURB \
 _("The maximum number of actions saved in history.")
-
-
-#endif  /* __GIMP_RC_BLURBS_H__ */
