@@ -15,13 +15,9 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_BATCH_H__
-#define __GIMP_BATCH_H__
+#pragma once
 
 
 gint   gimp_batch_run (Gimp         *gimp,
                        const gchar  *batch_interpreter,
                        const gchar **batch_commands);
-
-
-#endif /* __GIMP_BATCH_H__ */
