@@ -121,7 +121,10 @@ gimp_user_install_items[] =
 static gboolean  user_install_detect_old         (GimpUserInstall    *install,
                                                   const gchar        *gimp_dir);
 static gchar   * user_install_old_style_gimpdir  (void);
+
+#ifdef G_OS_UNIX
 static gchar   * user_install_flatpak_gimpdir    (gint                minor);
+#endif
 
 static void      user_install_log                (GimpUserInstall    *install,
                                                   const gchar        *format,
@@ -221,18 +224,14 @@ gimp_user_install_run (GimpUserInstall *install,
 
   if (install->migrate)
     {
-      gchar *verstring;
-
-      /* TODO: these 2 strings should be merged into one, but it was not
-       * possible to do it at implementation time, in order not to break
-       * string freeze.
-       */
-      verstring = g_strdup_printf ("%d.%d", install->old_major, install->old_minor);
       user_install_log (install,
-                        _("It seems you have used GIMP %s before.  "
+                        /* TRANSLATORS: the %d.%d replacement strings
+                         * will be a series version (e.g. 2.10). The %s
+                         * replacement will be a directory.
+                         */
+                        _("It seems you have used GIMP %d.%d before.  "
                           "GIMP will now migrate your user settings to '%s'."),
-                        verstring, dirname);
-      g_free (verstring);
+                        install->old_major, install->old_minor, dirname);
     }
   else
     {
@@ -297,7 +296,7 @@ user_install_detect_old (GimpUserInstall *install,
       gint major;
       gint minor;
 
-      for (major = 3; major >= 2; major--)
+      for (major = GIMP_MAJOR_VERSION; major >= 2; major--)
         {
           gint max_minor;
 
@@ -324,14 +323,14 @@ user_install_detect_old (GimpUserInstall *install,
 
               if (migrate)
                 {
-                  install->old_major = 2;
+                  install->old_major = major;
                   install->old_minor = minor;
 
                   break;
                 }
 
 #ifdef G_OS_UNIX
-              if (minor == 10)
+              if (major == 2 && minor == 10)
                 {
                   /* This is special-casing for GIMP 2.10 as flatpak where
                    * we had this weird inconsistency: depending on whether a
@@ -381,6 +380,8 @@ user_install_detect_old (GimpUserInstall *install,
                 }
 #endif
             }
+          if (migrate)
+            break;
         }
     }
 
@@ -446,6 +447,7 @@ user_install_old_style_gimpdir (void)
   return gimp_dir;
 }
 
+#ifdef G_OS_UNIX
 static gchar *
 user_install_flatpak_gimpdir (gint minor)
 {
@@ -466,6 +468,7 @@ user_install_flatpak_gimpdir (gint minor)
 
   return gimp_dir;
 }
+#endif
 
 static void
 user_install_log (GimpUserInstall *install,
@@ -829,6 +832,52 @@ user_update_post_process_menurc_over20 (gpointer user_data)
   return g_string_free (string, FALSE);
 }
 
+#define SHORTCUTSRC_UPDATE_PATTERN \
+  "\"("                            \
+  "tools-vector|"                  \
+  "dialogs-vectors|"               \
+  "layers-text-.*-vectors|"        \
+  "view-snap-to-vectors"           \
+  ")\""
+
+static gboolean
+user_update_shortcutsrc (const GMatchInfo *matched_value,
+                         GString          *new_value,
+                         gpointer          data)
+{
+  gchar *match = g_match_info_fetch (matched_value, 0);
+
+  if (g_strcmp0 (match, "\"tools-vector\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"tools-path\"");
+    }
+  else if (g_strcmp0 (match, "\"dialogs-vectors\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"dialogs-path\"");
+    }
+  else if (g_strcmp0 (match, "\"layers-text-along-vectors\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"layers-text-along-path\"");
+    }
+  else if (g_strcmp0 (match, "\"layers-text-to-vectors\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"layers-text-to-path\"");
+    }
+  else if (g_strcmp0 (match, "\"view-snap-to-vectors\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"view-snap-to-path\"");
+    }
+
+  g_free (match);
+
+  return FALSE;
+}
+
 #define TEMPLATERC_UPDATE_PATTERN \
   "\\(precision (.*)-gamma\\)"
 
@@ -878,16 +927,16 @@ user_update_controllerrc (const GMatchInfo *matched_value,
   return FALSE;
 }
 
-#define SESSIONRC_UPDATE_PATTERN \
-  "\\(position [0-9]* [0-9]*\\)"        "|"  \
-  "\\(size [0-9]* [0-9]*\\)"            "|" \
-  "\\(left-docks-width \"?[0-9]*\"?\\)" "|" \
+#define SESSIONRC_UPDATE_PATTERN_2TO3 \
+  "\\(position [0-9]* [0-9]*\\)"         "|" \
+  "\\(size [0-9]* [0-9]*\\)"             "|" \
+  "\\(left-docks-width \"?[0-9]*\"?\\)"  "|" \
   "\\(right-docks-width \"?[0-9]*\"?\\)"
 
 static gboolean
-user_update_sessionrc (const GMatchInfo *matched_value,
-                       GString          *new_value,
-                       gpointer          data)
+user_update_sessionrc_2to3 (const GMatchInfo *matched_value,
+                            GString          *new_value,
+                            gpointer          data)
 {
   GimpUserInstall *install = (GimpUserInstall *) data;
   gchar           *original;
@@ -960,6 +1009,52 @@ user_update_sessionrc (const GMatchInfo *matched_value,
   return FALSE;
 }
 
+#define TOOLRC_UPDATE_PATTERN \
+  "\"gimp-vector-tool\""
+
+static gboolean
+user_update_toolrc (const GMatchInfo *matched_value,
+                    GString          *new_value,
+                    gpointer          data)
+{
+  gchar *original;
+
+  original = g_match_info_fetch (matched_value, 0);
+
+  if (g_strcmp0 (original, "\"gimp-vector-tool\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"gimp-path-tool\"");
+    }
+
+  g_free (original);
+
+  return FALSE;
+}
+
+#define SESSIONRC_UPDATE_PATTERN \
+  "\"gimp-vectors-list\""
+
+static gboolean
+user_update_sessionrc (const GMatchInfo *matched_value,
+                       GString          *new_value,
+                       gpointer          data)
+{
+  gchar *original;
+
+  original = g_match_info_fetch (matched_value, 0);
+
+  if (g_strcmp0 (original, "\"gimp-vectors-list\"") == 0)
+    {
+      /* Renamed in GIMP 3.2. */
+      g_string_append (new_value, "\"gimp-path-list\"");
+    }
+
+  g_free (original);
+
+  return FALSE;
+}
+
 #define GIMPRC_UPDATE_PATTERN \
   "\\(show-tooltips [^)]*\\)"  "|" \
   "\\(theme [^)]*\\)"          "|" \
@@ -1298,29 +1393,49 @@ user_install_migrate_files (GimpUserInstall *install)
               g_str_has_prefix (basename, "gimpswap.") ||
               strcmp (basename, "pluginrc") == 0       ||
               strcmp (basename, "themerc") == 0        ||
-              strcmp (basename, "toolrc") == 0         ||
               strcmp (basename, "gtkrc") == 0)
             {
               goto next_file;
             }
+          else if (strcmp (basename, "toolrc") == 0)
+            {
+              if (install->old_major < 2 ||
+                  (install->old_major == 2 && install->old_minor < 10))
+                {
+                  /* No new tool since GIMP 2.10. */
+                  goto next_file;
+                }
+              else
+                {
+                  update_pattern  = TOOLRC_UPDATE_PATTERN;
+                  update_callback = user_update_toolrc;
+                }
+            }
           else if (install->old_major < 3 &&
                    strcmp (basename, "sessionrc") == 0)
             {
               /* We need to update size and positions because of scale
                * factor support.
                */
+              update_pattern  = SESSIONRC_UPDATE_PATTERN_2TO3;
+              update_callback = user_update_sessionrc_2to3;
+            }
+          else if (strcmp (basename, "sessionrc") == 0)
+            {
+              /* sessionrc updates since 3.0. */
               update_pattern  = SESSIONRC_UPDATE_PATTERN;
               update_callback = user_update_sessionrc;
             }
           else if (strcmp (basename, "menurc") == 0)
             {
-              switch (install->old_minor)
+              if (install->old_major < 2 ||
+                  (install->old_major == 2 && install->old_minor == 0))
                 {
-                case 0:
                   /*  skip menurc for gimp 2.0 as the format has changed  */
                   goto next_file;
-                  break;
-                default:
+                }
+              else
+                {
                   update_pattern        = MENURC_OVER20_UPDATE_PATTERN;
                   update_callback       = user_update_menurc_over20;
                   post_process_callback = user_update_post_process_menurc_over20;
@@ -1329,6 +1444,11 @@ user_install_migrate_files (GimpUserInstall *install)
                   break;
                 }
             }
+          else if (strcmp (basename, "shortcutsrc") == 0)
+            {
+              update_pattern  = SHORTCUTSRC_UPDATE_PATTERN;
+              update_callback = user_update_shortcutsrc;
+            }
           else if (strcmp (basename, "templaterc") == 0)
             {
               update_pattern  = TEMPLATERC_UPDATE_PATTERN;
