@@ -34,7 +34,6 @@
 
 #ifdef G_OS_WIN32
 #include <windows.h>
-#include <process.h>
 #endif
 
 #include <cairo.h>
@@ -103,6 +102,14 @@ static void         appstream_text_characters      (GMarkupParseContext  *contex
 static const gchar* gimp_extension_get_tag_lang    (const gchar         **attribute_names,
                                                     const gchar         **attribute_values);
 
+static gboolean     gimp_version_break             (const gchar          *v,
+                                                    gint                 *major,
+                                                    gint                 *minor,
+                                                    gint                 *micro,
+                                                    gint                 *rc,
+                                                    gboolean             *is_git);
+
+
 gint
 gimp_get_pid (void)
 {
@@ -147,9 +154,7 @@ gimp_get_default_language (const gchar *category)
 {
   gchar *lang;
   gchar *p;
-#ifndef G_OS_WIN32
   gint   cat = LC_CTYPE;
-#endif
 
   if (! category)
     category = "LC_CTYPE";
@@ -1555,47 +1560,71 @@ gimp_view_size_get_smaller (gint view_size)
 }
 
 /**
- * gimp_get_type_children:
- * @type: the %GType to find children types for.
- * @types: set %NULL for the initial call (internal variable for
- *         recursive calls).
- * @excluded: a list of types to exclude.
+ * gimp_version_cmp:
+ * @v1: a string representing a version, ex. "2.10.22".
+ * @v2: a string representing another version, ex. "2.99.2".
  *
- * Gather and recursively return all the subtypes of @type (except any
- * type listed in @excluded).
+ * If @v2 is %NULL, @v1 is compared to the currently running version.
  *
- * Note that @type itself is not included, so if you wished to have it,
- * you must add it yourself after calling this function.
- *
- * Returns: a list of %Gtypes.
+ * Returns: an integer less than, equal to, or greater than zero if @v1
+ *          is found to represent a version respectively, lower than,
+ *          matching, or greater than @v2.
  */
-GList *
-gimp_get_type_children (GType  type,
-                        GList *types,
-                        GList *excluded)
+gint
+gimp_version_cmp (const gchar *v1,
+                  const gchar *v2)
 {
-  GType *dtypes;
-  guint  n_types;
+  gint     major1;
+  gint     minor1;
+  gint     micro1;
+  gint     rc1;
+  gboolean is_git1;
+  gint     major2  = GIMP_MAJOR_VERSION;
+  gint     minor2  = GIMP_MINOR_VERSION;
+  gint     micro2  = GIMP_MICRO_VERSION;
+  gint     rc2     = 0;
+  gboolean is_git2 = FALSE;
 
-  dtypes = g_type_children (type, &n_types);
+#if defined(GIMP_RC_VERSION)
+  rc2 = GIMP_RC_VERSION;
+#if defined(GIMP_IS_RC_GIT)
+  is_git2 = TRUE;
+#endif
+#endif
 
-  /* TODO: when bumping GLib >= 2.80, use GTYPE_TO_POINTER instead. */
-#define GIMPTYPE_TO_POINTER(t) ((gpointer) (guintptr) (t))
+  g_return_val_if_fail (v1 != NULL, -1);
 
-  for (gint i = 0; i < n_types; i++)
+  if (! gimp_version_break (v1, &major1, &minor1, &micro1, &rc1, &is_git1))
     {
-      if (g_list_find (excluded, GIMPTYPE_TO_POINTER (dtypes[i])))
-        continue;
+      /* If version is not properly parsed, something is wrong with
+       * upstream version number or parsing. This should not happen.
+       */
+      g_printerr ("%s: version not properly formatted: %s\n",
+                  G_STRFUNC, v1);
 
-      types = gimp_get_type_children (dtypes[i], types, excluded);
-      types = g_list_prepend (types, GIMPTYPE_TO_POINTER (dtypes[i]));
+      return -1;
+    }
+  if (v2 && ! gimp_version_break (v2, &major2, &minor2, &micro2, &rc2, &is_git2))
+    {
+      g_printerr ("%s: version not properly formatted: %s\n",
+                  G_STRFUNC, v2);
+
+      return 1;
     }
 
-#undef GIMPTYPE_TO_POINTER
-
-  g_free (dtypes);
-
-  return types;
+  if (major1 == major2 && minor1 == minor2 && micro1 == micro2 &&
+      rc1 == rc2 && is_git1 == is_git2)
+    return 0;
+  else if (major1 > major2                                                                    ||
+           (major1 == major2 && minor1 > minor2)                                              ||
+           (major1 == major2 && minor1 == minor2 && micro1 > micro2)                          ||
+           /* RC 0 is the real release, so it's "higher" than any other. */
+           (major1 == major2 && minor1 == minor2 && micro1 == micro2 && rc1 == 0 && rc2 > 0)  ||
+           (major1 == major2 && minor1 == minor2 && micro1 == micro2 && rc1 > rc2 && rc2 > 0) ||
+           (major1 == major2 && minor1 == minor2 && micro1 == micro2 && rc1 == rc2 && is_git1))
+    return 1;
+  else
+    return -1;
 }
 
 /* Private functions */
@@ -1834,3 +1863,70 @@ gimp_extension_get_tag_lang (const gchar **attribute_names,
 
   return NULL;
 }
+
+static gboolean
+gimp_version_break (const gchar *v,
+                    gint        *major,
+                    gint        *minor,
+                    gint        *micro,
+                    gint        *rc,
+                    gboolean    *is_git)
+{
+  gchar **versions;
+
+  *major  = 0;
+  *minor  = 0;
+  *micro  = 0;
+  *rc     = 0;
+  *is_git = FALSE;
+
+  if (v == NULL)
+    return FALSE;
+
+  versions = g_strsplit_set (v, ".", 3);
+  if (versions[0] != NULL)
+    {
+      *major = g_ascii_strtoll (versions[0], NULL, 10);
+      if (versions[1] != NULL)
+        {
+          *minor = g_ascii_strtoll (versions[1], NULL, 10);
+          if (versions[2] != NULL)
+            {
+              gchar **micro_rc_git;
+
+              *micro = g_ascii_strtoll (versions[2], NULL, 10);
+
+              micro_rc_git = g_strsplit_set (versions[2], "-", 2);
+
+              if (g_strv_length (micro_rc_git) > 1 &&
+                  strlen (micro_rc_git[1]) > 2     &&
+                  micro_rc_git[1][0] == 'R'           &&
+                  micro_rc_git[1][1] == 'C')
+                {
+                  gchar **rc_git;
+
+                  *rc = g_ascii_strtoll (micro_rc_git[1] + 2, NULL, 10);
+
+                  rc_git = g_strsplit_set (micro_rc_git[1], "+", 2);
+
+                  if (g_strv_length (rc_git) > 1 &&
+                      strlen (rc_git[1]) == 3    &&
+                      rc_git[1][0] == 'g'        &&
+                      rc_git[1][1] == 'i'        &&
+                      rc_git[1][2] == 't')
+                    {
+                      *is_git = TRUE;
+                    }
+
+                  g_strfreev (rc_git);
+                }
+
+              g_strfreev (micro_rc_git);
+            }
+        }
+    }
+
+  g_strfreev (versions);
+
+  return (*major > 0 || *minor > 0 || *micro > 0);
+}
