@@ -74,7 +74,6 @@
 #include "gimppattern.h"
 #include "gimptemplate.h"
 #include "gimptoolinfo.h"
-#include "gimptoolpreset.h"
 #include "gimptreeproxy.h"
 
 #include "text/gimpfont.h"
@@ -98,7 +97,6 @@ enum
   CLIPBOARD_CHANGED,
   FILTER_HISTORY_CHANGED,
   IMAGE_OPENED,
-  FOCUSED_ONCE,
   LAST_SIGNAL
 };
 
@@ -207,13 +205,6 @@ gimp_class_init (GimpClass *klass)
                   NULL, NULL, NULL,
                   G_TYPE_NONE, 1, G_TYPE_FILE);
 
-  gimp_signals[FOCUSED_ONCE] =
-    g_signal_new ("focused-once",
-                  G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_RUN_LAST, 0,
-                  NULL, NULL, NULL,
-                  G_TYPE_NONE, 0);
-
   object_class->constructed      = gimp_constructed;
   object_class->set_property     = gimp_set_property;
   object_class->get_property     = gimp_get_property;
@@ -302,8 +293,6 @@ gimp_init (Gimp *gimp)
 
   gimp->templates = gimp_list_new (GIMP_TYPE_TEMPLATE, TRUE);
   gimp_object_set_static_name (GIMP_OBJECT (gimp->templates), "templates");
-
-  gimp->focused_once = FALSE;
 }
 
 static void
@@ -892,7 +881,7 @@ gimp_is_restored (Gimp *gimp)
 {
   g_return_val_if_fail (GIMP_IS_GIMP (gimp), FALSE);
 
-  return gimp->initialized && gimp->restored && gimp_data_factories_wait (gimp);
+  return gimp->initialized && gimp->restored;
 }
 
 /**
@@ -928,26 +917,6 @@ gimp_exit (Gimp     *gimp,
                    gimp, NULL);
 }
 
-void
-gimp_set_focused_once (Gimp *gimp)
-{
-  g_return_if_fail (GIMP_IS_GIMP (gimp));
-
-  if (! gimp->focused_once)
-    {
-      gimp->focused_once = TRUE;
-      g_signal_emit (gimp, gimp_signals[FOCUSED_ONCE], 0);
-    }
-}
-
-gboolean
-gimp_has_focused_once (Gimp *gimp)
-{
-  g_return_val_if_fail (GIMP_IS_GIMP (gimp), FALSE);
-
-  return gimp->focused_once;
-}
-
 GList *
 gimp_get_image_iter (Gimp *gimp)
 {
@@ -1326,8 +1295,6 @@ gimp_get_data_factory (Gimp  *gimp,
     return gimp->dynamics_factory;
   else if (g_type_is_a (data_type, GIMP_TYPE_MYBRUSH))
     return gimp->mybrush_factory;
-  else if (g_type_is_a (data_type, GIMP_TYPE_TOOL_PRESET))
-    return gimp->tool_preset_factory;
 
   /* If we reach this, it means we forgot a data factory in our list! */
   g_return_val_if_reached (NULL);
