@@ -18,9 +18,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_CONTEXT_H__
-#define __GIMP_CONTEXT_H__
-
+#pragma once
 
 #include "gimpviewable.h"
 
@@ -367,6 +365,3 @@ void             gimp_context_template_changed    (GimpContext     *context);
 GimpLineArt    * gimp_context_take_line_art       (GimpContext     *context);
 void             gimp_context_store_line_art      (GimpContext     *context,
                                                    GimpLineArt     *line_art);
-
-
-#endif /* __GIMP_CONTEXT_H__ */
