@@ -18,8 +18,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_EXTENSION_ERROR_H__
-#define __GIMP_EXTENSION_ERROR_H__
+#pragma once
 
 
 typedef enum
@@ -36,7 +35,3 @@ typedef enum
 #define GIMP_EXTENSION_ERROR (gimp_extension_error_quark ())
 
 GQuark  gimp_extension_error_quark (void) G_GNUC_CONST;
-
-
-#endif /* __GIMP_EXTENSION_ERROR_H__ */
-
