@@ -15,8 +15,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_IMAGE_PRIVATE_H__
-#define __GIMP_IMAGE_PRIVATE_H__
+#pragma once
 
 
 typedef struct _GimpImageFlushAccumulator GimpImageFlushAccumulator;
@@ -139,7 +138,6 @@ struct _GimpImagePrivate
   gboolean           quick_mask_state;      /*  TRUE if quick mask is on       */
   gboolean           quick_mask_inverted;   /*  TRUE if quick mask is inverted */
   GeglColor         *quick_mask_color;      /*  rgba triplet of the color      */
-  GList             *quick_mask_selected;   /*  Drawables selected to revert   */
 
   /*  Undo apparatus  */
   GimpUndoStack     *undo_stack;            /*  stack for undo operations    */
@@ -155,6 +153,3 @@ struct _GimpImagePrivate
 
 void   gimp_image_take_mask (GimpImage   *image,
                              GimpChannel *mask);
-
-
-#endif  /* __GIMP_IMAGE_PRIVATE_H__ */
