@@ -15,8 +15,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_IMAGE_UNDO_PUSH_H__
-#define __GIMP_IMAGE_UNDO_PUSH_H__
+#pragma once
 
 
 /*  image undos  */
@@ -215,6 +214,22 @@ GimpUndo * gimp_image_undo_push_text_layer_convert  (GimpImage     *image,
                                                      const gchar   *undo_desc,
                                                      GimpTextLayer *layer);
 
+/*  link layer undos  */
+
+GimpUndo * gimp_image_undo_push_link_layer          (GimpImage     *image,
+                                                     const gchar   *undo_desc,
+                                                     GimpLinkLayer *layer);
+
+/*  vector layer undos  */
+
+GimpUndo * gimp_image_undo_push_vector_layer        (GimpImage        *image,
+                                                     const gchar      *undo_desc,
+                                                     GimpVectorLayer  *layer,
+                                                     const GParamSpec *pspec);
+GimpUndo * gimp_image_undo_push_vector_layer_modified
+                                                    (GimpImage       *image,
+                                                     const gchar     *undo_desc,
+                                                     GimpVectorLayer *layer);
 
 /*  layer mask undos  */
 
@@ -279,6 +294,3 @@ GimpUndo * gimp_image_undo_push_fs_to_layer         (GimpImage     *image,
 
 GimpUndo * gimp_image_undo_push_cantundo            (GimpImage     *image,
                                                      const gchar   *undo_desc);
-
-
-#endif  /* __GIMP_IMAGE_UNDO_PUSH_H__ */
