@@ -280,7 +280,6 @@ gimp_item_class_init (GimpItemClass *klass)
   klass->stroke                    = NULL;
   klass->to_selection              = NULL;
 
-  klass->default_name              = NULL;
   klass->rename_desc               = NULL;
   klass->translate_desc            = NULL;
   klass->scale_desc                = NULL;
@@ -775,7 +774,7 @@ gimp_item_new (GType        type,
     gimp_object_set_name (GIMP_OBJECT (item), name);
   else
     gimp_object_set_static_name (GIMP_OBJECT (item),
-                                 GIMP_ITEM_GET_CLASS (item)->default_name);
+                                 GIMP_VIEWABLE_GET_CLASS (item)->default_name);
 
   return item;
 }
@@ -1100,7 +1099,7 @@ gimp_item_rename (GimpItem     *item,
   item_class = GIMP_ITEM_GET_CLASS (item);
 
   if (! new_name || ! *new_name)
-    new_name = item_class->default_name;
+    new_name = GIMP_VIEWABLE_GET_CLASS (item)->default_name;
 
   if (strcmp (new_name, gimp_object_get_name (item)))
     return item_class->rename (item, new_name, item_class->rename_desc, error);
@@ -1778,7 +1777,7 @@ gimp_item_transform (GimpItem               *item,
   g_object_freeze_notify (G_OBJECT (item));
 
   item_class->transform (item, context, matrix, direction, interpolation,
-                         clip_result, progress);
+                         clip_result, progress, TRUE);
 
   g_object_thaw_notify (G_OBJECT (item));
 
@@ -2651,7 +2650,8 @@ gimp_item_mask_bounds (GimpItem *item,
       ! gimp_channel_is_empty (selection) &&
       gimp_item_bounds (GIMP_ITEM (selection), &x, &y, &width, &height))
     {
-      gint off_x, off_y;
+      gint off_x = 0;
+      gint off_y = 0;
       gint x2, y2;
 
       gimp_item_get_offset (item, &off_x, &off_y);
@@ -2725,7 +2725,8 @@ gimp_item_mask_intersect (GimpItem *item,
       gimp_item_bounds (GIMP_ITEM (selection),
                         &tmp_x, &tmp_y, &tmp_width, &tmp_height))
     {
-      gint off_x, off_y;
+      gint off_x = 0;
+      gint off_y = 0;
 
       gimp_item_get_offset (item, &off_x, &off_y);
 
