@@ -15,9 +15,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_ITEM_PROP_UNDO_H__
-#define __GIMP_ITEM_PROP_UNDO_H__
-
+#pragma once
 
 #include "gimpitemundo.h"
 
@@ -59,6 +57,3 @@ struct _GimpItemPropUndoClass
 
 
 GType   gimp_item_prop_undo_get_type (void) G_GNUC_CONST;
-
-
-#endif /* __GIMP_ITEM_PROP_UNDO_H__ */
