@@ -15,28 +15,18 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_RESOURCE_H__
-#define __GIMP_RESOURCE_H__
-
+#pragma once
 
 #include "gimpviewable.h"
 
 
-#define GIMP_TYPE_RESOURCE            (gimp_resource_get_type ())
-#define GIMP_RESOURCE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_RESOURCE, GimpResource))
-#define GIMP_RESOURCE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_RESOURCE, GimpResourceClass))
-#define GIMP_IS_RESOURCE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_RESOURCE))
-#define GIMP_IS_RESOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_RESOURCE))
-#define GIMP_RESOURCE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_RESOURCE, GimpResourceClass))
+#define GIMP_TYPE_RESOURCE (gimp_resource_get_type ())
+G_DECLARE_DERIVABLE_TYPE (GimpResource,
+                          gimp_resource,
+                          GIMP, RESOURCE,
+                          GimpViewable)
 
 
-typedef struct _GimpResourceClass GimpResourceClass;
-
-struct _GimpResource
-{
-  GimpViewable parent_instance;
-};
-
 struct _GimpResourceClass
 {
   GimpViewableClass parent_class;
@@ -44,6 +34,3 @@ struct _GimpResourceClass
 
 
 GType   gimp_resource_get_type (void) G_GNUC_CONST;
-
-
-#endif /* __GIMP_RESOURCE_H__ */
