@@ -1,9 +1,9 @@
 /* GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995-1999 Spencer Kimball and Peter Mattis
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,15 +12,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
 #include <string.h>
 
-#include <glib-object.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gegl.h>
 
 #include <cairo.h>
 
@@ -29,9 +29,8 @@
 
 #include "core-types.h"
 
-#include "base/pixel-region.h"
-#include "base/tile-manager.h"
-
+#include "gimpboundary.h"
+#include "gimpbezierdesc.h"
 #include "gimpscanconvert.h"
 
 
@@ -54,13 +53,9 @@ struct _GimpScanConvert
   gdouble         dash_offset;
   GArray         *dash_info;
 
-  guint           num_nodes;
   GArray         *path_data;
 };
 
-/* private functions */
-static gint   gimp_cairo_stride_for_width        (gint             width);
-
 
 /*  public functions  */
 
@@ -69,7 +64,7 @@ static gint   gimp_cairo_stride_for_width        (gint             width);
  *
  * Create a new scan conversion context.
  *
- * Return value: a newly allocated #GimpScanConvert context.
+ * Returns: a newly allocated #GimpScanConvert context.
  */
 GimpScanConvert *
 gimp_scan_convert_new (void)
@@ -82,6 +77,51 @@ gimp_scan_convert_new (void)
   return sc;
 }
 
+GimpScanConvert *
+gimp_scan_convert_new_from_boundary (const GimpBoundSeg *bound_segs,
+                                     gint                n_bound_segs,
+                                     gint                offset_x,
+                                     gint                offset_y)
+{
+  g_return_val_if_fail (bound_segs == NULL || n_bound_segs != 0, NULL);
+
+  if (bound_segs)
+    {
+      GimpBoundSeg *stroke_segs;
+      gint          n_stroke_segs;
+
+      stroke_segs = gimp_boundary_sort (bound_segs, n_bound_segs,
+                                        &n_stroke_segs);
+
+      if (stroke_segs)
+        {
+          GimpBezierDesc *bezier;
+
+          bezier = gimp_bezier_desc_new_from_bound_segs (stroke_segs,
+                                                         n_bound_segs,
+                                                         n_stroke_segs);
+
+          g_free (stroke_segs);
+
+          if (bezier)
+            {
+              GimpScanConvert *scan_convert;
+
+              scan_convert = gimp_scan_convert_new ();
+
+              gimp_bezier_desc_translate (bezier, offset_x, offset_y);
+              gimp_scan_convert_add_bezier (scan_convert, bezier);
+
+              gimp_bezier_desc_free (bezier);
+
+              return scan_convert;
+            }
+        }
+    }
+
+  return NULL;
+}
+
 /**
  * gimp_scan_convert_free:
  * @sc: a #GimpScanConvert context
@@ -186,7 +226,6 @@ gimp_scan_convert_add_polyline (GimpScanConvert   *sc,
           pd.point.x = points[i].x;
           pd.point.y = points[i].y;
           sc->path_data = g_array_append_val (sc->path_data, pd);
-          sc->num_nodes++;
           prev = points[i];
         }
     }
@@ -200,6 +239,26 @@ gimp_scan_convert_add_polyline (GimpScanConvert   *sc,
     }
 }
 
+/**
+ * gimp_scan_convert_add_polyline:
+ * @sc:     a #GimpScanConvert context
+ * @bezier: a #GimpBezierDesc
+ *
+ * Adds a @bezier path to @sc.
+ *
+ * Please note that you should use gimp_scan_convert_stroke() if you
+ * specify open paths.
+ **/
+void
+gimp_scan_convert_add_bezier (GimpScanConvert       *sc,
+                              const GimpBezierDesc  *bezier)
+{
+  g_return_if_fail (sc != NULL);
+  g_return_if_fail (bezier != NULL);
+
+  sc->path_data = g_array_append_vals (sc->path_data,
+                                       bezier->data, bezier->num_data);
+}
 
 /**
  * gimp_scan_convert_stroke:
@@ -211,7 +270,7 @@ gimp_scan_convert_add_polyline (GimpScanConvert   *sc,
  *               extend to a distance of more than @miter times @width from
  *               the actual join point
  * @dash_offset: offset to apply on the dash pattern
- * @dash_info:   dash pattern or %NULL for a solid line
+ * @dash_info: (nullable): dash pattern or %NULL for a solid line
  *
  * Stroke the content of a GimpScanConvert. The next
  * gimp_scan_convert_render() will result in the outline of the
@@ -234,10 +293,11 @@ gimp_scan_convert_stroke (GimpScanConvert *sc,
                           GArray          *dash_info)
 {
   sc->do_stroke = TRUE;
-  sc->width = width;
-  sc->join  = join;
-  sc->cap   = cap;
-  sc->miter = miter;
+  sc->width     = width;
+  sc->join      = join;
+  sc->cap       = cap;
+  sc->miter     = miter;
+
   if (sc->dash_info)
     {
       g_array_free (sc->dash_info, TRUE);
@@ -301,7 +361,8 @@ gimp_scan_convert_stroke (GimpScanConvert *sc,
 
       if (n_dashes >= 2)
         {
-          sc->dash_info = g_array_sized_new (FALSE, FALSE, sizeof (gdouble), n_dashes);
+          sc->dash_info = g_array_sized_new (FALSE, FALSE,
+                                             sizeof (gdouble), n_dashes);
           sc->dash_info = g_array_append_vals (sc->dash_info, dashes, n_dashes);
           sc->dash_offset = dash_offset;
         }
@@ -313,224 +374,247 @@ gimp_scan_convert_stroke (GimpScanConvert *sc,
 
 /**
  * gimp_scan_convert_render:
- * @sc:           a #GimpScanConvert context
- * @tile_manager: the #TileManager to render to
- * @off_x:        horizontal offset into the @tile_manager
- * @off_y:        vertical offset into the @tile_manager
- * @antialias:    whether to apply antialiasiing
+ * @sc:        a #GimpScanConvert context
+ * @buffer:    the #GeglBuffer to render to
+ * @off_x:     horizontal offset into the @buffer
+ * @off_y:     vertical offset into the @buffer
+ * @antialias: whether to apply antialiasiing
  *
  * This is a wrapper around gimp_scan_convert_render_full() that replaces the
- * content of the @tile_manager with a rendered form of the path passed in.
+ * content of the @buffer with a rendered form of the path passed in.
  *
  * You cannot add additional polygons after this command.
  */
 void
 gimp_scan_convert_render (GimpScanConvert *sc,
-                          TileManager     *tile_manager,
+                          GeglBuffer      *buffer,
                           gint             off_x,
                           gint             off_y,
                           gboolean         antialias)
 {
-  gimp_scan_convert_render_full (sc, tile_manager, off_x, off_y,
-                                 TRUE, antialias, 255);
+  gimp_scan_convert_render_full (sc, buffer, off_x, off_y,
+                                 TRUE, antialias, 1.0);
 }
 
 /**
  * gimp_scan_convert_render_value:
- * @sc:           a #GimpScanConvert context
- * @tile_manager: the #TileManager to render to
- * @off_x:        horizontal offset into the @tile_manager
- * @off_y:        vertical offset into the @tile_manager
- * @value:        value to use for covered pixels
+ * @sc:     a #GimpScanConvert context
+ * @buffer: the #GeglBuffer to render to
+ * @off_x:  horizontal offset into the @buffer
+ * @off_y:  vertical offset into the @buffer
+ * @value:  value to use for covered pixels
  *
- * This is a wrapper around gimp_scan_convert_render_full() that doesn't do
- * antialiasing but gives control over the value that should be used for pixels
- * covered by the scan conversion. Uncovered pixels are set to zero.
+ * This is a wrapper around gimp_scan_convert_render_full() that
+ * doesn't do antialiasing but gives control over the value that
+ * should be used for pixels covered by the scan conversion. Uncovered
+ * pixels are set to zero.
  *
  * You cannot add additional polygons after this command.
  */
 void
 gimp_scan_convert_render_value (GimpScanConvert *sc,
-                                TileManager     *tile_manager,
+                                GeglBuffer      *buffer,
                                 gint             off_x,
                                 gint             off_y,
-                                guchar           value)
+                                gdouble          value)
 {
-  gimp_scan_convert_render_full (sc, tile_manager, off_x, off_y,
+  gimp_scan_convert_render_full (sc, buffer, off_x, off_y,
                                  TRUE, FALSE, value);
 }
 
 /**
  * gimp_scan_convert_compose:
- * @sc:           a #GimpScanConvert context
- * @tile_manager: the #TileManager to render to
- * @off_x:        horizontal offset into the @tile_manager
- * @off_y:        vertical offset into the @tile_manager
+ * @sc:     a #GimpScanConvert context
+ * @buffer: the #GeglBuffer to render to
+ * @off_x:  horizontal offset into the @buffer
+ * @off_y:  vertical offset into the @buffer
  *
  * This is a wrapper around of gimp_scan_convert_render_full() that composes
- * the (aliased) scan conversion on top of the content of the @tile_manager.
+ * the (aliased) scan conversion on top of the content of the @buffer.
  *
  * You cannot add additional polygons after this command.
  */
 void
 gimp_scan_convert_compose (GimpScanConvert *sc,
-                           TileManager     *tile_manager,
+                           GeglBuffer      *buffer,
                            gint             off_x,
                            gint             off_y)
 {
-  gimp_scan_convert_render_full (sc, tile_manager, off_x, off_y,
-                                 FALSE, FALSE, 255);
+  gimp_scan_convert_render_full (sc, buffer, off_x, off_y,
+                                 FALSE, FALSE, 1.0);
 }
 
 /**
  * gimp_scan_convert_compose_value:
- * @sc:           a #GimpScanConvert context
- * @tile_manager: the #TileManager to render to
- * @off_x:        horizontal offset into the @tile_manager
- * @off_y:        vertical offset into the @tile_manager
- * @value:        value to use for covered pixels
+ * @sc:     a #GimpScanConvert context
+ * @buffer: the #GeglBuffer to render to
+ * @off_x:  horizontal offset into the @buffer
+ * @off_y:  vertical offset into the @buffer
+ * @value:  value to use for covered pixels
  *
  * This is a wrapper around gimp_scan_convert_render_full() that
  * composes the (aliased) scan conversion with value @value on top of the
- * content of the @tile_manager.
+ * content of the @buffer.
  *
  * You cannot add additional polygons after this command.
  */
 void
 gimp_scan_convert_compose_value (GimpScanConvert *sc,
-                                 TileManager     *tile_manager,
+                                 GeglBuffer      *buffer,
                                  gint             off_x,
                                  gint             off_y,
-                                 gint             value)
+                                 gdouble          value)
 {
-  gimp_scan_convert_render_full (sc, tile_manager, off_x, off_y,
+  gimp_scan_convert_render_full (sc, buffer, off_x, off_y,
                                  FALSE, FALSE, value);
 }
 
 /**
  * gimp_scan_convert_render_full:
- * @sc:           a #GimpScanConvert context
- * @tile_manager: the #TileManager to render to
- * @off_x:        horizontal offset into the @tile_manager
- * @off_y:        vertical offset into the @tile_manager
- * @replace:      if true the original content of the @tile_manager gets destroyed
- * @antialias:    if true the rendering happens antialiased
- * @value:        value to use for covered pixels
+ * @sc:        a #GimpScanConvert context
+ * @buffer:    the #GeglBuffer to render to
+ * @off_x:     horizontal offset into the @buffer
+ * @off_y:     vertical offset into the @buffer
+ * @replace:   if true the original content of the @buffer gets estroyed
+ * @antialias: if true the rendering happens antialiased
+ * @value:     value to use for covered pixels
  *
- * This function renders the area described by the path to the @tile_manager,
- * taking the offset @off_x and @off_y in the tilemanager into account.
- * The rendering can happen antialiased and be rendered on top of existing
- * content or replacing it completely. The @value specifies the opacity value
- * to be used for the objects in the @sc.
- *
- * This function expects a tile manager of depth 1.
+ * This function renders the area described by the path to the
+ * @buffer, taking the offset @off_x and @off_y in the buffer into
+ * account.  The rendering can happen antialiased and be rendered on
+ * top of existing content or replacing it completely. The @value
+ * specifies the opacity value to be used for the objects in the @sc.
  *
  * You cannot add additional polygons after this command.
  */
 void
 gimp_scan_convert_render_full (GimpScanConvert *sc,
-                               TileManager     *tile_manager,
+                               GeglBuffer      *buffer,
                                gint             off_x,
                                gint             off_y,
                                gboolean         replace,
                                gboolean         antialias,
-                               guchar           value)
+                               gdouble          value)
 {
-  PixelRegion      maskPR;
-  gpointer         pr;
-  gint             x, y;
-  gint             width, height;
-
-  cairo_t         *cr;
-  cairo_surface_t *surface;
-  cairo_path_t     path;
+  const Babl         *format;
+  guchar             *shared_buf      = NULL;
+  gsize               shared_buf_size = 0;
+  GeglBufferIterator *iter;
+  GeglRectangle      *roi;
+  cairo_t            *cr;
+  cairo_surface_t    *surface;
+  cairo_path_t        path;
+  gint                bpp;
+  gint                x, y;
+  gint                width, height;
 
   g_return_if_fail (sc != NULL);
-  g_return_if_fail (tile_manager != NULL);
+  g_return_if_fail (GEGL_IS_BUFFER (buffer));
 
-  x = 0;
-  y = 0;
-  width  = tile_manager_width (tile_manager);
-  height = tile_manager_height (tile_manager);
+  x      = gegl_buffer_get_x      (buffer);
+  y      = gegl_buffer_get_y      (buffer);
+  width  = gegl_buffer_get_width  (buffer);
+  height = gegl_buffer_get_height (buffer);
 
-  if (sc->clip &&
-      ! gimp_rectangle_intersect (x, y, width, height,
-                                  sc->clip_x, sc->clip_y,
-                                  sc->clip_w, sc->clip_h,
-                                  &x, &y, &width, &height))
+  if (sc->clip && ! gimp_rectangle_intersect (x, y, width, height,
+                                              sc->clip_x, sc->clip_y,
+                                              sc->clip_w, sc->clip_h,
+                                              &x, &y, &width, &height))
     return;
 
-  pixel_region_init (&maskPR, tile_manager, x, y, width, height, TRUE);
-
-  g_return_if_fail (maskPR.bytes == 1);
-
   path.status   = CAIRO_STATUS_SUCCESS;
   path.data     = (cairo_path_data_t *) sc->path_data->data;
   path.num_data = sc->path_data->len;
 
-  for (pr = pixel_regions_register (1, &maskPR);
-       pr != NULL;
-       pr = pixel_regions_process (pr))
+  format = babl_format ("Y u8");
+  bpp    = babl_format_get_bytes_per_pixel (format);
+
+  iter = gegl_buffer_iterator_new (buffer, NULL, 0, format,
+                                   GEGL_ACCESS_READWRITE, GEGL_ABYSS_NONE, 1);
+  roi = &iter->items[0].roi;
+
+  while (gegl_buffer_iterator_next (iter))
     {
-      guchar *tmp_buf = NULL;
-      gint    stride;
+      guchar     *data    = iter->items[0].data;
+      guchar     *tmp_buf = NULL;
+      const gint  stride  = cairo_format_stride_for_width (CAIRO_FORMAT_A8,
+                                                           roi->width);
 
-      stride = gimp_cairo_stride_for_width (maskPR.w);
-
-      g_assert (stride > 0);
-
-      if (maskPR.rowstride != stride)
+      /*  cairo rowstrides are always multiples of 4, whereas
+       *  maskPR.rowstride can be anything, so to be able to create an
+       *  image surface, we maybe have to create our own temporary
+       *  buffer
+       */
+      if (roi->width * bpp != stride)
         {
-          const guchar *src = maskPR.data;
-          guchar       *dest;
-          gint          i;
-
-          dest = tmp_buf = g_alloca (stride * maskPR.h);
-
-          if (!replace)
+          if (shared_buf_size < stride * roi->height)
             {
-              for (i = 0; i < maskPR.h; i++)
-                {
-                  memcpy (dest, src, maskPR.w);
+              shared_buf_size = stride * roi->height;
+              g_free (shared_buf);
+              shared_buf = g_malloc (shared_buf_size);
+            }
+          tmp_buf = shared_buf;
 
-                  src  += maskPR.rowstride;
+          if (! replace)
+            {
+              const guchar *src  = data;
+              guchar       *dest = tmp_buf;
+              gint          i;
+
+              for (i = 0; i < roi->height; i++)
+                {
+                  memcpy (dest, src, roi->width * bpp);
+
+                  src  += roi->width * bpp;
                   dest += stride;
                 }
             }
         }
 
       surface = cairo_image_surface_create_for_data (tmp_buf ?
-                                                     tmp_buf : maskPR.data,
+                                                     tmp_buf : data,
                                                      CAIRO_FORMAT_A8,
-                                                     maskPR.w, maskPR.h,
+                                                     roi->width, roi->height,
                                                      stride);
 
       cairo_surface_set_device_offset (surface,
-                                       -off_x - maskPR.x,
-                                       -off_y - maskPR.y);
+                                       -off_x - roi->x,
+                                       -off_y - roi->y);
       cr = cairo_create (surface);
       cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+
       if (replace)
         {
           cairo_set_source_rgba (cr, 0, 0, 0, 0);
           cairo_paint (cr);
         }
-      cairo_set_source_rgba (cr, 0, 0, 0, value / 255.0);
+
+      cairo_set_source_rgba (cr, 0, 0, 0, value);
       cairo_append_path (cr, &path);
-      cairo_set_antialias (cr, antialias ? CAIRO_ANTIALIAS_GRAY : CAIRO_ANTIALIAS_NONE);
+
+      cairo_set_antialias (cr, antialias ?
+                           CAIRO_ANTIALIAS_GRAY : CAIRO_ANTIALIAS_NONE);
       cairo_set_miter_limit (cr, sc->miter);
+
       if (sc->do_stroke)
         {
-          cairo_set_line_cap (cr, sc->cap == GIMP_CAP_BUTT ? CAIRO_LINE_CAP_BUTT :
-                                  sc->cap == GIMP_CAP_ROUND ? CAIRO_LINE_CAP_ROUND :
-                                  CAIRO_LINE_CAP_SQUARE);
-          cairo_set_line_join (cr, sc->join == GIMP_JOIN_MITER ? CAIRO_LINE_JOIN_MITER :
-                                   sc->join == GIMP_JOIN_ROUND ? CAIRO_LINE_JOIN_ROUND :
-                                   CAIRO_LINE_JOIN_BEVEL);
+          cairo_set_line_cap (cr,
+                              sc->cap == GIMP_CAP_BUTT ? CAIRO_LINE_CAP_BUTT :
+                              sc->cap == GIMP_CAP_ROUND ? CAIRO_LINE_CAP_ROUND :
+                              CAIRO_LINE_CAP_SQUARE);
+          cairo_set_line_join (cr,
+                               sc->join == GIMP_JOIN_MITER ? CAIRO_LINE_JOIN_MITER :
+                               sc->join == GIMP_JOIN_ROUND ? CAIRO_LINE_JOIN_ROUND :
+                               CAIRO_LINE_JOIN_BEVEL);
 
           cairo_set_line_width (cr, sc->width);
+
           if (sc->dash_info)
-            cairo_set_dash (cr, (double *) sc->dash_info->data, sc->dash_info->len, sc->dash_offset);
+            cairo_set_dash (cr,
+                            (double *) sc->dash_info->data,
+                            sc->dash_info->len,
+                            sc->dash_offset);
+
           cairo_scale (cr, 1.0, sc->ratio_xy);
           cairo_stroke (cr);
         }
@@ -545,35 +629,19 @@ gimp_scan_convert_render_full (GimpScanConvert *sc,
 
       if (tmp_buf)
         {
-          guchar       *dest = maskPR.data;
           const guchar *src  = tmp_buf;
+          guchar       *dest = data;
           gint          i;
 
-          for (i = 0; i < maskPR.h; i++)
+          for (i = 0; i < roi->height; i++)
             {
-              memcpy (dest, src, maskPR.w);
+              memcpy (dest, src, roi->width * bpp);
 
               src  += stride;
-              dest += maskPR.rowstride;
+              dest += roi->width * bpp;
             }
         }
     }
+
+  g_free (shared_buf);
 }
-
-static gint
-gimp_cairo_stride_for_width (gint width)
-{
-#ifdef __GNUC__
-#warning use cairo_format_stride_for_width() as soon as we depend on cairo 1.6
-#endif
-#if 0
-  return cairo_format_stride_for_width (CAIRO_FORMAT_A8, width);
-#endif
-
-#define CAIRO_STRIDE_ALIGNMENT (sizeof (guint32))
-#define CAIRO_STRIDE_FOR_WIDTH_BPP(w,bpp) \
-   (((bpp)*(w)+7)/8 + CAIRO_STRIDE_ALIGNMENT-1) & ~(CAIRO_STRIDE_ALIGNMENT-1)
-
-  return CAIRO_STRIDE_FOR_WIDTH_BPP (width, 8);
-}
-
