@@ -15,9 +15,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __DIALOGS_TYPES_H__
-#define __DIALOGS_TYPES_H__
-
+#pragma once
 
 #include "display/display-types.h"
 
@@ -32,6 +30,3 @@ typedef void (* GimpScaleCallback) (GtkWidget             *dialog,
                                     gdouble                yresolution,
                                     GimpUnit              *resolution_unit,
                                     gpointer               user_data);
-
-
-#endif /* __DIALOGS_TYPES_H__ */
