@@ -3,9 +3,9 @@
  *
  * Copyright (C) 2003  Henrik Brix Andersen <brix@gimp.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,17 +14,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GRID_DIALOG_H__
-#define __GRID_DIALOG_H__
+#pragma once
 
 
 GtkWidget * grid_dialog_new (GimpImage   *image,
                              GimpContext *context,
                              GtkWidget   *parent);
-
-
-#endif  /*  __GRID_DIALOG_H__  */
