@@ -32,12 +32,15 @@
 #include "core/gimpdrawable-filters.h"
 #include "core/gimpimage.h"
 #include "core/gimplayer.h"
+#include "core/gimplink.h"
+#include "core/gimplinklayer.h"
 
 #include "text/gimptext.h"
 #include "text/gimptextlayer.h"
 
 #include "widgets/gimpcontainerlistview.h"
 #include "widgets/gimplayermodebox.h"
+#include "widgets/gimpopendialog.h"
 #include "widgets/gimpviewabledialog.h"
 
 #include "item-options-dialog.h"
@@ -50,6 +53,7 @@ typedef struct _LayerOptionsDialog LayerOptionsDialog;
 
 struct _LayerOptionsDialog
 {
+  Gimp                     *gimp;
   GimpLayer                *layer;
   GimpLayerMode             mode;
   GimpLayerColorSpace       blend_space;
@@ -68,6 +72,8 @@ struct _LayerOptionsDialog
   GtkWidget                *composite_mode_combo;
   GtkWidget                *size_se;
   GtkWidget                *offset_se;
+
+  GimpLink                 *link;
 };
 
 
@@ -93,6 +99,9 @@ static void   layer_options_dialog_mode_notify    (GtkWidget          *widget,
 static void   layer_options_dialog_rename_toggled (GtkWidget          *widget,
                                                    LayerOptionsDialog *private);
 
+static void   layer_options_file_set              (GtkFileChooserButton *widget,
+                                                   LayerOptionsDialog   *private);
+
 
 /*  public functions  */
 
@@ -127,6 +136,7 @@ layer_options_dialog_new (GimpImage                *image,
   GtkWidget            *grid;
   GtkListStore         *space_model;
   GtkWidget            *combo;
+  GtkWidget            *file_select;
   GtkWidget            *scale;
   GtkWidget            *label;
   GtkAdjustment        *adjustment;
@@ -144,6 +154,7 @@ layer_options_dialog_new (GimpImage                *image,
 
   private = g_slice_new0 (LayerOptionsDialog);
 
+  private->gimp               = image->gimp;
   private->layer              = layer;
   private->mode               = layer_mode;
   private->blend_space        = layer_blend_space;
@@ -156,6 +167,8 @@ layer_options_dialog_new (GimpImage                *image,
   private->callback           = callback;
   private->user_data          = user_data;
 
+  private->link               = NULL;
+
   if (layer && gimp_item_is_text_layer (GIMP_ITEM (layer)))
     private->rename_text_layers = GIMP_TEXT_LAYER (layer)->auto_rename;
 
@@ -372,19 +385,6 @@ layer_options_dialog_new (GimpImage                *image,
 
   row += 2;
 
-  if (! layer)
-    {
-      /*  The fill type  */
-      combo = gimp_enum_combo_box_new (GIMP_TYPE_FILL_TYPE);
-      gimp_grid_attach_aligned (GTK_GRID (grid), 0, row++,
-                                _("_Fill with:"), 0.0, 0.5,
-                                combo, 1);
-      gimp_int_combo_box_connect (GIMP_INT_COMBO_BOX (combo),
-                                  private->fill_type,
-                                  G_CALLBACK (gimp_int_combo_box_get_active),
-                                  &private->fill_type, NULL);
-    }
-
   if (layer)
     {
       GtkWidget     *left_vbox = item_options_dialog_get_vbox (dialog);
@@ -402,6 +402,57 @@ layer_options_dialog_new (GimpImage                *image,
                                            GIMP_VIEW_SIZE_SMALL, 0);
       gtk_container_add (GTK_CONTAINER (frame), view);
       gtk_widget_show (view);
+
+      if (GIMP_IS_LINK_LAYER (layer))
+        {
+          GtkWidget *open_dialog;
+          GimpLink  *link;
+
+          /* File chooser dialog. */
+          open_dialog = gimp_open_dialog_new (private->gimp);
+          gtk_window_set_title (GTK_WINDOW (open_dialog),
+                                _("Select Linked Image"));
+
+          /* File chooser button. */
+          file_select = gtk_file_chooser_button_new_with_dialog (open_dialog);
+          link = gimp_link_layer_get_link (GIMP_LINK_LAYER (layer));
+          gtk_file_chooser_set_file (GTK_FILE_CHOOSER (file_select),
+                                     gimp_link_get_file (link, NULL, NULL),
+                                     NULL);
+          gtk_widget_show (file_select);
+          gimp_grid_attach_aligned (GTK_GRID (grid), 0, row++,
+                                    _("_Linked image:"), 0.0, 0.5,
+                                    file_select, 1);
+
+          g_signal_connect (file_select, "file-set",
+                            G_CALLBACK (layer_options_file_set),
+                            private);
+
+          private->link = gimp_link_duplicate (link);
+
+          /* Absolute path checkbox. */
+          button = gtk_check_button_new_with_mnemonic (_("S_tore with absolute path"));
+          gimp_grid_attach_aligned (GTK_GRID (grid), 0, row++,
+                                    NULL, 0.0, 0.5,
+                                    button, 2);
+          g_object_bind_property (G_OBJECT (private->link), "absolute-path",
+                                  G_OBJECT (button),        "active",
+                                  G_BINDING_SYNC_CREATE |
+                                  G_BINDING_BIDIRECTIONAL);
+          gtk_widget_set_visible (button, TRUE);
+        }
+    }
+  else
+    {
+      /*  The fill type  */
+      combo = gimp_enum_combo_box_new (GIMP_TYPE_FILL_TYPE);
+      gimp_grid_attach_aligned (GTK_GRID (grid), 0, row,
+                                _("_Fill with:"), 0.0, 0.5,
+                                combo, 1);
+      gimp_int_combo_box_connect (GIMP_INT_COMBO_BOX (combo),
+                                  private->fill_type,
+                                  G_CALLBACK (gimp_int_combo_box_get_active),
+                                  &private->fill_type, NULL);
     }
 
   button = item_options_dialog_get_lock_position (dialog);
@@ -502,6 +553,7 @@ layer_options_dialog_callback (GtkWidget    *dialog,
                      private->composite_mode,
                      private->opacity / 100.0,
                      private->fill_type,
+                     private->link,
                      width,
                      height,
                      offset_x,
@@ -574,3 +626,45 @@ layer_options_dialog_rename_toggled (GtkWidget          *widget,
         }
     }
 }
+
+static void
+layer_options_file_set (GtkFileChooserButton *widget,
+                        LayerOptionsDialog   *private)
+{
+  GFile *file;
+
+  file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (widget));
+  if (file)
+    {
+      gint width  = 0;
+      gint height = 0;
+
+      if (private->layer)
+        {
+          width  = gimp_item_get_width (GIMP_ITEM (private->layer));
+          height = gimp_item_get_height (GIMP_ITEM (private->layer));
+
+          if (width == 0 || height == 0)
+            {
+              GimpImage *image = gimp_item_get_image (GIMP_ITEM (private->layer));
+
+              width  = gimp_image_get_width (image);
+              height = gimp_image_get_height (image);
+            }
+        }
+
+      gimp_link_set_file (private->link, file, width, height, TRUE, NULL, NULL);
+      if (gimp_link_is_broken (private->link))
+        {
+          gimp_link_set_file (private->link, NULL, width, height, TRUE, NULL, NULL);
+          g_signal_handlers_block_by_func (widget,
+                                           G_CALLBACK (layer_options_file_set),
+                                           private);
+          gtk_file_chooser_unselect_file (GTK_FILE_CHOOSER (widget), file);
+          g_signal_handlers_unblock_by_func (widget,
+                                             G_CALLBACK (layer_options_file_set),
+                                             private);
+        }
+    }
+  g_clear_object (&file);
+}
