@@ -47,12 +47,12 @@
 
 #include "file/file-open.h"
 
+#include "path/gimppath.h"
+#include "path/gimppath-import.h"
+
 #include "text/gimptext.h"
 #include "text/gimptextlayer.h"
 
-#include "vectors/gimppath.h"
-#include "vectors/gimppath-import.h"
-
 #include "widgets/gimpdnd.h"
 
 #include "gimpdisplay.h"
@@ -258,6 +258,7 @@ gimp_display_shell_drop_drawable (GtkWidget    *widget,
 
       gimp_image_add_layer (image, new_layer,
                             GIMP_IMAGE_ACTIVE_PARENT, -1, TRUE);
+      gimp_drawable_enable_resize_undo (GIMP_DRAWABLE (new_layer));
 
       gimp_image_undo_group_end (image);
 
@@ -570,7 +571,7 @@ gimp_display_shell_drop_uri_list (GtkWidget *widget,
 
           new_layers = file_open_layers (shell->display->gimp, context,
                                          GIMP_PROGRESS (shell->display),
-                                         image, FALSE,
+                                         image, FALSE, FALSE,
                                          file, GIMP_RUN_INTERACTIVE, NULL,
                                          &status, &error);
 
