@@ -15,12 +15,8 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_DISPLAY_SHELL_HANDLERS_H__
-#define __GIMP_DISPLAY_SHELL_HANDLERS_H__
+#pragma once
 
 
 void   gimp_display_shell_connect    (GimpDisplayShell *shell);
 void   gimp_display_shell_disconnect (GimpDisplayShell *shell);
-
-
-#endif /*  __GIMP_DISPLAY_SHELL_HANDLERS_H__  */
