@@ -258,13 +258,8 @@ gimp_display_shell_events (GtkWidget        *widget,
       {
         GdkEventFocus *fevent = (GdkEventFocus *) event;
 
-        if (fevent->in)
-          {
-            gimp_set_focused_once (gimp);
-
-            if (shell->display->config->activate_on_focus)
-              set_display = TRUE;
-          }
+        if (fevent->in && shell->display->config->activate_on_focus)
+          set_display = TRUE;
       }
       break;
 
@@ -1057,7 +1052,7 @@ gimp_display_shell_canvas_tool_events (GtkWidget        *canvas,
 
             if (gimp_display_shell_key_to_state (kevent->keyval) == GDK_MOD1_MASK)
               /* Make sure the picked layer is reset. */
-              g_clear_weak_pointer (&shell->picked_layer);
+              shell->picked_layer = NULL;
 
             switch (kevent->keyval)
               {
@@ -1156,7 +1151,7 @@ gimp_display_shell_canvas_tool_events (GtkWidget        *canvas,
             statusbar = gimp_display_shell_get_statusbar (shell);
             gimp_statusbar_pop_temp (statusbar);
 
-            g_clear_weak_pointer (&shell->picked_layer);
+            shell->picked_layer = NULL;
             shell->mod_action = GIMP_MODIFIER_ACTION_NONE;
           }
         else if (shell->mod_action != GIMP_MODIFIER_ACTION_NONE &&
@@ -1772,7 +1767,7 @@ gimp_display_shell_start_scrolling (GimpDisplayShell *shell,
                                             _("Layer picked: '%s'"),
                                             gimp_object_get_name (layer));
                 }
-              g_set_weak_pointer (&shell->picked_layer, layer);
+              shell->picked_layer = layer;
             }
         }
       break;
