@@ -34,11 +34,9 @@
 
 #include "core/gimpcontext.h"
 
-#include "menus/menus.h"
-
-#include "vectors/gimpanchor.h"
-#include "vectors/gimpbezierstroke.h"
-#include "vectors/gimppath.h"
+#include "path/gimpanchor.h"
+#include "path/gimpbezierstroke.h"
+#include "path/gimppath.h"
 
 #include "widgets/gimpdialogfactory.h"
 #include "widgets/gimpdockcontainer.h"
@@ -48,6 +46,8 @@
 
 #include "tools/gimptools-utils.h"
 
+#include "menus/menus.h"
+
 #include "gimpcanvashandle.h"
 #include "gimpcanvasitem-utils.h"
 #include "gimpcanvasline.h"
@@ -667,7 +667,7 @@ gimp_tool_path_button_press (GimpToolWidget      *widget,
       private->cur_anchor = gimp_bezier_stroke_extend (private->sel_stroke,
                                                        &position,
                                                        private->sel_anchor,
-                                                       EXTEND_EDITABLE);
+                                                       GIMP_STROKE_EXTEND_EDITABLE);
 
       private->restriction = GIMP_ANCHOR_FEATURE_SYMMETRIC;
 
@@ -1195,7 +1195,7 @@ gimp_tool_path_key_press (GimpToolWidget *widget,
     case GDK_KEY_Escape:
       if (private->edit_mode != GIMP_PATH_MODE_DESIGN)
         g_object_set (private,
-                      "vectors-edit-mode", GIMP_PATH_MODE_DESIGN,
+                      "path-edit-mode", GIMP_PATH_MODE_DESIGN,
                       NULL);
       break;
 
@@ -1309,7 +1309,7 @@ gimp_tool_path_get_popup (GimpToolWidget    *widget,
 
   menu_factory   = menus_get_global_menu_factory (gimp_dialog_factory_get_context (dialog_factory)->gimp);
   ui_manager     = gimp_menu_factory_get_manager (menu_factory,
-                                                  "<VectorToolPath>", widget);
+                                                  "<ToolPath>", widget);
 
   /* we're using a side effects of gimp_tool_path_get_function
    * that update the private->cur_* variables. */
@@ -1319,7 +1319,7 @@ gimp_tool_path_get_popup (GimpToolWidget    *widget,
     {
       gimp_ui_manager_update (ui_manager, widget);
 
-      *ui_path = "/vector-toolpath-popup";
+      *ui_path = "/tool-path-popup";
       return ui_manager;
     }
 
