@@ -32,13 +32,13 @@
 #include "core/gimp.h"
 #include "core/gimpcontext.h"
 #include "core/gimpdocumentlist.h"
-#include "core/gimpdrawable-filters.h"
-#include "core/gimpdrawablefilter.h"
 #include "core/gimpimage.h"
 #include "core/gimpimage-merge.h"
 #include "core/gimpimage-undo.h"
 #include "core/gimpimagefile.h"
 #include "core/gimplayer.h"
+#include "core/gimplink.h"
+#include "core/gimplinklayer.h"
 #include "core/gimpparamspecs.h"
 #include "core/gimpprogress.h"
 
@@ -55,15 +55,32 @@
 #include "gimp-intl.h"
 
 
-static void     file_open_sanitize_image       (GimpImage           *image,
-                                                gboolean             as_new);
-static void     file_open_convert_items        (GimpImage           *dest_image,
-                                                const gchar         *basename,
-                                                GList               *items);
-static GList *  file_open_get_layers           (GimpImage           *image,
-                                                gboolean             merge_visible,
-                                                gint                *n_visible);
-static gboolean file_open_file_proc_is_import  (GimpPlugInProcedure *file_proc);
+static GimpImage * file_open_link_image           (Gimp                *gimp,
+                                                   GimpContext         *context,
+                                                   GimpProgress        *progress,
+                                                   GFile               *file,
+                                                   gint                 vector_width,
+                                                   gint                 vector_height,
+                                                   gboolean             vector_keep_ratio,
+                                                   gboolean             as_new,
+                                                   GimpPlugInProcedure *file_proc,
+                                                   GimpRunMode          run_mode,
+                                                   gboolean            *file_proc_handles_vector,
+                                                   GimpPDBStatusType   *status,
+                                                   const gchar        **mime_type,
+                                                   GError             **error);
+
+static void        file_open_sanitize_image       (GimpImage           *image,
+                                                   gboolean             as_new);
+static void        file_open_convert_items        (GimpImage           *dest_image,
+                                                   const gchar         *basename,
+                                                   GList               *items);
+static GList     * file_open_get_layers           (GimpImage           *image,
+                                                   gboolean             merge_visible,
+                                                   gint                *n_visible);
+static gboolean    file_open_file_proc_is_import  (GimpPlugInProcedure *file_proc);
+static gboolean    file_open_valid_permissions    (GFile               *file,
+                                                   GError             **error);
 
 
 /*  public functions  */
@@ -75,9 +92,11 @@ file_open_image (Gimp                *gimp,
                  GFile               *file,
                  gint                 vector_width,
                  gint                 vector_height,
+                 gboolean             vector_keep_ratio,
                  gboolean             as_new,
                  GimpPlugInProcedure *file_proc,
                  GimpRunMode          run_mode,
+                 gboolean            *file_proc_handles_vector,
                  GimpPDBStatusType   *status,
                  const gchar        **mime_type,
                  GError             **error)
@@ -120,46 +139,8 @@ file_open_image (Gimp                *gimp,
         }
     }
 
-  /* FIXME enable these tests for remote files again, needs testing */
-  if (g_file_is_native (file))
-    {
-      GFileInfo *info;
-
-      info = g_file_query_info (file,
-                                G_FILE_ATTRIBUTE_STANDARD_TYPE ","
-                                G_FILE_ATTRIBUTE_ACCESS_CAN_READ,
-                                G_FILE_QUERY_INFO_NONE,
-                                NULL, error);
-
-      if (info != NULL)
-        {
-          if (g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_REGULAR)
-            {
-              g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Not a regular file"));
-              g_object_unref (info);
-              return NULL;
-            }
-
-          if (! g_file_info_get_attribute_boolean (info,
-                                                   G_FILE_ATTRIBUTE_ACCESS_CAN_READ))
-            {
-              g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Permission denied"));
-              g_object_unref (info);
-              return NULL;
-            }
-
-          g_object_unref (info);
-        }
-      else
-        {
-          /* File likely does not exists. error will already have a more
-           * accurate reason.
-           */
-          return NULL;
-        }
-    }
+  if (! file_open_valid_permissions (file, error))
+    return NULL;
 
   if (! file_proc)
     file_proc = gimp_plug_in_manager_file_procedure_find (gimp->plug_in_manager,
@@ -212,6 +193,9 @@ file_open_image (Gimp                *gimp,
       return NULL;
     }
 
+  if (file_proc_handles_vector)
+    *file_proc_handles_vector = file_proc->handles_vector;
+
   if (progress)
     g_object_add_weak_pointer (G_OBJECT (progress), (gpointer) &progress);
 
@@ -225,7 +209,7 @@ file_open_image (Gimp                *gimp,
                                             G_TYPE_FILE,        file,
                                             G_TYPE_INT,         vector_width,
                                             G_TYPE_INT,         vector_height,
-                                            G_TYPE_BOOLEAN,     TRUE,
+                                            G_TYPE_BOOLEAN,     vector_keep_ratio,
                                             G_TYPE_BOOLEAN,     vector_width && vector_height ? FALSE : TRUE,
                                             G_TYPE_NONE);
     }
@@ -501,9 +485,8 @@ file_open_with_display (Gimp               *gimp,
                         GError            **error)
 {
   return file_open_with_proc_and_display (gimp, context, progress,
-                                          file, as_new, NULL,
-                                          monitor,
-                                          status, error);
+                                          file, as_new, FALSE, NULL,
+                                          monitor, status, error);
 }
 
 GimpImage *
@@ -512,12 +495,13 @@ file_open_with_proc_and_display (Gimp                *gimp,
                                  GimpProgress        *progress,
                                  GFile               *file,
                                  gboolean             as_new,
+                                 gboolean             as_link,
                                  GimpPlugInProcedure *file_proc,
                                  GObject             *monitor,
                                  GimpPDBStatusType   *status,
                                  GError             **error)
 {
-  GimpImage   *image;
+  GimpImage   *image     = NULL;
   const gchar *mime_type = NULL;
   GimpRunMode  run_mode  = GIMP_RUN_INTERACTIVE;
 
@@ -531,14 +515,26 @@ file_open_with_proc_and_display (Gimp                *gimp,
   if (gimp->no_interface)
     run_mode = GIMP_RUN_NONINTERACTIVE;
 
-  image = file_open_image (gimp, context, progress,
-                           file, 0, 0,
-                           as_new,
-                           file_proc,
-                           run_mode,
-                           status,
-                           &mime_type,
-                           error);
+  if (as_link)
+    image = file_open_link_image (gimp, context, progress,
+                                  file, 0, 0, TRUE,
+                                  as_new,
+                                  file_proc,
+                                  run_mode,
+                                  NULL,
+                                  status,
+                                  &mime_type,
+                                  error);
+  else
+    image = file_open_image (gimp, context, progress,
+                             file, 0, 0, TRUE,
+                             as_new,
+                             file_proc,
+                             run_mode,
+                             NULL,
+                             status,
+                             &mime_type,
+                             error);
 
   if (image)
     {
@@ -557,15 +553,19 @@ file_open_with_proc_and_display (Gimp                *gimp,
           gimp_image_get_n_layers (image) == 1)
         {
           GimpObject *layer = gimp_image_get_layer_iter (image)->data;
-          gchar      *basename;
 
-          basename = g_path_get_basename (gimp_file_get_utf8_name (file));
+          if (! GIMP_IS_LINK_LAYER (layer))
+            {
+              gchar *basename;
 
-          gimp_item_rename (GIMP_ITEM (layer), basename, NULL);
-          gimp_image_undo_free (image);
-          gimp_image_clean_all (image);
+              basename = g_path_get_basename (gimp_file_get_utf8_name (file));
 
-          g_free (basename);
+              gimp_item_rename (GIMP_ITEM (layer), basename, NULL);
+              gimp_image_undo_free (image);
+              gimp_image_clean_all (image);
+
+              g_free (basename);
+            }
         }
 
       if (gimp_create_display (image->gimp, image, gimp_unit_pixel (), 1.0,
@@ -613,6 +613,7 @@ file_open_layers (Gimp                *gimp,
                   GimpProgress        *progress,
                   GimpImage           *dest_image,
                   gboolean             merge_visible,
+                  gboolean             as_link,
                   GFile               *file,
                   GimpRunMode          run_mode,
                   GimpPlugInProcedure *file_proc,
@@ -631,14 +632,26 @@ file_open_layers (Gimp                *gimp,
   g_return_val_if_fail (status != NULL, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-  new_image = file_open_image (gimp, context, progress,
-                               file,
-                               gimp_image_get_width (dest_image),
-                               gimp_image_get_height (dest_image),
-                               FALSE,
-                               file_proc,
-                               run_mode,
-                               status, &mime_type, error);
+  if (as_link)
+    new_image = file_open_link_image (gimp, context, progress,
+                                      file,
+                                      gimp_image_get_width (dest_image),
+                                      gimp_image_get_height (dest_image),
+                                      TRUE,
+                                      FALSE,
+                                      file_proc,
+                                      run_mode,
+                                      NULL, status, &mime_type, error);
+  else
+    new_image = file_open_image (gimp, context, progress,
+                                 file,
+                                 gimp_image_get_width (dest_image),
+                                 gimp_image_get_height (dest_image),
+                                 TRUE,
+                                 FALSE,
+                                 file_proc,
+                                 run_mode,
+                                 NULL, status, &mime_type, error);
 
   if (new_image)
     {
@@ -745,6 +758,89 @@ file_open_from_command_line (Gimp     *gimp,
 
 /*  private functions  */
 
+static GimpImage *
+file_open_link_image (Gimp                *gimp,
+                      GimpContext         *context,
+                      GimpProgress        *progress,
+                      GFile               *file,
+                      gint                 vector_width,
+                      gint                 vector_height,
+                      gboolean             vector_keep_ratio,
+                      gboolean             as_new,
+                      GimpPlugInProcedure *file_proc,
+                      GimpRunMode          run_mode,
+                      gboolean            *file_proc_handles_vector,
+                      GimpPDBStatusType   *status,
+                      const gchar        **mime_type,
+                      GError             **error)
+{
+  GimpImage *image = NULL;
+
+  g_return_val_if_fail (GIMP_IS_GIMP (gimp), NULL);
+  g_return_val_if_fail (GIMP_IS_CONTEXT (context), NULL);
+  g_return_val_if_fail (progress == NULL || GIMP_IS_PROGRESS (progress), NULL);
+  g_return_val_if_fail (G_IS_FILE (file), NULL);
+  g_return_val_if_fail (status != NULL, NULL);
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  if (! file_proc)
+    file_proc = gimp_plug_in_manager_file_procedure_find (gimp->plug_in_manager,
+                                                          GIMP_FILE_PROCEDURE_GROUP_OPEN,
+                                                          file, error);
+
+  if (! file_open_valid_permissions (file, error))
+    return NULL;
+
+  if (g_file_is_native (file) && file_proc != NULL)
+    {
+      GimpLink *link = gimp_link_new (gimp, file,
+                                      vector_width, vector_height, vector_keep_ratio,
+                                      progress, error);
+
+      if (gimp_link_is_broken (link))
+        {
+          *status = GIMP_PDB_EXECUTION_ERROR;
+        }
+      else
+        {
+          GimpLayer *layer;
+          gint       width;
+          gint       height;
+
+          gimp_link_get_size (link, &width, &height);
+          image = gimp_image_new (gimp, width, height,
+                                  gimp_link_get_base_type (link),
+                                  gimp_link_get_precision (link));
+          layer = gimp_link_layer_new (image, link);
+          gimp_image_add_layer (image, layer, NULL, 0, FALSE);
+
+          gimp_image_set_load_proc (image, gimp_link_get_load_proc (link));
+          file_proc = gimp_image_get_load_proc (image);
+          if (mime_type)
+            *mime_type = g_slist_nth_data (file_proc->mime_types_list, 0);
+          if (file_proc_handles_vector)
+            *file_proc_handles_vector = file_proc->handles_vector;
+
+          *status = GIMP_PDB_SUCCESS;
+        }
+
+      g_clear_object (&link);
+    }
+  else if (! g_file_is_native (file))
+    {
+      gchar *uri = g_file_get_uri (file);
+
+      if (error && ! *error)
+        g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                     _("Only platform-native file paths are supported: '%s' cannot be opened as link."),
+                     uri);
+
+      g_free (uri);
+    }
+
+  return image;
+}
+
 static void
 file_open_sanitize_image (GimpImage *image,
                           gboolean   as_new)
@@ -790,45 +886,11 @@ file_open_convert_items (GimpImage   *dest_image,
 
   for (list = items; list; list = g_list_next (list))
     {
-      GimpItem      *src     = list->data;
-      GimpContainer *filters = NULL;
-      GimpItem      *item;
+      GimpItem *src = list->data;
+      GimpItem *item;
 
       item = gimp_item_convert (src, dest_image, G_TYPE_FROM_INSTANCE (src));
 
-      /* Import any attached layer effects */
-      if (GIMP_IS_DRAWABLE (item))
-        filters = gimp_drawable_get_filters (GIMP_DRAWABLE (src));
-
-      if (filters != NULL &&
-          gimp_container_get_n_children (filters) > 0)
-        {
-          GList *filter_list;
-
-          for (filter_list = GIMP_LIST (filters)->queue->tail; filter_list;
-               filter_list = g_list_previous (filter_list))
-            {
-              if (GIMP_IS_DRAWABLE_FILTER (filter_list->data))
-                {
-                  GimpDrawableFilter *old_filter = filter_list->data;
-                  GimpDrawableFilter *filter;
-
-                  filter =
-                    gimp_drawable_filter_duplicate (GIMP_DRAWABLE (item),
-                                                    old_filter);
-
-                  if (filter != NULL)
-                    {
-                      gimp_drawable_filter_apply (filter, NULL);
-                      gimp_drawable_filter_commit (filter, TRUE, NULL, FALSE);
-
-                      gimp_drawable_filter_layer_mask_freeze (filter);
-                      g_object_unref (filter);
-                    }
-                }
-            }
-        }
-
       if (g_list_length (items) == 1)
         {
           gimp_object_set_name (GIMP_OBJECT (item), basename);
@@ -876,7 +938,68 @@ file_open_get_layers (GimpImage *image,
 static gboolean
 file_open_file_proc_is_import (GimpPlugInProcedure *file_proc)
 {
-  return !(file_proc &&
-           file_proc->mime_types &&
-           strcmp (file_proc->mime_types, "image/x-xcf") == 0);
+  const gchar *proc_name;
+
+  g_return_val_if_fail (file_proc != NULL, TRUE);
+
+  proc_name = gimp_object_get_name (file_proc);
+
+  return (g_strcmp0 (proc_name, "gimp-xcf-load") != 0 &&
+          /* Assuming that all file-compressor file are XCF.
+           * So far, this is always true with current file-compressor
+           * implementation.
+           */
+          g_strcmp0 (proc_name, "file-gz-load")  != 0 &&
+          g_strcmp0 (proc_name, "file-bz2-load") != 0 &&
+          g_strcmp0 (proc_name, "file-xz-load")  != 0);
+}
+
+static gboolean
+file_open_valid_permissions (GFile   *file,
+                             GError **error)
+{
+  /* FIXME enable these tests for remote files again, needs testing */
+  if (g_file_is_native (file))
+    {
+      GFileInfo *info;
+
+      info = g_file_query_info (file,
+                                G_FILE_ATTRIBUTE_STANDARD_TYPE ","
+                                G_FILE_ATTRIBUTE_ACCESS_CAN_READ,
+                                G_FILE_QUERY_INFO_NONE,
+                                NULL, error);
+
+      if (info != NULL)
+        {
+          if (g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_REGULAR)
+            {
+              g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                                   _("Not a regular file"));
+              g_object_unref (info);
+              return FALSE;
+            }
+
+          if (! g_file_info_get_attribute_boolean (info,
+                                                   G_FILE_ATTRIBUTE_ACCESS_CAN_READ))
+            {
+              g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                                   _("Permission denied"));
+              g_object_unref (info);
+              return FALSE;
+            }
+
+          g_object_unref (info);
+        }
+      else
+        {
+          /* File likely does not exists. error will already have a more
+           * accurate reason.
+           */
+          return FALSE;
+        }
+
+      return TRUE;
+    }
+
+  return FALSE;
 }
