@@ -17,8 +17,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_GEGL_ENUMS_H__
-#define __GIMP_GEGL_ENUMS_H__
+#pragma once
 
 
 #define GIMP_TYPE_CAGE_MODE (gimp_cage_mode_get_type ())
@@ -30,6 +29,3 @@ typedef enum
   GIMP_CAGE_MODE_CAGE_CHANGE, /*< desc="Create or adjust the cage"            >*/
   GIMP_CAGE_MODE_DEFORM       /*< desc="Deform the cage\nto deform the image" >*/
 } GimpCageMode;
-
-
-#endif /* __GIMP_GEGL_ENUMS_H__ */
