@@ -25,6 +25,9 @@
 #ifdef G_OS_WIN32
 #include <windows.h>
 #endif
+#ifdef __APPLE__
+#include <CoreFoundation/CoreFoundation.h>
+#endif
 
 #include "libgimpbase/gimpbase.h"
 #include "libgimpconfig/gimpconfig.h"
@@ -64,9 +67,8 @@ static void   themes_theme_settings_portal_changed (GDBusProxy            *proxy
                                                     GVariant              *parameters,
                                                     Gimp                  *gimp);
 #endif
-
-#ifdef G_OS_WIN32
-static gboolean themes_win32_is_darkmode_active    (void);
+#if defined(__APPLE__)
+static gboolean themes_macos_is_dark_mode_active   (void);
 #endif
 
 
@@ -406,7 +408,14 @@ themes_apply_theme (Gimp          *gimp,
 #elif defined(G_OS_WIN32)
   if (config->theme_scheme == GIMP_THEME_SYSTEM)
     {
-      prefer_dark_theme = themes_win32_is_darkmode_active ();
+      prefer_dark_theme = gimp_is_win32_system_theme_dark ();
+      color_scheme = prefer_dark_theme ? GIMP_THEME_DARK : GIMP_THEME_LIGHT;
+    }
+  else
+#elif defined(__APPLE__)
+  if (config->theme_scheme == GIMP_THEME_SYSTEM)
+    {
+      prefer_dark_theme = themes_macos_is_dark_mode_active ();
       color_scheme = prefer_dark_theme ? GIMP_THEME_DARK : GIMP_THEME_LIGHT;
     }
   else
@@ -857,6 +866,25 @@ themes_theme_settings_portal_changed (GDBusProxy  *proxy,
 }
 #endif
 
+#ifdef __APPLE__
+static gboolean
+themes_macos_is_dark_mode_active (void)
+{
+  gboolean    is_dark = FALSE;
+  CFStringRef style;
+
+  style = CFPreferencesCopyAppValue (CFSTR ("AppleInterfaceStyle"), kCFPreferencesCurrentUser);
+  if (style)
+    {
+      if (CFStringCompare (style, CFSTR ("Dark"), kCFCompareCaseInsensitive) == kCFCompareEqualTo)
+        is_dark = TRUE;
+      CFRelease(style);
+    }
+
+    return is_dark;
+}
+#endif /* __APPLE__ */
+
 #ifdef G_OS_WIN32
 void
 themes_set_title_bar (Gimp *gimp)
@@ -874,22 +902,4 @@ themes_set_title_bar (Gimp *gimp)
   if (windows)
     g_list_free (windows);
 }
-
-static gboolean
-themes_win32_is_darkmode_active (void)
-{
-  DWORD   val      = 0;
-  DWORD   val_size = sizeof (val);
-  LSTATUS status;
-
-  status = RegGetValueA(HKEY_CURRENT_USER,
-                        "Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize",
-                        "AppsUseLightTheme",
-                        RRF_RT_REG_DWORD,
-                        NULL,
-                        &val,
-                        &val_size);
-
-  return status == ERROR_SUCCESS && val == 0;
-}
 #endif
