@@ -17,12 +17,9 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_PLUG_IN_MESSAGE_H__
-#define __GIMP_PLUG_IN_MESSAGE_H__
+#pragma once
 
 
 void   gimp_plug_in_handle_message (GimpPlugIn      *plug_in,
                                     GimpWireMessage *msg);
 
-
-#endif /* __GIMP_PLUG_IN_MESSAGE_H__ */
