@@ -18,8 +18,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_PROP_GUI_VIGNETTE_H__
-#define __GIMP_PROP_GUI_VIGNETTE_H__
+#pragma once
 
 
 GtkWidget *
@@ -31,6 +30,3 @@ _gimp_prop_gui_new_vignette (GObject                  *config,
                              GimpCreatePickerFunc      create_picker_func,
                              GimpCreateControllerFunc  create_controller_func,
                              gpointer                  creator);
-
-
-#endif /* __GIMP_PROP_GUI_VIGNETTE_H__ */
