@@ -134,8 +134,7 @@ static GimpTempBuf * gimp_font_get_new_preview    (GimpViewable          *viewab
                                                    GimpContext           *context,
                                                    gint                   width,
                                                    gint                   height,
-                                                   GeglColor             *color,
-                                                   GeglColor             *background);
+                                                   GeglColor             *fg_color);
 
 static void          gimp_font_config_iface_init  (GimpConfigInterface  *iface);
 static gboolean      gimp_font_serialize          (GimpConfig           *config,
@@ -601,6 +600,7 @@ gimp_font_class_init (GimpFontClass *klass)
   viewable_class->get_new_preview   = gimp_font_get_new_preview;
 
   viewable_class->default_icon_name = "gtk-select-font";
+  viewable_class->default_name      = _("Font");
 }
 
 static void
@@ -713,8 +713,7 @@ gimp_font_get_new_preview (GimpViewable *viewable,
                            GimpContext  *context,
                            gint          width,
                            gint          height,
-                           GeglColor    *color,
-                           GeglColor    *background)
+                           GeglColor    *fg_color)
 {
   GimpFont        *font = GIMP_FONT (viewable);
   PangoContext    *pango_context;
@@ -735,8 +734,9 @@ gimp_font_get_new_preview (GimpViewable *viewable,
   if (! pango_context)
     return NULL;
 
-  if (! font->popup_layout ||
-      font->popup_width != width || font->popup_height != height)
+  if (! font->popup_layout        ||
+      font->popup_width  != width ||
+      font->popup_height != height)
     {
       PangoFontDescription *font_desc;
       const gchar          *name;
@@ -769,19 +769,7 @@ gimp_font_get_new_preview (GimpViewable *viewable,
   stride = cairo_format_stride_for_width (CAIRO_FORMAT_ARGB32, width);
 
   temp_buf = gimp_temp_buf_new (width, height, babl_format ("cairo-ARGB32"));
-  if (background)
-    {
-      guint32 *data = (guint32 *) gimp_temp_buf_get_data (temp_buf);
-      guint32  argb;
-
-      gegl_color_get_pixel (background, babl_format ("cairo-ARGB32"), &argb);
-      for (gint i = 0; i < width * height; i++)
-        data[i] = argb;
-    }
-  else
-    {
-      memset (gimp_temp_buf_get_data (temp_buf), 255, width * height * 4);
-    }
+  memset (gimp_temp_buf_get_data (temp_buf), 0, width * height * 4);
 
   surface = cairo_image_surface_create_for_data (gimp_temp_buf_get_data (temp_buf),
                                                  CAIRO_FORMAT_ARGB32,
@@ -805,11 +793,11 @@ gimp_font_get_new_preview (GimpViewable *viewable,
 
   cairo_translate (cr, layout_x, layout_y);
   cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-  if (color)
+  if (fg_color)
     {
       gfloat rgb[3];
 
-      gegl_color_get_pixel (color, babl_format ("R'G'B' float"), rgb);
+      gegl_color_get_pixel (fg_color, babl_format ("R'G'B' float"), rgb);
       cairo_set_source_rgb (cr, rgb[0], rgb[1], rgb[2]);
     }
   else
