@@ -15,10 +15,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-
-#ifndef __GIMP_FOREGROUND_SELECT_OPTIONS_H__
-#define __GIMP_FOREGROUND_SELECT_OPTIONS_H__
-
+#pragma once
 
 #include "gimpselectionoptions.h"
 
@@ -57,8 +54,3 @@ struct _GimpForegroundSelectOptionsClass
 GType       gimp_foreground_select_options_get_type       (void) G_GNUC_CONST;
 
 GtkWidget * gimp_foreground_select_options_gui            (GimpToolOptions             *tool_options);
-
-
-
-#endif /* __GIMP_FOREGROUND_SELECT_OPTIONS_H__ */
-
