@@ -22,6 +22,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "libgimpbase/gimpbase.h"
+#include "libgimpcolor/gimpcolor.h"
 #include "libgimpmath/gimpmath.h"
 #include "libgimpwidgets/gimpwidgets.h"
 
@@ -331,10 +332,7 @@ gimp_gradient_tool_editor_line_selection_changed (GimpToolLine     *line,
           seg = gimp_gradient_tool_editor_handle_get_segment (gradient_tool,
                                                               selection);
 
-          homogeneous = seg->right_color.r    == seg->next->left_color.r &&
-                        seg->right_color.g    == seg->next->left_color.g &&
-                        seg->right_color.b    == seg->next->left_color.b &&
-                        seg->right_color.a    == seg->next->left_color.a &&
+          homogeneous = gimp_color_is_perceptually_identical (seg->right_color, seg->next->left_color) &&
                         seg->right_color_type == seg->next->left_color_type;
 
           gimp_chain_button_set_active (
@@ -400,7 +398,7 @@ gimp_gradient_tool_editor_color_entry_color_changed (GimpColorButton  *button,
   GimpGradientOptions *options       = GIMP_GRADIENT_TOOL_GET_OPTIONS (gradient_tool);
   GimpPaintOptions    *paint_options = GIMP_PAINT_OPTIONS (options);
   gint                 selection;
-  GimpRGB              color;
+  GeglColor           *color;
   Direction            direction;
   GtkWidget           *chain_button;
   GimpGradientSegment *seg;
@@ -411,7 +409,7 @@ gimp_gradient_tool_editor_color_entry_color_changed (GimpColorButton  *button,
   selection =
     gimp_tool_line_get_selection (GIMP_TOOL_LINE (gradient_tool->widget));
 
-  gimp_color_button_get_color (button, &color);
+  color = gimp_color_button_get_color (button);
 
   direction =
     GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button),
@@ -442,12 +440,14 @@ gimp_gradient_tool_editor_color_entry_color_changed (GimpColorButton  *button,
   switch (selection)
     {
     case GIMP_TOOL_LINE_HANDLE_START:
-      seg->left_color      = color;
+      g_clear_object (&seg->left_color);
+      seg->left_color      = g_object_ref (color);
       seg->left_color_type = GIMP_GRADIENT_COLOR_FIXED;
       break;
 
     case GIMP_TOOL_LINE_HANDLE_END:
-      seg->right_color      = color;
+      g_clear_object (&seg->right_color);
+      seg->right_color      = g_object_ref (color);
       seg->right_color_type = GIMP_GRADIENT_COLOR_FIXED;
       break;
 
@@ -456,7 +456,8 @@ gimp_gradient_tool_editor_color_entry_color_changed (GimpColorButton  *button,
           (chain_button               &&
            gimp_chain_button_get_active (GIMP_CHAIN_BUTTON (chain_button))))
         {
-          seg->right_color      = color;
+          g_clear_object (&seg->right_color);
+          seg->right_color      = gegl_color_duplicate (color);
           seg->right_color_type = GIMP_GRADIENT_COLOR_FIXED;
         }
 
@@ -464,13 +465,16 @@ gimp_gradient_tool_editor_color_entry_color_changed (GimpColorButton  *button,
           (chain_button                &&
            gimp_chain_button_get_active (GIMP_CHAIN_BUTTON (chain_button))))
         {
-          seg->next->left_color      = color;
+          g_clear_object (&seg->next->left_color);
+          seg->next->left_color      = g_object_ref (color);
           seg->next->left_color_type = GIMP_GRADIENT_COLOR_FIXED;
         }
     }
 
   gimp_gradient_tool_editor_thaw_gradient (gradient_tool);
   gimp_gradient_tool_editor_end_edit (gradient_tool, FALSE);
+
+  g_object_unref (color);
 }
 
 static void
@@ -1202,14 +1206,15 @@ gimp_gradient_tool_editor_color_entry_new (GimpGradientTool  *gradient_tool,
   GtkWidget   *hbox;
   GtkWidget   *button;
   GtkWidget   *combo;
-  GimpRGB      color   = {};
+  GeglColor   *color   = gegl_color_new ("transparent");
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
 
   /* the color panel */
-  *color_panel = button = gimp_color_panel_new (title, &color,
+  *color_panel = button = gimp_color_panel_new (title, color,
                                                 GIMP_COLOR_AREA_SMALL_CHECKS,
                                                 24, 24);
+  g_object_unref (color);
   gimp_color_button_set_update (GIMP_COLOR_BUTTON (button), TRUE);
   gimp_color_panel_set_context (GIMP_COLOR_PANEL (button), context);
   gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
@@ -1299,7 +1304,7 @@ gimp_gradient_tool_editor_init_endpoint_gui (GimpGradientTool *gradient_tool)
   gtk_entry_set_width_chars (GTK_ENTRY (spinbutton), 6);
 
   gradient_tool->endpoint_se =
-  se                         = gimp_size_entry_new (1, GIMP_UNIT_PIXEL, "%a",
+  se                         = gimp_size_entry_new (1, gimp_unit_pixel (), "%a",
                                                     TRUE, TRUE, FALSE, 6,
                                                     GIMP_SIZE_ENTRY_UPDATE_SIZE);
   gtk_grid_set_row_spacing (GTK_GRID (se), 4);
@@ -1386,7 +1391,7 @@ gimp_gradient_tool_editor_init_stop_gui (GimpGradientTool *gradient_tool)
 
   /* the position size entry */
   gradient_tool->stop_se =
-  se                     = gimp_size_entry_new (1, GIMP_UNIT_PERCENT, "%a",
+  se                     = gimp_size_entry_new (1, gimp_unit_percent (), "%a",
                                                 FALSE, TRUE, FALSE, 6,
                                                 GIMP_SIZE_ENTRY_UPDATE_SIZE);
   gimp_size_entry_show_unit_menu (GIMP_SIZE_ENTRY (se), FALSE);
@@ -1485,7 +1490,7 @@ gimp_gradient_tool_editor_init_midpoint_gui (GimpGradientTool *gradient_tool)
 
   /* the position size entry */
   gradient_tool->midpoint_se =
-  se                         = gimp_size_entry_new (1, GIMP_UNIT_PERCENT, "%a",
+  se                         = gimp_size_entry_new (1, gimp_unit_percent (), "%a",
                                                     FALSE, TRUE, FALSE, 6,
                                                     GIMP_SIZE_ENTRY_UPDATE_SIZE);
   gimp_size_entry_show_unit_menu (GIMP_SIZE_ENTRY (se), FALSE);
@@ -1570,7 +1575,7 @@ gimp_gradient_tool_editor_update_endpoint_gui (GimpGradientTool *gradient_tool,
   const gchar         *title;
   gdouble              x;
   gdouble              y;
-  GimpRGB              color;
+  GeglColor           *color = NULL;
   GimpGradientColor    color_type;
 
   editable = gimp_gradient_tool_editor_is_gradient_editable (gradient_tool);
@@ -1617,16 +1622,16 @@ gimp_gradient_tool_editor_update_endpoint_gui (GimpGradientTool *gradient_tool,
     case GIMP_TOOL_LINE_HANDLE_START:
       title = _("Start Endpoint");
 
-      gimp_gradient_segment_get_left_flat_color (gradient_tool->gradient, context,
-                                                 seg, &color);
+      color = gimp_gradient_segment_get_left_flat_color (gradient_tool->gradient, context,
+                                                         seg);
       color_type = seg->left_color_type;
       break;
 
     case GIMP_TOOL_LINE_HANDLE_END:
       title = _("End Endpoint");
 
-      gimp_gradient_segment_get_right_flat_color (gradient_tool->gradient, context,
-                                                  seg, &color);
+      color = gimp_gradient_segment_get_right_flat_color (gradient_tool->gradient, context,
+                                                          seg);
       color_type = seg->right_color_type;
       break;
 
@@ -1639,8 +1644,7 @@ gimp_gradient_tool_editor_update_endpoint_gui (GimpGradientTool *gradient_tool,
   gimp_size_entry_set_refval (GIMP_SIZE_ENTRY (gradient_tool->endpoint_se), 0, x);
   gimp_size_entry_set_refval (GIMP_SIZE_ENTRY (gradient_tool->endpoint_se), 1, y);
 
-  gimp_color_button_set_color (
-    GIMP_COLOR_BUTTON (gradient_tool->endpoint_color_panel), &color);
+  gimp_color_button_set_color (GIMP_COLOR_BUTTON (gradient_tool->endpoint_color_panel), color);
   gimp_int_combo_box_set_active (
     GIMP_INT_COMBO_BOX (gradient_tool->endpoint_type_combo), color_type);
 
@@ -1648,6 +1652,8 @@ gimp_gradient_tool_editor_update_endpoint_gui (GimpGradientTool *gradient_tool,
   gtk_widget_set_sensitive (gradient_tool->endpoint_type_combo,  editable);
 
   gtk_widget_show (gradient_tool->endpoint_editor);
+
+  g_object_unref (color);
 }
 
 static void
@@ -1663,9 +1669,9 @@ gimp_gradient_tool_editor_update_stop_gui (GimpGradientTool *gradient_tool,
   gdouble              min;
   gdouble              max;
   gdouble              value;
-  GimpRGB              left_color;
+  GeglColor           *left_color;
   GimpGradientColor    left_color_type;
-  GimpRGB              right_color;
+  GeglColor           *right_color;
   GimpGradientColor    right_color_type;
 
   editable = gimp_gradient_tool_editor_is_gradient_editable (gradient_tool);
@@ -1682,12 +1688,11 @@ gimp_gradient_tool_editor_update_stop_gui (GimpGradientTool *gradient_tool,
   max   = seg->next->right;
   value = seg->right;
 
-  gimp_gradient_segment_get_right_flat_color (gradient_tool->gradient, context,
-                                              seg, &left_color);
+  left_color = gimp_gradient_segment_get_right_flat_color (gradient_tool->gradient, context, seg);
   left_color_type = seg->right_color_type;
 
-  gimp_gradient_segment_get_left_flat_color (gradient_tool->gradient, context,
-                                             seg->next, &right_color);
+  right_color = gimp_gradient_segment_get_left_flat_color (gradient_tool->gradient, context,
+                                                           seg->next);
   right_color_type = seg->next->left_color_type;
 
   gimp_tool_gui_set_title (gradient_tool->gui, title);
@@ -1698,12 +1703,12 @@ gimp_gradient_tool_editor_update_stop_gui (GimpGradientTool *gradient_tool,
                               0, 100.0 * value);
 
   gimp_color_button_set_color (
-    GIMP_COLOR_BUTTON (gradient_tool->stop_left_color_panel), &left_color);
+    GIMP_COLOR_BUTTON (gradient_tool->stop_left_color_panel), left_color);
   gimp_int_combo_box_set_active (
     GIMP_INT_COMBO_BOX (gradient_tool->stop_left_type_combo), left_color_type);
 
   gimp_color_button_set_color (
-    GIMP_COLOR_BUTTON (gradient_tool->stop_right_color_panel), &right_color);
+    GIMP_COLOR_BUTTON (gradient_tool->stop_right_color_panel), right_color);
   gimp_int_combo_box_set_active (
     GIMP_INT_COMBO_BOX (gradient_tool->stop_right_type_combo), right_color_type);
 
@@ -1718,6 +1723,8 @@ gimp_gradient_tool_editor_update_stop_gui (GimpGradientTool *gradient_tool,
     editable);
 
   g_free (title);
+  g_object_unref (left_color);
+  g_object_unref (right_color);
 
   gtk_widget_show (gradient_tool->stop_editor);
 }
