@@ -12,14 +12,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef  __GIMP_INK_OPTIONS_GUI_H__
-#define  __GIMP_INK_OPTIONS_GUI_H__
+#pragma once
 
 
-GtkWidget * gimp_ink_options_gui      (GimpToolOptions *tool_options);
-
-
-#endif  /*  __GIMP_INK_OPTIONS_GUI_H__  */
+GtkWidget * gimp_ink_options_gui (GimpToolOptions *tool_options);
