@@ -15,9 +15,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_MAGNIFY_TOOL_H__
-#define __GIMP_MAGNIFY_TOOL_H__
-
+#pragma once
 
 #include "gimpdrawtool.h"
 
@@ -55,6 +53,3 @@ void    gimp_magnify_tool_register (GimpToolRegisterCallback  callback,
                                     gpointer                  data);
 
 GType   gimp_magnify_tool_get_type (void) G_GNUC_CONST;
-
-
-#endif  /*  __GIMP_MAGNIFY_TOOL_H__  */
