@@ -46,7 +46,10 @@ G_DEFINE_TYPE (GimpMybrushTool, gimp_mybrush_tool, GIMP_TYPE_PAINT_TOOL)
 
 #define parent_class gimp_mybrush_tool_parent_class
 
-
+static void   gimp_mybrush_tool_cursor_update         (GimpTool         *tool,
+                                                       const GimpCoords *coords,
+                                                       GdkModifierType   state,
+                                                       GimpDisplay      *display);
 static void   gimp_mybrush_tool_options_notify        (GimpTool         *tool,
                                                        GimpToolOptions  *options,
                                                        const GParamSpec *pspec);
@@ -86,6 +89,7 @@ gimp_mybrush_tool_class_init (GimpMybrushToolClass *klass)
   GimpToolClass      *tool_class       = GIMP_TOOL_CLASS (klass);
   GimpPaintToolClass *paint_tool_class = GIMP_PAINT_TOOL_CLASS (klass);
 
+  tool_class->cursor_update     = gimp_mybrush_tool_cursor_update;
   tool_class->options_notify    = gimp_mybrush_tool_options_notify;
 
   paint_tool_class->get_outline = gimp_mybrush_tool_get_outline;
@@ -108,6 +112,23 @@ gimp_mybrush_tool_init (GimpMybrushTool *mybrush_tool)
                                        GIMP_COLOR_PICK_TARGET_FOREGROUND);
 }
 
+static void gimp_mybrush_tool_cursor_update (GimpTool         *tool,
+                                             const GimpCoords *coords,
+                                             GdkModifierType   state,
+                                             GimpDisplay      *display)
+{
+  GimpDisplayShell   *shell;
+  GimpMybrushOptions *options = GIMP_MYBRUSH_TOOL_GET_OPTIONS (tool);
+
+  g_return_if_fail (GIMP_IS_DISPLAY (display));
+
+  shell = gimp_display_get_shell (display);
+
+  options->view_zoom     = (gimp_zoom_model_get_factor (shell->zoom) > 0.0f) ?
+                            gimp_zoom_model_get_factor (shell->zoom) : 1.0f;
+  options->view_rotation = shell->rotate_angle;
+}
+
 static void
 gimp_mybrush_tool_options_notify (GimpTool         *tool,
                                   GimpToolOptions  *options,
