@@ -34,6 +34,7 @@
 #include "core/gimperror.h"
 #include "core/gimpimage.h"
 #include "core/gimplayer.h"
+#include "core/gimplinklayer.h"
 #include "core/gimppaintinfo.h"
 #include "core/gimpprojection.h"
 #include "core/gimptoolinfo.h"
@@ -41,6 +42,8 @@
 #include "paint/gimppaintcore.h"
 #include "paint/gimppaintoptions.h"
 
+#include "path/gimpvectorlayer.h"
+
 #include "widgets/gimpdevices.h"
 #include "widgets/gimpwidgets-utils.h"
 
@@ -324,18 +327,35 @@ gimp_paint_tool_button_press (GimpTool            *tool,
           return;
         }
 
-      if (gimp_item_is_content_locked (GIMP_ITEM (drawable), &locked_item))
+      if (gimp_item_is_vector_layer (GIMP_ITEM (drawable)) ||
+          gimp_item_is_link_layer (GIMP_ITEM (drawable))   ||
+          gimp_item_is_content_locked (GIMP_ITEM (drawable), &locked_item))
         {
           gboolean constrain_only;
 
-          /* Allow pixel-locked layers to be set as sources */
+          /* Allow vector/link or pixel-locaked layers to be set as sources */
           constrain_only = (state & gimp_get_constrain_behavior_mask () &&
                             ! (state & gimp_get_extend_selection_mask ()));
           if (! (GIMP_IS_SOURCE_TOOL (tool) && constrain_only))
             {
-              gimp_tool_message_literal (tool, display,
-                                         _("The selected item's pixels are locked."));
-              gimp_tools_blink_lock_box (display->gimp, locked_item);
+              if (gimp_item_is_link_layer (GIMP_ITEM (drawable)))
+                {
+                  gimp_tool_message_literal (tool, display,
+                                             _("Link layers must be rasterized "
+                                               "before they can be painted on."));
+                }
+              else if (gimp_item_is_vector_layer (GIMP_ITEM (drawable)))
+                {
+                  gimp_tool_message_literal (tool, display,
+                                             _("Vector layers must be rasterized "
+                                               "before they can be painted on."));
+                }
+              else
+                {
+                  gimp_tool_message_literal (tool, display,
+                                             _("The selected item's pixels are locked."));
+                  gimp_tools_blink_lock_box (display->gimp, locked_item);
+                }
               g_list_free (drawables);
 
               return;
