@@ -39,7 +39,7 @@
 #include "gimp-intl.h"
 
 
-#define SB_WIDTH 5
+#define SB_WIDTH 7
 
 
 enum
@@ -53,7 +53,7 @@ enum
 
 /*  local function prototypes  */
 
-static void     gimp_rectangle_options_fixed_rule_changed     (GtkWidget                   *combo_box,
+static void     gimp_rectangle_options_fixed_rule_changed     (GtkWidget                   *widget,
                                                                GimpRectangleOptionsPrivate *private);
 
 static void     gimp_rectangle_options_string_current_updates (GimpNumberPairEntry         *entry,
@@ -148,7 +148,7 @@ gimp_rectangle_options_default_init (GimpRectangleOptionsInterface *iface)
                                                              NULL,
                                                              _("Unit of top left corner coordinate"),
                                                              TRUE, TRUE,
-                                                             GIMP_UNIT_PIXEL,
+                                                             gimp_unit_pixel (),
                                                              GIMP_PARAM_READWRITE |
                                                              G_PARAM_CONSTRUCT));
 
@@ -157,7 +157,7 @@ gimp_rectangle_options_default_init (GimpRectangleOptionsInterface *iface)
                                                              NULL,
                                                              _("Unit of selection size"),
                                                              TRUE, TRUE,
-                                                             GIMP_UNIT_PIXEL,
+                                                             gimp_unit_pixel (),
                                                              GIMP_PARAM_READWRITE |
                                                              G_PARAM_CONSTRUCT));
 
@@ -287,7 +287,7 @@ gimp_rectangle_options_default_init (GimpRectangleOptionsInterface *iface)
                                                              NULL,
                                                              _("Unit of fixed width, height or size"),
                                                              TRUE, TRUE,
-                                                             GIMP_UNIT_PIXEL,
+                                                             gimp_unit_pixel (),
                                                              GIMP_PARAM_READWRITE |
                                                              G_PARAM_CONSTRUCT));
 
@@ -483,10 +483,10 @@ gimp_rectangle_options_set_property (GObject      *object,
       private->height = g_value_get_double (value);
       break;
     case GIMP_RECTANGLE_OPTIONS_PROP_POSITION_UNIT:
-      private->position_unit = g_value_get_int (value);
+      private->position_unit = g_value_get_object (value);
       break;
     case GIMP_RECTANGLE_OPTIONS_PROP_SIZE_UNIT:
-      private->size_unit = g_value_get_int (value);
+      private->size_unit = g_value_get_object (value);
       break;
 
     case GIMP_RECTANGLE_OPTIONS_PROP_FIXED_RULE_ACTIVE:
@@ -535,7 +535,7 @@ gimp_rectangle_options_set_property (GObject      *object,
       private->use_string_current = g_value_get_boolean (value);
       break;
     case GIMP_RECTANGLE_OPTIONS_PROP_FIXED_UNIT:
-      private->fixed_unit = g_value_get_int (value);
+      private->fixed_unit = g_value_get_object (value);
       break;
 
     case GIMP_RECTANGLE_OPTIONS_PROP_FIXED_CENTER:
@@ -590,10 +590,10 @@ gimp_rectangle_options_get_property (GObject      *object,
       g_value_set_double (value, private->height);
       break;
     case GIMP_RECTANGLE_OPTIONS_PROP_POSITION_UNIT:
-      g_value_set_int (value, private->position_unit);
+      g_value_set_object (value, private->position_unit);
       break;
     case GIMP_RECTANGLE_OPTIONS_PROP_SIZE_UNIT:
-      g_value_set_int (value, private->size_unit);
+      g_value_set_object (value, private->size_unit);
       break;
 
     case GIMP_RECTANGLE_OPTIONS_PROP_FIXED_RULE_ACTIVE:
@@ -642,7 +642,7 @@ gimp_rectangle_options_get_property (GObject      *object,
       g_value_set_boolean (value, private->use_string_current);
       break;
     case GIMP_RECTANGLE_OPTIONS_PROP_FIXED_UNIT:
-      g_value_set_int (value, private->fixed_unit);
+      g_value_set_object (value, private->fixed_unit);
       break;
 
     case GIMP_RECTANGLE_OPTIONS_PROP_FIXED_CENTER:
@@ -674,15 +674,20 @@ gimp_rectangle_options_get_size_entry (GimpRectangleOptions *rectangle_options)
 
 /**
  * gimp_rectangle_options_fixed_rule_changed:
- * @combo_box:
+ * @widget:
  * @private:
  *
  * Updates tool options widgets depending on current fixed rule state.
  */
 static void
-gimp_rectangle_options_fixed_rule_changed (GtkWidget                   *combo_box,
+gimp_rectangle_options_fixed_rule_changed (GtkWidget                   *widget,
                                            GimpRectangleOptionsPrivate *private)
 {
+  /* Update fixed_rule_active if checkbox was changed */
+  if (GTK_IS_TOGGLE_BUTTON (widget))
+    private->fixed_rule_active =
+      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+
   /* Setup sensitivity for Width and Height entries */
 
   gtk_widget_set_sensitive (gimp_size_entry_get_help_widget (
@@ -758,7 +763,7 @@ gimp_rectangle_options_prop_dimension_frame_new (GObject      *config,
                                                  GtkSizeGroup *label_group,
                                                  GtkWidget   **entry)
 {
-  GimpUnit       unit_value;
+  GimpUnit      *unit_value;
   GtkWidget     *frame;
   GtkWidget     *hbox;
   GtkWidget     *label;
@@ -876,16 +881,14 @@ gimp_rectangle_options_gui (GimpToolOptions *tool_options)
     size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 
     /* Fixed aspect entry/buttons */
-    private->fixed_aspect_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+    g_set_weak_pointer (&private->fixed_aspect_hbox,
+                        gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2));
     gtk_box_pack_start (GTK_BOX (vbox2), private->fixed_aspect_hbox,
                         FALSE, FALSE, 0);
     gtk_size_group_add_widget (size_group, private->fixed_aspect_hbox);
     g_object_unref (size_group);
     /* don't show */
 
-    g_object_add_weak_pointer (G_OBJECT (private->fixed_aspect_hbox),
-                               (gpointer) &private->fixed_aspect_hbox);
-
     entry = gimp_prop_number_pair_entry_new (config,
                                              "aspect-numerator",
                                              "aspect-denominator",
@@ -910,15 +913,12 @@ gimp_rectangle_options_gui (GimpToolOptions *tool_options)
                                                    entry,
                                                    private->aspect_history);
 
-    private->aspect_button_box =
-      gimp_prop_enum_icon_box_new (G_OBJECT (entry),
-                                   "aspect", "gimp", -1, -1);
+    g_set_weak_pointer (&private->aspect_button_box,
+                        gimp_prop_enum_icon_box_new (G_OBJECT (entry),
+                                                     "aspect", "gimp", -1, -1));
     gtk_box_pack_start (GTK_BOX (private->fixed_aspect_hbox),
                         private->aspect_button_box, FALSE, FALSE, 0);
 
-    g_object_add_weak_pointer (G_OBJECT (private->aspect_button_box),
-                               (gpointer) &private->aspect_button_box);
-
     /* hide "square" */
     children =
       gtk_container_get_children (GTK_CONTAINER (private->aspect_button_box));
@@ -926,41 +926,37 @@ gimp_rectangle_options_gui (GimpToolOptions *tool_options)
     g_list_free (children);
 
     /* Fixed width entry */
-    private->fixed_width_entry =
-      gimp_prop_size_entry_new (config,
-                                "desired-fixed-width", TRUE, "fixed-unit", "%a",
-                                GIMP_SIZE_ENTRY_UPDATE_SIZE, 300);
+    g_set_weak_pointer (&private->fixed_width_entry,
+                        gimp_prop_size_entry_new (config,
+                                                  "desired-fixed-width",
+                                                  TRUE, "fixed-unit", "%a",
+                                                  GIMP_SIZE_ENTRY_UPDATE_SIZE,
+                                                  300));
     gtk_box_pack_start (GTK_BOX (vbox2), private->fixed_width_entry,
                         FALSE, FALSE, 0);
     gtk_size_group_add_widget (size_group, private->fixed_width_entry);
     gtk_widget_hide (private->fixed_width_entry);
 
-    g_object_add_weak_pointer (G_OBJECT (private->fixed_width_entry),
-                               (gpointer) &private->fixed_width_entry);
-
     /* Fixed height entry */
-    private->fixed_height_entry =
-      gimp_prop_size_entry_new (config,
-                                "desired-fixed-height", TRUE, "fixed-unit", "%a",
-                                GIMP_SIZE_ENTRY_UPDATE_SIZE, 300);
+    g_set_weak_pointer (&private->fixed_height_entry,
+                        gimp_prop_size_entry_new (config,
+                                                  "desired-fixed-height",
+                                                  TRUE, "fixed-unit", "%a",
+                                                  GIMP_SIZE_ENTRY_UPDATE_SIZE,
+                                                  300));
     gtk_box_pack_start (GTK_BOX (vbox2), private->fixed_height_entry,
                         FALSE, FALSE, 0);
     gtk_size_group_add_widget (size_group, private->fixed_height_entry);
     gtk_widget_hide (private->fixed_height_entry);
 
-    g_object_add_weak_pointer (G_OBJECT (private->fixed_height_entry),
-                               (gpointer) &private->fixed_height_entry);
-
     /* Fixed size entry */
-    private->fixed_size_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+    g_set_weak_pointer (&private->fixed_size_hbox,
+                        gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2));
     gtk_box_pack_start (GTK_BOX (vbox2), private->fixed_size_hbox,
                         FALSE, FALSE, 0);
     gtk_size_group_add_widget (size_group, private->fixed_size_hbox);
     gtk_widget_hide (private->fixed_size_hbox);
 
-    g_object_add_weak_pointer (G_OBJECT (private->fixed_size_hbox),
-                               (gpointer) &private->fixed_size_hbox);
-
     entry = gimp_prop_number_pair_entry_new (config,
                                              "desired-fixed-size-width",
                                              "desired-fixed-size-height",
@@ -1035,15 +1031,13 @@ gimp_rectangle_options_gui (GimpToolOptions *tool_options)
   gtk_box_pack_start (GTK_BOX (vbox), combo, FALSE, FALSE, 0);
 
   /*  Auto Shrink  */
-  private->auto_shrink_button = gtk_button_new_with_label (_("Auto Shrink"));
+  g_set_weak_pointer (&private->auto_shrink_button,
+                      gtk_button_new_with_label (_("Auto Shrink")));
   gtk_box_pack_start (GTK_BOX (vbox), private->auto_shrink_button,
                       FALSE, FALSE, 0);
   gtk_widget_set_sensitive (private->auto_shrink_button, FALSE);
   gtk_widget_show (private->auto_shrink_button);
 
-  g_object_add_weak_pointer (G_OBJECT (private->auto_shrink_button),
-                             (gpointer) &private->auto_shrink_button);
-
   button = gimp_prop_check_button_new (config, "shrink-merged", NULL);
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
