@@ -15,12 +15,8 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __GIMP_TOOL_OPTIONS_GUI_H__
-#define __GIMP_TOOL_OPTIONS_GUI_H__
+#pragma once
 
 
 GtkWidget * gimp_tool_options_gui       (GimpToolOptions *tool_options);
 GtkWidget * gimp_tool_options_empty_gui (GimpToolOptions *tool_options);
-
-
-#endif  /*  __GIMP_TOOL_OPTIONS_GUI_H__  */
