@@ -39,7 +39,7 @@
 #include "core/gimpprogress.h"
 #include "core/gimp-transform-resize.h"
 
-#include "vectors/gimppath.h"
+#include "path/gimppath.h"
 
 #include "display/gimpdisplay.h"
 #include "display/gimpdisplayshell.h"
@@ -924,7 +924,7 @@ gimp_transform_tool_transform (GimpTransformTool *tr_tool,
           gimp_drawable_transform_paste (GIMP_DRAWABLE (selected_objects->data),
                                          new_buffer, buffer_profile,
                                          new_offset_x, new_offset_y,
-                                         new_layer);
+                                         new_layer, TRUE);
           g_object_unref (new_buffer);
         }
       break;
