@@ -15,15 +15,11 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __UNIQUE_H__
-#define __UNIQUE_H__
+#pragma once
 
 
-gboolean gimp_unique_open (const gchar **filenames,
-                           gboolean      as_new);
+gboolean gimp_unique_open      (const gchar **filenames,
+                                gboolean      as_new);
 
 gboolean gimp_unique_batch_run (const gchar  *batch_interpreter,
                                 const gchar **batch_commands);
-
-
-#endif /* __UNIQUE_H__ */
