@@ -51,6 +51,7 @@
 #include <gtk/gtk.h>
 
 #include "libgimpcolor/gimpcolor.h"
+#include "libgimpcolor/gimpcolor-private.h"
 #include "libgimpmath/gimpmath.h"
 #include "libgimpbase/gimpbase.h"
 #include "libgimpwidgets/gimpwidgets.h"
@@ -135,12 +136,12 @@ static void   gradient_editor_drop_gradient         (GtkWidget          *widget,
 static void   gradient_editor_drop_color            (GtkWidget          *widget,
                                                      gint                x,
                                                      gint                y,
-                                                     const GimpRGB      *color,
+                                                     GeglColor          *color,
                                                      gpointer            data);
 static void   gradient_editor_control_drop_color    (GtkWidget          *widget,
                                                      gint                x,
                                                      gint                y,
-                                                     const GimpRGB      *color,
+                                                     GeglColor          *color,
                                                      gpointer            data);
 static void   gradient_editor_scrollbar_update      (GtkAdjustment      *adj,
                                                      GimpGradientEditor *editor);
@@ -157,11 +158,11 @@ static void   gradient_editor_replace_selection     (GimpGradientEditor *editor,
                                                      GimpGradientSegment *replace_seg);
 
 static void   gradient_editor_left_color_update     (GimpColorDialog    *dialog,
-                                                     const GimpRGB      *color,
+                                                     GeglColor          *color,
                                                      GimpColorDialogState state,
                                                      GimpGradientEditor *editor);
 static void   gradient_editor_right_color_update    (GimpColorDialog    *dialog,
-                                                     const GimpRGB      *color,
+                                                     GeglColor          *color,
                                                      GimpColorDialogState state,
                                                      GimpGradientEditor *editor);
 
@@ -314,9 +315,9 @@ gimp_gradient_editor_init (GimpGradientEditor *editor)
   GtkWidget      *vbox;
   GtkWidget      *hbox;
   GtkWidget      *hint_vbox;
-  GimpRGB         transp;
+  GeglColor      *transp;
 
-  gimp_rgba_set (&transp, 0.0, 0.0, 0.0, 0.0);
+  transp = gegl_color_new ("transparent");
 
   /* Frame for gradient view and gradient control */
   frame = gtk_frame_new (NULL);
@@ -415,7 +416,7 @@ gimp_gradient_editor_init (GimpGradientEditor *editor)
   gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
-  editor->current_color = gimp_color_area_new (&transp,
+  editor->current_color = gimp_color_area_new (transp,
                                                GIMP_COLOR_AREA_SMALL_CHECKS,
                                                GDK_BUTTON1_MASK |
                                                GDK_BUTTON2_MASK);
@@ -435,18 +436,25 @@ gimp_gradient_editor_init (GimpGradientEditor *editor)
   editor->hint_label4 = gradient_hint_label_add (GTK_BOX (hint_vbox));
 
   /* Black, 50% Gray, White, Clear */
-  gimp_rgba_set (&editor->saved_colors[0], 0.0, 0.0, 0.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[1], 0.5, 0.5, 0.5, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[2], 1.0, 1.0, 1.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[3], 0.0, 0.0, 0.0, GIMP_OPACITY_TRANSPARENT);
+  editor->saved_colors[0] = gegl_color_new ("black");
+  editor->saved_colors[1] = gegl_color_new ("gray");
+  editor->saved_colors[2] = gegl_color_new ("white");
+  editor->saved_colors[3] = gegl_color_new ("transparent");
 
   /* Red, Yellow, Green, Cyan, Blue, Magenta */
-  gimp_rgba_set (&editor->saved_colors[4], 1.0, 0.0, 0.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[5], 1.0, 1.0, 0.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[6], 0.0, 1.0, 0.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[7], 0.0, 1.0, 1.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[8], 0.0, 0.0, 1.0, GIMP_OPACITY_OPAQUE);
-  gimp_rgba_set (&editor->saved_colors[9], 1.0, 0.0, 1.0, GIMP_OPACITY_OPAQUE);
+  editor->saved_colors[4] = gegl_color_new ("red");
+  editor->saved_colors[5] = gegl_color_new ("yellow");
+  /* XXX: green in GEGL is 0 0.5 0, so we override it. */
+  editor->saved_colors[6] = gegl_color_new ("green");
+  gegl_color_set_rgba_with_space (editor->saved_colors[6], 0.0, 1.0, 0.0, GIMP_OPACITY_OPAQUE, NULL);
+  /* XXX: Cyan */
+  editor->saved_colors[7] = gegl_color_new (NULL);
+  gegl_color_set_rgba_with_space (editor->saved_colors[7], 0.0, 1.0, 1.0, GIMP_OPACITY_OPAQUE, NULL);
+  editor->saved_colors[8] = gegl_color_new ("blue");
+  /* XXX: what we defined Magenta is "fuchsia" in GEGL. */
+  editor->saved_colors[9] = gegl_color_new ("fuchsia");
+
+  g_object_unref (transp);
 }
 
 static void
@@ -477,6 +485,9 @@ gimp_gradient_editor_dispose (GObject *object)
 
   g_clear_object (&editor->zoom_gesture);
 
+  for (gint i = 0; i < GRAD_NUM_COLORS; i++)
+    g_clear_object (&editor->saved_colors[i]);
+
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -615,7 +626,7 @@ gimp_gradient_editor_edit_left_color (GimpGradientEditor *editor)
                            GTK_WIDGET (editor),
                            gimp_dialog_factory_get_singleton (),
                            "gimp-gradient-editor-color-dialog",
-                           &editor->control_sel_l->left_color,
+                           editor->control_sel_l->left_color,
                            TRUE, TRUE);
 
   g_signal_connect (editor->color_dialog, "destroy",
@@ -660,7 +671,7 @@ gimp_gradient_editor_edit_right_color (GimpGradientEditor *editor)
                            GTK_WIDGET (editor),
                            gimp_dialog_factory_get_singleton (),
                            "gimp-gradient-editor-color-dialog",
-                           &editor->control_sel_l->right_color,
+                           editor->control_sel_l->right_color,
                            TRUE, TRUE);
 
   g_signal_connect (editor->color_dialog, "destroy",
@@ -838,7 +849,7 @@ static void
 gradient_editor_drop_color (GtkWidget     *widget,
                             gint           x,
                             gint           y,
-                            const GimpRGB *color,
+                            GeglColor     *color,
                             gpointer       data)
 {
   GimpGradientEditor  *editor = GIMP_GRADIENT_EDITOR (data);
@@ -863,25 +874,27 @@ gradient_editor_drop_color (GtkWidget     *widget,
     {
       lseg->right = xpos;
       lseg->middle = (lseg->left + lseg->right) / 2.0;
-      lseg->right_color = *color;
+      g_clear_object (&lseg->right_color);
+      lseg->right_color = gegl_color_duplicate (color);
     }
 
   if (rseg)
     {
       rseg->left = xpos;
       rseg->middle = (rseg->left + rseg->right) / 2.0;
-      rseg->left_color  = *color;
+      g_clear_object (&rseg->left_color);
+      rseg->left_color = gegl_color_duplicate (color);
     }
 
   gimp_data_thaw (GIMP_DATA (gradient));
 }
 
 static void
-gradient_editor_control_drop_color (GtkWidget     *widget,
-                                    gint           x,
-                                    gint           y,
-                                    const GimpRGB *color,
-                                    gpointer       data)
+gradient_editor_control_drop_color (GtkWidget *widget,
+                                    gint       x,
+                                    gint       y,
+                                    GeglColor *color,
+                                    gpointer   data)
 {
   GimpGradientEditor    *editor = GIMP_GRADIENT_EDITOR (data);
   GimpGradient          *gradient;
@@ -913,10 +926,16 @@ gradient_editor_control_drop_color (GtkWidget     *widget,
   gimp_data_freeze (GIMP_DATA (gradient));
 
   if (lseg)
-    lseg->right_color = *color;
+    {
+      g_clear_object (&lseg->right_color);
+      lseg->right_color = gegl_color_duplicate (color);
+    }
 
   if (rseg)
-    rseg->left_color  = *color;
+    {
+      g_clear_object (&rseg->left_color);
+      rseg->left_color = gegl_color_duplicate (color);
+    }
 
   gimp_data_thaw (GIMP_DATA (gradient));
 }
@@ -981,8 +1000,14 @@ gradient_editor_save_selection (GimpGradientEditor *editor)
     {
       seg = gimp_gradient_segment_new ();
 
+      g_clear_object (&seg->left_color);
+      g_clear_object (&seg->right_color);
+
       *seg = *oseg; /* Copy everything */
 
+      seg->left_color  = gegl_color_duplicate (oseg->left_color);
+      seg->right_color = gegl_color_duplicate (oseg->right_color);
+
       if (prev == NULL)
         tmp = seg; /* Remember first segment */
       else
@@ -1046,7 +1071,7 @@ gradient_editor_replace_selection (GimpGradientEditor  *editor,
 
 static void
 gradient_editor_left_color_update (GimpColorDialog      *dialog,
-                                   const GimpRGB        *color,
+                                   GeglColor            *color,
                                    GimpColorDialogState  state,
                                    GimpGradientEditor   *editor)
 {
@@ -1055,34 +1080,35 @@ gradient_editor_left_color_update (GimpColorDialog      *dialog,
   switch (state)
     {
     case GIMP_COLOR_DIALOG_UPDATE:
-      gimp_gradient_segment_range_blend (gradient,
-                                         editor->control_sel_l,
-                                         editor->control_sel_r,
-                                         color,
-                                         &editor->control_sel_r->right_color,
-                                         TRUE, TRUE);
       break;
 
     case GIMP_COLOR_DIALOG_OK:
-      gimp_gradient_segment_range_blend (gradient,
-                                         editor->control_sel_l,
-                                         editor->control_sel_r,
-                                         color,
-                                         &editor->control_sel_r->right_color,
-                                         TRUE, TRUE);
       gimp_gradient_segments_free (editor->saved_segments);
-      gtk_widget_destroy (editor->color_dialog);
-      editor->color_dialog = NULL;
-      gtk_widget_set_sensitive (GTK_WIDGET (editor), TRUE);
-      gimp_ui_manager_update (gimp_editor_get_ui_manager (GIMP_EDITOR (editor)),
-                              gimp_editor_get_popup_data (GIMP_EDITOR (editor)));
       break;
 
     case GIMP_COLOR_DIALOG_CANCEL:
       gradient_editor_replace_selection (editor, editor->saved_segments);
+
       if (! editor->saved_dirty)
         gimp_data_clean (GIMP_DATA (gradient));
       gimp_viewable_invalidate_preview (GIMP_VIEWABLE (gradient));
+      break;
+    }
+
+  gimp_gradient_segment_range_blend (gradient,
+                                     editor->control_sel_l,
+                                     editor->control_sel_r,
+                                     color,
+                                     editor->control_sel_r->right_color,
+                                     TRUE, TRUE);
+
+  switch (state)
+    {
+    case GIMP_COLOR_DIALOG_UPDATE:
+      break;
+
+    case GIMP_COLOR_DIALOG_OK:
+    case GIMP_COLOR_DIALOG_CANCEL:
       gtk_widget_destroy (editor->color_dialog);
       editor->color_dialog = NULL;
       gtk_widget_set_sensitive (GTK_WIDGET (editor), TRUE);
@@ -1094,7 +1120,7 @@ gradient_editor_left_color_update (GimpColorDialog      *dialog,
 
 static void
 gradient_editor_right_color_update (GimpColorDialog      *dialog,
-                                    const GimpRGB        *color,
+                                    GeglColor            *color,
                                     GimpColorDialogState  state,
                                     GimpGradientEditor   *editor)
 {
@@ -1103,34 +1129,34 @@ gradient_editor_right_color_update (GimpColorDialog      *dialog,
   switch (state)
     {
     case GIMP_COLOR_DIALOG_UPDATE:
-      gimp_gradient_segment_range_blend (gradient,
-                                         editor->control_sel_l,
-                                         editor->control_sel_r,
-                                         &editor->control_sel_l->left_color,
-                                         color,
-                                         TRUE, TRUE);
       break;
 
     case GIMP_COLOR_DIALOG_OK:
-      gimp_gradient_segment_range_blend (gradient,
-                                         editor->control_sel_l,
-                                         editor->control_sel_r,
-                                         &editor->control_sel_l->left_color,
-                                         color,
-                                         TRUE, TRUE);
       gimp_gradient_segments_free (editor->saved_segments);
-      gtk_widget_destroy (editor->color_dialog);
-      editor->color_dialog = NULL;
-      gtk_widget_set_sensitive (GTK_WIDGET (editor), TRUE);
-      gimp_ui_manager_update (gimp_editor_get_ui_manager (GIMP_EDITOR (editor)),
-                              gimp_editor_get_popup_data (GIMP_EDITOR (editor)));
       break;
 
     case GIMP_COLOR_DIALOG_CANCEL:
       gradient_editor_replace_selection (editor, editor->saved_segments);
+
       if (! editor->saved_dirty)
         gimp_data_clean (GIMP_DATA (gradient));
       gimp_viewable_invalidate_preview (GIMP_VIEWABLE (gradient));
+      break;
+    }
+
+  gimp_gradient_segment_range_blend (gradient,
+                                     editor->control_sel_l,
+                                     editor->control_sel_r,
+                                     editor->control_sel_l->left_color,
+                                     color,
+                                     TRUE, TRUE);
+  switch (state)
+    {
+    case GIMP_COLOR_DIALOG_UPDATE:
+      break;
+
+    case GIMP_COLOR_DIALOG_OK:
+    case GIMP_COLOR_DIALOG_CANCEL:
       gtk_widget_destroy (editor->color_dialog);
       editor->color_dialog = NULL;
       gtk_widget_set_sensitive (GTK_WIDGET (editor), TRUE);
@@ -1283,8 +1309,9 @@ view_set_hint (GimpGradientEditor *editor,
                gint                x)
 {
   GimpDataEditor *data_editor = GIMP_DATA_EDITOR (editor);
-  GimpRGB         rgb;
-  GimpHSV         hsv;
+  GeglColor      *color       = NULL;
+  gdouble         rgb[4];
+  gfloat          hsv[3];
   gdouble         xpos;
   gchar          *str1;
   gchar          *str2;
@@ -1295,23 +1322,28 @@ view_set_hint (GimpGradientEditor *editor,
 
   gimp_gradient_get_color_at (GIMP_GRADIENT (data_editor->data),
                               data_editor->context, NULL,
-                              xpos, FALSE, FALSE, &rgb);
+                              xpos, FALSE, FALSE, &color);
 
-  gimp_color_area_set_color (GIMP_COLOR_AREA (editor->current_color), &rgb);
+  gimp_color_area_set_color (GIMP_COLOR_AREA (editor->current_color), color);
 
-  gimp_rgb_to_hsv (&rgb, &hsv);
+  gegl_color_get_pixel (color, babl_format ("R'G'B'A double"), rgb);
+  gegl_color_get_pixel (color, babl_format ("HSV float"), hsv);
 
   str1 = g_strdup_printf (_("Position: %0.4f"), xpos);
-  str2 = g_strdup_printf (_("RGB (%0.3f, %0.3f, %0.3f)"),
-                          rgb.r, rgb.g, rgb.b);
+  /* TODO: Current hints are displaying sRGB values. Ideally we'd want to update
+   * the RGB space depending on the active image.
+   */
+  str2 = g_strdup_printf (_("sRGB (%0.3f, %0.3f, %0.3f)"),
+                          rgb[0], rgb[1], rgb[2]);
   str3 = g_strdup_printf (_("HSV (%0.1f, %0.1f, %0.1f)"),
-                          hsv.h * 360.0, hsv.s * 100.0, hsv.v * 100.0);
+                          hsv[0] * 360.0, hsv[1] * 100.0, hsv[2] * 100.0);
   str4 = g_strdup_printf (_("Luminance: %0.1f    Opacity: %0.1f"),
-                          GIMP_RGB_LUMINANCE (rgb.r, rgb.g, rgb.b) * 100.0,
-                          rgb.a * 100.0);
+                          GIMP_RGB_LUMINANCE (rgb[0], rgb[1], rgb[2]) * 100.0,
+                          rgb[3] * 100.0);
 
   gradient_editor_set_hint (editor, str1, str2, str3, str4);
 
+  g_object_unref (color);
   g_free (str1);
   g_free (str2);
   g_free (str3);
@@ -1325,7 +1357,8 @@ view_pick_color (GimpGradientEditor  *editor,
                  gint                 x)
 {
   GimpDataEditor *data_editor = GIMP_DATA_EDITOR (editor);
-  GimpRGB         color;
+  GeglColor      *color       = NULL;
+  gdouble         rgb[3];
   gdouble         xpos;
   gchar          *str2;
   gchar          *str3;
@@ -1336,30 +1369,32 @@ view_pick_color (GimpGradientEditor  *editor,
                               data_editor->context, NULL,
                               xpos, FALSE, FALSE, &color);
 
-  gimp_color_area_set_color (GIMP_COLOR_AREA (editor->current_color), &color);
+  gimp_color_area_set_color (GIMP_COLOR_AREA (editor->current_color), color);
 
-  str2 = g_strdup_printf (_("RGB (%d, %d, %d)"),
-                          (gint) (color.r * 255.0),
-                          (gint) (color.g * 255.0),
-                          (gint) (color.b * 255.0));
+  gegl_color_get_pixel (color, babl_format ("R'G'B' double"), rgb);
+  str2 = g_strdup_printf (_("sRGB (%d, %d, %d)"),
+                          (gint) (rgb[0] * 255.0),
+                          (gint) (rgb[1] * 255.0),
+                          (gint) (rgb[2] * 255.0));
 
-  str3 = g_strdup_printf ("(%0.3f, %0.3f, %0.3f)", color.r, color.g, color.b);
+  str3 = g_strdup_printf ("(%0.3f, %0.3f, %0.3f)", rgb[0], rgb[1], rgb[2]);
 
   if (pick_target == GIMP_COLOR_PICK_TARGET_FOREGROUND)
     {
-      gimp_context_set_foreground (data_editor->context, &color);
+      gimp_context_set_foreground (data_editor->context, color);
 
       gradient_editor_set_hint (editor, _("Foreground color set to:"),
                                 str2, str3, NULL);
     }
   else
     {
-      gimp_context_set_background (data_editor->context, &color);
+      gimp_context_set_background (data_editor->context, color);
 
       gradient_editor_set_hint (editor, _("Background color set to:"),
                                 str2, str3, NULL);
     }
 
+  g_object_unref (color);
   g_free (str2);
   g_free (str3);
 }
