@@ -46,14 +46,14 @@
 /*  local function prototypes  */
 
 static void   color_area_foreground_changed (GimpContext          *context,
-                                             const GimpRGB        *color,
+                                             GeglColor            *color,
                                              GimpColorDialog      *dialog);
 static void   color_area_background_changed (GimpContext          *context,
-                                             const GimpRGB        *color,
+                                             GeglColor            *color,
                                              GimpColorDialog      *dialog);
 
 static void   color_area_dialog_update      (GimpColorDialog      *dialog,
-                                             const GimpRGB        *color,
+                                             GeglColor            *color,
                                              GimpColorDialogState  state,
                                              GimpContext          *context);
 
@@ -73,8 +73,8 @@ static GtkWidget       *color_area          = NULL;
 static GtkWidget       *color_dialog        = NULL;
 static gboolean         color_dialog_active = FALSE;
 static GimpActiveColor  edit_color          = GIMP_ACTIVE_COLOR_FOREGROUND;
-static GimpRGB          revert_fg;
-static GimpRGB          revert_bg;
+static GeglColor       *revert_fg           = NULL;
+static GeglColor       *revert_bg           = NULL;
 
 
 /*  public functions  */
@@ -122,7 +122,7 @@ gimp_toolbox_color_area_create (GimpToolbox *toolbox,
 
 static void
 color_area_foreground_changed (GimpContext     *context,
-                               const GimpRGB   *color,
+                               GeglColor       *color,
                                GimpColorDialog *dialog)
 {
   if (edit_color == GIMP_ACTIVE_COLOR_FOREGROUND)
@@ -131,9 +131,7 @@ color_area_foreground_changed (GimpContext     *context,
                                        color_area_dialog_update,
                                        context);
 
-      /* FIXME this should use GimpColorDialog API */
-      gimp_color_selection_set_color (GIMP_COLOR_SELECTION (dialog->selection),
-                                      color);
+      gimp_color_dialog_set_color (dialog, color);
 
       g_signal_handlers_unblock_by_func (dialog,
                                          color_area_dialog_update,
@@ -143,7 +141,7 @@ color_area_foreground_changed (GimpContext     *context,
 
 static void
 color_area_background_changed (GimpContext     *context,
-                               const GimpRGB   *color,
+                               GeglColor       *color,
                                GimpColorDialog *dialog)
 {
   if (edit_color == GIMP_ACTIVE_COLOR_BACKGROUND)
@@ -152,9 +150,7 @@ color_area_background_changed (GimpContext     *context,
                                        color_area_dialog_update,
                                        context);
 
-      /* FIXME this should use GimpColorDialog API */
-      gimp_color_selection_set_color (GIMP_COLOR_SELECTION (dialog->selection),
-                                      color);
+      gimp_color_dialog_set_color (dialog, color);
 
       g_signal_handlers_unblock_by_func (dialog,
                                          color_area_dialog_update,
@@ -164,7 +160,7 @@ color_area_background_changed (GimpContext     *context,
 
 static void
 color_area_dialog_update (GimpColorDialog      *dialog,
-                          const GimpRGB        *color,
+                          GeglColor            *color,
                           GimpColorDialogState  state,
                           GimpContext          *context)
 {
@@ -205,8 +201,8 @@ color_area_dialog_update (GimpColorDialog      *dialog,
     case GIMP_COLOR_DIALOG_CANCEL:
       gtk_widget_hide (color_dialog);
       color_dialog_active = FALSE;
-      gimp_context_set_foreground (context, &revert_fg);
-      gimp_context_set_background (context, &revert_bg);
+      gimp_context_set_foreground (context, revert_fg);
+      gimp_context_set_background (context, revert_bg);
       break;
     }
 
@@ -219,23 +215,26 @@ color_area_color_clicked (GimpFgBgEditor  *editor,
                           GimpActiveColor  active_color,
                           GimpContext     *context)
 {
-  GimpRGB      color;
+  GeglColor   *color;
   const gchar *title;
 
   if (! color_dialog_active)
     {
-      gimp_context_get_foreground (context, &revert_fg);
-      gimp_context_get_background (context, &revert_bg);
+      g_clear_object (&revert_fg);
+      revert_fg = gegl_color_duplicate (gimp_context_get_foreground (context));
+
+      g_clear_object (&revert_bg);
+      revert_bg = gegl_color_duplicate (gimp_context_get_background (context));
     }
 
   if (active_color == GIMP_ACTIVE_COLOR_FOREGROUND)
     {
-      gimp_context_get_foreground (context, &color);
+      color = gimp_context_get_foreground (context);
       title = _("Change Foreground Color");
     }
   else
     {
-      gimp_context_get_background (context, &color);
+      color = gimp_context_get_background (context);
       title = _("Change Background Color");
     }
 
@@ -248,8 +247,7 @@ color_area_color_clicked (GimpFgBgEditor  *editor,
                                             GTK_WIDGET (editor),
                                             gimp_dialog_factory_get_singleton (),
                                             "gimp-toolbox-color-dialog",
-                                            &color,
-                                            TRUE, FALSE);
+                                            color, TRUE, FALSE);
 
       g_signal_connect_object (color_dialog, "update",
                                G_CALLBACK (color_area_dialog_update),
@@ -271,7 +269,7 @@ color_area_color_clicked (GimpFgBgEditor  *editor,
     }
 
   gtk_window_set_title (GTK_WINDOW (color_dialog), title);
-  gimp_color_dialog_set_color (GIMP_COLOR_DIALOG (color_dialog), &color);
+  gimp_color_dialog_set_color (GIMP_COLOR_DIALOG (color_dialog), color);
 
   gtk_window_present (GTK_WINDOW (color_dialog));
   color_dialog_active = TRUE;
