@@ -80,10 +80,6 @@
 #  undef RGB
 #endif
 
-#ifdef GDK_WINDOWING_QUARTZ
-#include <Cocoa/Cocoa.h>
-#endif
-
 #include <locale.h>
 
 #include "gimp.h"
@@ -133,6 +129,7 @@ static gboolean            _export_exif          = FALSE;
 static gboolean            _export_xmp           = FALSE;
 static gboolean            _export_iptc          = FALSE;
 static gboolean            _export_thumbnail     = TRUE;
+static gboolean            _update_metadata      = TRUE;
 static gint32              _num_processors       = 1;
 static GimpCheckSize       _check_size           = GIMP_CHECK_SIZE_MEDIUM_CHECKS;
 static GimpCheckType       _check_type           = GIMP_CHECK_TYPE_GRAY_CHECKS;
@@ -200,15 +197,6 @@ gimp_main (GType  plug_in_type,
 
   gint i, j, k;
 
-  /* Make plugins output available on console */
-  if (AttachConsole (ATTACH_PARENT_PROCESS) != 0 && ! g_getenv ("TERM") && ! g_getenv ("SHELL"))
-    {
-      /* 'r' is needed to prevent interleaving and '+' to support colors */
-      freopen ("CONOUT$", "r+", stdout);
-      freopen ("CONOUT$", "r+", stderr);
-      _flushall ();
-    }
-
   /* Reduce risks */
   SetDllDirectoryW (L"");
 
@@ -239,33 +227,16 @@ gimp_main (GType  plug_in_type,
   /* Use Dr. Mingw (dumps backtrace on crash) if it is available. */
   {
     time_t   t;
-#ifdef ENABLE_RELOCATABLE_RESOURCES
-    gchar   *plugin_dir;
-    size_t   codeview_path_len;
     gchar   *codeview_path;
-#endif
     gchar   *filename;
     gchar   *dir;
     wchar_t *plug_in_backtrace_path_utf16;
 
-#ifdef ENABLE_RELOCATABLE_RESOURCES
-    /* FIXME: https://github.com/jrfonseca/drmingw/issues/91
-     * FIXME: This needs to take into account the plugin path
-    plugin_dir = ???
-    codeview_path_len = strlen (g_getenv ("_NT_SYMBOL_PATH") ? g_getenv ("_NT_SYMBOL_PATH") : "") + strlen (plugin_dir) + 2;
-    codeview_path = g_try_malloc (codeview_path_len);
-    if (codeview_path == NULL)
-      {
-        g_warning ("Failed to allocate memory");
-      }
-    if (g_getenv ("_NT_SYMBOL_PATH"))
-      g_snprintf (codeview_path, codeview_path_len, "%s;%s", plugin_dir, g_getenv ("_NT_SYMBOL_PATH"));
-    else
-      g_snprintf (codeview_path, codeview_path_len, "%s", plugin_dir);
+    /* FIXME: https://github.com/jrfonseca/drmingw/issues/91 */
+    codeview_path = g_build_filename (gimp_installation_directory (),
+                                      "bin", NULL);
     g_setenv ("_NT_SYMBOL_PATH", codeview_path, TRUE);
     g_free (codeview_path);
-    g_free (plugin_dir);*/
-#endif
 
     /* This has to be the non-roaming directory (i.e., the local
      * directory) as backtraces correspond to the binaries on this
@@ -366,14 +337,6 @@ gimp_main (GType  plug_in_type,
 
 #endif /* G_OS_WIN32 */
 
-#ifdef GDK_WINDOWING_QUARTZ
-  /* Sets activation policy to prevent plugins from appearing as separate apps
-   * in Dock.
-   * Makes plugins behave as helper processes of GIMP on macOS.
-   */
-  [NSApp setActivationPolicy:NSApplicationActivationPolicyAccessory];
-#endif
-
   g_assert (plug_in_type != G_TYPE_NONE);
 
   if ((argc != N_ARGS) || (strcmp (argv[ARG_GIMP], "-gimp") != 0))
@@ -486,6 +449,7 @@ gimp_main (GType  plug_in_type,
       GIMP_TYPE_DRAWABLE,          GIMP_TYPE_PARAM_DRAWABLE,
       GIMP_TYPE_LAYER,             GIMP_TYPE_PARAM_LAYER,
       GIMP_TYPE_TEXT_LAYER,        GIMP_TYPE_PARAM_TEXT_LAYER,
+      GIMP_TYPE_VECTOR_LAYER,      GIMP_TYPE_PARAM_VECTOR_LAYER,
       GIMP_TYPE_GROUP_LAYER,       GIMP_TYPE_PARAM_GROUP_LAYER,
       GIMP_TYPE_CHANNEL,           GIMP_TYPE_PARAM_CHANNEL,
       GIMP_TYPE_LAYER_MASK,        GIMP_TYPE_PARAM_LAYER_MASK,
@@ -785,6 +749,28 @@ gimp_export_thumbnail (void)
   return _export_thumbnail;
 }
 
+/**
+ * gimp_update_metadata:
+ *
+ * Returns whether file plug-ins should update the
+ * image's metadata.
+ *
+ * Note that metadata that reflects the image characteristics
+ * will still be updated even if this is set to FALSE. This only
+ * concerns metadata changes that are nonessential, like setting
+ * GIMP in Exif.Image.Software, synchronizing the comment with its
+ * equivalent metadata tags, etc.
+ *
+ * Returns: TRUE if preferences are set to update the metadata.
+ *
+ * Since: 3.1
+ **/
+gboolean
+gimp_update_metadata (void)
+{
+  return _update_metadata;
+}
+
 /**
  * gimp_get_num_processors:
  *
@@ -1128,6 +1114,7 @@ _gimp_config (GPConfig *config)
   _export_exif          = config->export_exif      ? TRUE : FALSE;
   _export_xmp           = config->export_xmp       ? TRUE : FALSE;
   _export_iptc          = config->export_iptc      ? TRUE : FALSE;
+  _update_metadata      = config->update_metadata  ? TRUE : FALSE;
   _export_comment       = config->export_comment;
   _num_processors       = config->num_processors;
   _default_display_id   = config->default_display_id;
@@ -1154,6 +1141,11 @@ _gimp_config (GPConfig *config)
                 "application-license", "GPL3",
                 NULL);
 
+  /* XXX Running gegl_init() before gegl_config() is not appreciated by
+   * GEGL and generates a bunch of CRITICALs.
+   */
+  babl_init ();
+
   g_clear_object (&_check_custom_color1);
   _check_custom_color1 = gegl_color_new (NULL);
   pixel = g_bytes_get_data (config->check_custom_color1, &bpp);
