@@ -289,17 +289,6 @@ gimp_plug_in_class_init (GimpPlugInClass *klass)
                         G_PARAM_CONSTRUCT_ONLY);
 
   g_object_class_install_properties (object_class, N_PROPS, props);
-
-  /* libgimp creates GeglColor-s in _gimp_config(), which requires at
-   * least babl to be initialized.
-   * We don't call gegl_init() because gegl_config() does not appreciate
-   * being called after, which generates a bunch of CRITICALs (see
-   * commit b06fe36970c and gegl#427).
-   * Therefore gegl_init() still needs to be called manually by plug-ins
-   * if necessary (it is called by gimp_ui_init() too, but this only
-   * applies to GUI plug-ins).
-   */
-  babl_init ();
 }
 
 static void
@@ -1812,6 +1801,12 @@ _gimp_plug_in_get_item (GimpPlugIn *plug_in,
                                "id", item_id,
                                NULL);
         }
+      else if (gimp_item_id_is_vector_layer (item_id))
+        {
+          item = g_object_new (GIMP_TYPE_VECTOR_LAYER,
+                               "id", item_id,
+                               NULL);
+        }
       else if (gimp_item_id_is_group_layer (item_id))
         {
           item = g_object_new (GIMP_TYPE_GROUP_LAYER,
