@@ -426,7 +426,8 @@ gimp_procedure_config_save_metadata (GimpProcedureConfig *config,
             }
         }
 
-      if ((priv->metadata_flags & GIMP_METADATA_SAVE_COMMENT))
+      if (gimp_update_metadata () &&
+          (priv->metadata_flags & GIMP_METADATA_SAVE_COMMENT))
         {
           gchar *comment_value = NULL;
           gint   len;
