@@ -382,7 +382,7 @@ typedef enum
   GIMP_FILL_CIELAB_MIDDLE_GRAY, /*< desc="Middle Gray (CIELAB)" >*/
   GIMP_FILL_WHITE,              /*< desc="White"            >*/
   GIMP_FILL_TRANSPARENT,        /*< desc="Transparency"     >*/
-  GIMP_FILL_PATTERN             /*< desc="Pattern"          >*/
+  GIMP_FILL_PATTERN,            /*< desc="Pattern"          >*/
 } GimpFillType;
 
 
