@@ -33,9 +33,7 @@
 #include <string.h>
 #include <math.h>
 
-#define _WIN32_WINNT 0x0501
 #include <windows.h>
-#define DIRECTINPUT_VERSION 0x0800
 #include <dinput.h>
 
 #include <gegl.h>
