@@ -27,8 +27,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#ifndef __GIMP_COLOR_WHEEL_H__
-#define __GIMP_COLOR_WHEEL_H__
+#pragma once
 
 G_BEGIN_DECLS
 
@@ -77,9 +76,9 @@ void        gimp_color_wheel_set_color         (GimpColorWheel  *wheel,
                                                 double           s,
                                                 double           v);
 void        gimp_color_wheel_get_color         (GimpColorWheel  *wheel,
-                                                gdouble         *h,
-                                                gdouble         *s,
-                                                gdouble         *v);
+                                                gfloat          *h,
+                                                gfloat          *s,
+                                                gfloat          *v);
 
 void        gimp_color_wheel_set_ring_fraction (GimpColorWheel  *wheel,
                                                 gdouble          fraction);
@@ -93,5 +92,3 @@ void        gimp_color_wheel_set_color_config  (GimpColorWheel  *wheel,
 gboolean    gimp_color_wheel_is_adjusting      (GimpColorWheel  *wheel);
 
 G_END_DECLS
-
-#endif /* __GIMP_COLOR_WHEEL_H__ */
