@@ -381,6 +381,16 @@ gimp_param_spec_text_layer ("$name",
                             "$blurb",
                             $none_ok,
                             $flags)
+CODE
+    }
+    elsif ($pdbtype eq 'vector_layer') {
+	$none_ok = exists $arg->{none_ok} ? 'TRUE' : 'FALSE';
+	$pspec = <<CODE;
+gimp_param_spec_vector_layer ("$name",
+                              "$nick",
+                              "$blurb",
+                              $none_ok,
+                              $flags)
 CODE
     }
     elsif ($pdbtype eq 'layer') {
@@ -952,7 +962,7 @@ CODE
         if ($proc->{deprecated}) {
 	    $out->{register} .= <<CODE;
   gimp_procedure_set_deprecated (procedure,
-                                 "$proc->{deprecated}");
+                                 "\"$proc->{deprecated}\"");
 CODE
 	}
 
@@ -1111,6 +1121,9 @@ GPL
 		elsif (!/libgimp/) {
 		    s/^/~/;
 		}
+		elsif (/libgimp[a-z]/) {
+		    s/^/"/;
+                }
 	    }
 	    $x cmp $y;
 	} keys %{$out->{headers}};
@@ -1137,7 +1150,7 @@ GPL
 
 	    $seen = 0 if !/^</;
 
-	    if (/libgimp/) {
+	    if (/libgimp[a-z]/) {
 		$lib = 1;
 	    }
 	    else {
@@ -1209,10 +1222,9 @@ GPL
 	my $internal = "$builddir/internal-procs.h$FILE_EXT";
 	open IFILE, "> $internal" or die "Can't open $internal: $!\n";
 	print IFILE $gpl;
-	my $guard = "__INTERNAL_PROCS_H__";
 	print IFILE <<HEADER;
-#ifndef $guard
-#define $guard
+#pragma once
+
 
 HEADER
 
@@ -1222,11 +1234,6 @@ HEADER
 	foreach (@group_decls) {
 	    print IFILE "void   $_" . ' ' x ($longest - length $_) . " (GimpPDB *pdb);\n";
 	}
-
-	print IFILE <<HEADER;
-
-#endif /* $guard */
-HEADER
 	close IFILE;
 	&write_file($internal, $destdir);
 
