@@ -371,6 +371,18 @@ package Gimp::CodeGen::pdb;
 		     take_value_func => 'g_value_set_object ($value, $var)',
 		     headers         => [ qw("text/gimptextlayer.h") ] },
 
+    vector_layer  => { name          => 'VECTOR_LAYER',
+		     gtype           => 'GIMP_TYPE_VECTOR_LAYER',
+		     type            => 'GimpVectorLayer *',
+		     const_type      => 'GimpVectorLayer *',
+		     init_value      => 'NULL',
+		     out_annotate    => '(transfer none)',
+		     get_value_func  => '$var = g_value_get_object ($value)',
+		     dup_value_func  => '$var = GIMP_VALUES_GET_VECTOR_LAYER ($value)',
+		     set_value_func  => 'g_value_set_object ($value, $var)',
+		     take_value_func => 'g_value_set_object ($value, $var)',
+		     headers         => [ qw("path/gimpvectorlayer.h") ] },
+
     group_layer => { name            => 'GROUP_LAYER',
 		     gtype           => 'GIMP_TYPE_GROUP_LAYER',
 		     type            => 'GimpGroupLayer *',
@@ -441,7 +453,7 @@ package Gimp::CodeGen::pdb;
 		     dup_value_func  => '$var = GIMP_VALUES_GET_PATH ($value)',
 		     set_value_func  => 'g_value_set_object ($value, $var)',
 		     take_value_func => 'g_value_set_object ($value, $var)',
-		     headers         => [ qw("vectors/gimppath.h") ] },
+		     headers         => [ qw("path/gimppath.h") ] },
 
     filter      => { name            => 'DRAWABLE_FILTER',
 		     gtype           => 'GIMP_TYPE_DRAWABLE_FILTER',
@@ -464,7 +476,7 @@ package Gimp::CodeGen::pdb;
 		     get_value_func  => '$var = g_value_get_object ($value)',
 		     dup_value_func  => '$var = GIMP_VALUES_DUP_FILE ($value)',
 		     set_value_func  => 'g_value_set_object ($value, $var)',
-		     take_value_func => 'g_value_take_object ($value, $var)' },
+		     take_value_func => 'g_value_set_object ($value, $var)' },
 
     parasite    => { name            => 'PARASITE',
 		     gtype           => 'GIMP_TYPE_PARASITE',
