@@ -85,7 +85,7 @@ struct _AlignLayersClass
 
 
 #define ALIGN_LAYERS_TYPE  (align_layers_get_type ())
-#define ALIGN_LAYERS (obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ALIGN_LAYERS_TYPE, AlignLayers))
+#define ALIGN_LAYERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ALIGN_LAYERS_TYPE, AlignLayers))
 
 GType                   align_layers_get_type               (void) G_GNUC_CONST;
 
@@ -96,9 +96,8 @@ static GimpProcedure  * align_layers_create_procedure       (GimpPlugIn
 static GimpValueArray * align_layers_run                    (GimpProcedure        *procedure,
                                                              GimpRunMode           run_mode,
                                                              GimpImage            *image,
-                                                             gint                  n_drawables,
                                                              GimpDrawable        **drawables,
-                                                             const GimpValueArray *args,
+                                                             GimpProcedureConfig  *config,
                                                              gpointer              run_data);
 
 
@@ -177,66 +176,80 @@ align_layers_create_procedure (GimpPlugIn  *plug_in,
                                            GIMP_PROCEDURE_SENSITIVE_NO_DRAWABLES);
 
       gimp_procedure_set_menu_label (procedure, _("Align Visi_ble Layers..."));
-      gimp_procedure_add_menu_path (procedure, "<Image>/Image/Arrange");
+      gimp_procedure_add_menu_path (procedure, "<Image>/Image/[Arrange]");
 
       gimp_procedure_set_documentation (procedure,
                                         _("Align all visible layers of the image"),
-                                        "Align visible layers",
+                                        _("Align visible layers"),
                                         name);
       gimp_procedure_set_attribution (procedure,
                                       "Shuji Narazaki <narazaki@InetQ.or.jp>",
                                       "Shuji Narazaki",
                                       "1997");
 
-      GIMP_PROC_ARG_INT (procedure, "horizontal-style",
-                         _("_Horizontal style"),
-                         _("(None = 0, Collect = 1, "
-                           "Fill left to right = 2, Fill right to left = 3, "
-                           "Snap to grid = 4)"),
-                         H_NONE, SNAP2HGRID, H_NONE,
-                         GIMP_PARAM_READWRITE);
+      gimp_procedure_add_choice_argument (procedure, "horizontal-style",
+                                          _("_Horizontal style"),
+                                          "",
+                                          gimp_choice_new_with_values ("none",               H_NONE,     _("None"),                 NULL,
+                                                                       "collect",            H_COLLECT,  _("Collect"),              NULL,
+                                                                       "fill-left-to-right", LEFT2RIGHT, _("Fill (left to right)"), NULL,
+                                                                       "fill-right-to-left", RIGHT2LEFT, _("Fill (right to left)"), NULL,
+                                                                       "snap-to-grid",       SNAP2HGRID, _("Snap to grid"),         NULL,
+                                                                       NULL),
+                                          "none",
+                                          G_PARAM_READWRITE);
 
-      GIMP_PROC_ARG_INT (procedure, "horizontal-base",
-                         _("Hori_zontal base"),
-                         _("(Left edge = 0, Center = 1, "
-                           "Right edge = 2)"),
-                         H_BASE_LEFT, H_BASE_RIGHT, H_BASE_LEFT,
-                         GIMP_PARAM_READWRITE);
+      gimp_procedure_add_choice_argument (procedure, "horizontal-base",
+                                          _("Hori_zontal base"),
+                                          "",
+                                          gimp_choice_new_with_values ("left-edge",  H_BASE_LEFT,   _("Left edge"),  NULL,
+                                                                       "center",     H_BASE_CENTER, _("Center"),     NULL,
+                                                                       "right-edge", H_BASE_RIGHT,  _("Right edge"), NULL,
+                                                                       NULL),
+                                          "left-edge",
+                                          G_PARAM_READWRITE);
 
-      GIMP_PROC_ARG_INT (procedure, "vertical-style",
-                         _("_Vertical style"),
-                         _("(None = 0, Collect = 1, "
-                           "Fill left to right = 2, Fill right to left = 3, "
-                           "Snap to grid = 4)"),
-                         V_NONE, SNAP2VGRID, V_NONE,
-                         GIMP_PARAM_READWRITE);
+      gimp_procedure_add_choice_argument (procedure, "vertical-style",
+                                          _("_Vertical style"),
+                                          "",
+                                          gimp_choice_new_with_values ("none",               V_NONE,     _("None"),                 NULL,
+                                                                       "collect",            V_COLLECT,  _("Collect"),              NULL,
+                                                                       "fill-left-to-right", TOP2BOTTOM, _("Fill (top to bottom)"), NULL,
+                                                                       "fill-right-to-left", BOTTOM2TOP, _("Fill (bottom to top)"), NULL,
+                                                                       "snap-to-grid",       SNAP2VGRID, _("Snap to grid"),         NULL,
+                                                                       NULL),
+                                          "none",
+                                          G_PARAM_READWRITE);
 
-      GIMP_PROC_ARG_INT (procedure, "vertical-base",
-                         _("Ver_tical base"),
-                         _("(Left edge = 0, Center = 1, "
-                           "Right edge = 2)"),
-                         V_BASE_TOP, V_BASE_BOTTOM, V_BASE_TOP,
-                         GIMP_PARAM_READWRITE);
+      gimp_procedure_add_choice_argument (procedure, "vertical-base",
+                                          _("Ver_tical base"),
+                                          "",
+                                          gimp_choice_new_with_values ("top-edge",    V_BASE_TOP,     _("Top edge"),    NULL,
+                                                                       "center",      V_BASE_CENTER,  _("Center"),      NULL,
+                                                                       "bottom-edge", V_BASE_BOTTOM,  _("Bottom edge"), NULL,
+                                                                       NULL),
+                                          "top-edge",
+                                          G_PARAM_READWRITE);
 
-      GIMP_PROC_ARG_INT (procedure, "grid-size",
-                         _("_Grid"),
-                         _("Grid"),
-                         1, 200, 10,
-                         GIMP_PARAM_READWRITE);
+      gimp_procedure_add_int_argument (procedure, "grid-size",
+                                       _("_Grid"),
+                                       _("Grid"),
+                                       1, 200, 10,
+                                       GIMP_PARAM_READWRITE);
 
-      GIMP_PROC_ARG_BOOLEAN (procedure,
-                             "ignore-bottom-layer",
-                             _("Ignore the _bottom layer even if visible"),
-                             _("Ignore the bottom layer even if visible"),
-                             TRUE,
-                             G_PARAM_READWRITE);
+      gimp_procedure_add_boolean_argument (procedure,
+                                           "ignore-bottom-layer",
+                                           _("Ignore the _bottom layer even if visible"),
+                                           _("Ignore the bottom layer even if visible"),
+                                           TRUE,
+                                           G_PARAM_READWRITE);
 
-      GIMP_PROC_ARG_BOOLEAN (procedure,
-                             "use-bottom-layer",
-                             _("_Use the (invisible) bottom layer as the base"),
-                             _("Use the (invisible) bottom layer as the base"),
-                             FALSE,
-                             G_PARAM_READWRITE);
+      gimp_procedure_add_boolean_argument (procedure,
+                                           "use-bottom-layer",
+                                           _("_Use the (invisible) bottom layer as the base"),
+                                           _("Use the (invisible) bottom layer as the base"),
+                                           FALSE,
+                                           G_PARAM_READWRITE);
 
       /* TODO: these 2 arguments existed in the original procedure but
        * were actually unused. If we want to keep them, let's at least
@@ -244,16 +257,16 @@ align_layers_create_procedure (GimpPlugIn  *plug_in,
        * them.
        */
       /*
-      GIMP_PROC_ARG_BOOLEAN (procedure,
-                             "link-after-alignment",
-                             "Link the visible layers after alignment",
-                             FALSE,
-                             G_PARAM_READWRITE);
-      GIMP_PROC_ARG_BOOLEAN (procedure,
-                             "use-bottom",
-                             "use the bottom layer as the base of alignment",
-                             TRUE,
-                             G_PARAM_READWRITE);
+      gimp_procedure_add_boolean_argument (procedure,
+                                           "link-after-alignment",
+                                           "Link the visible layers after alignment",
+                                           FALSE,
+                                           G_PARAM_READWRITE);
+      gimp_procedure_add_boolean_argument (procedure,
+                                           "use-bottom",
+                                           "use the bottom layer as the base of alignment",
+                                           TRUE,
+                                           G_PARAM_READWRITE);
                              */
     }
 
@@ -264,20 +277,15 @@ static GimpValueArray *
 align_layers_run (GimpProcedure        *procedure,
                   GimpRunMode           run_mode,
                   GimpImage            *image,
-                  gint                  n_drawables,
                   GimpDrawable        **drawables,
-                  const GimpValueArray *args,
+                  GimpProcedureConfig  *config,
                   gpointer              run_data)
 {
-  GimpProcedureConfig *config;
-  GimpValueArray      *return_vals = NULL;
-  GimpPDBStatusType    status      = GIMP_PDB_EXECUTION_ERROR;
-  GError              *error       = NULL;
-  GList               *layers;
-  gint                 layer_num;
-
-  config = gimp_procedure_create_config (procedure);
-  gimp_procedure_config_begin_run (config, NULL, run_mode, args);
+  GimpValueArray    *return_vals = NULL;
+  GimpPDBStatusType  status      = GIMP_PDB_EXECUTION_ERROR;
+  GError            *error       = NULL;
+  GList             *layers;
+  gint               layer_num;
 
   switch ( run_mode )
     {
@@ -312,11 +320,7 @@ align_layers_run (GimpProcedure        *procedure,
         gimp_displays_flush ();
     }
 
-  gimp_procedure_config_end_run (config, status);
-  g_object_unref (config);
-
-  return_vals = gimp_procedure_new_return_values (procedure, status,
-                                                  error);
+  return_vals = gimp_procedure_new_return_values (procedure, status, error);
 
   return return_vals;
 }
@@ -536,10 +540,13 @@ align_layers_gather_data (GimpLayer **layers,
   gboolean  use_bottom_layer;
 
   g_object_get (config,
-                "horizontal-style", &horizontal_style,
-                "vertical-style",   &vertical_style,
                 "use-bottom-layer", &use_bottom_layer,
                 NULL);
+  horizontal_style = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
+                                                          "horizontal-style");
+  vertical_style = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
+                                                        "vertical-style");
+
 
   data.step_x = 0;
   data.step_y = 0;
@@ -609,10 +616,12 @@ align_layers_perform_alignment (GimpLayer **layers,
   gint grid_size;
 
   g_object_get (config,
-                "horizontal-style", &horizontal_style,
-                "vertical-style",   &vertical_style,
-                "grid-size",        &grid_size,
+                "grid-size", &grid_size,
                 NULL);
+  horizontal_style = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
+                                                          "horizontal-style");
+  vertical_style = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
+                                                        "vertical-style");
 
   for (index = 0; index < layer_num; index++)
     {
@@ -686,10 +695,10 @@ align_layers_get_align_offsets (GimpDrawable *drawable,
   gint horizontal_base;
   gint vertical_base;
 
-  g_object_get (config,
-                "horizontal-base", &horizontal_base,
-                "vertical-base",   &vertical_base,
-                NULL);
+  horizontal_base = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
+                                                         "horizontal-base");
+  vertical_base = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
+                                                       "vertical-base");
 
   switch (horizontal_base)
     {
@@ -728,9 +737,8 @@ static int
 align_layers_dialog (GimpProcedure *procedure,
                      GObject       *config)
 {
-  GtkWidget    *dialog;
-  GtkListStore *store;
-  gboolean      run;
+  GtkWidget *dialog;
+  gboolean   run;
 
   gimp_ui_init (PLUG_IN_BINARY);
 
@@ -738,49 +746,6 @@ align_layers_dialog (GimpProcedure *procedure,
                                       GIMP_PROCEDURE_CONFIG (config),
                                       _("Align Visible Layers"));
 
-  gimp_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
-                                            GTK_RESPONSE_OK,
-                                            GTK_RESPONSE_CANCEL,
-                                            -1);
-
-  gimp_window_set_transient (GTK_WINDOW (dialog));
-
-  store = gimp_int_store_new (_("None"),                 H_NONE,
-                              _("Collect"),              H_COLLECT,
-                              _("Fill (left to right)"), LEFT2RIGHT,
-                              _("Fill (right to left)"), RIGHT2LEFT,
-                              _("Snap to grid"),         SNAP2HGRID,
-                              NULL);
-  gimp_procedure_dialog_get_int_combo (GIMP_PROCEDURE_DIALOG (dialog),
-                                       "horizontal-style",
-                                       GIMP_INT_STORE (store));
-
-  store = gimp_int_store_new (_("Left edge"),  H_BASE_LEFT,
-                              _("Center"),     H_BASE_CENTER,
-                              _("Right edge"), H_BASE_RIGHT,
-                              NULL);
-  gimp_procedure_dialog_get_int_combo (GIMP_PROCEDURE_DIALOG (dialog),
-                                       "horizontal-base",
-                                       GIMP_INT_STORE (store));
-
-  store = gimp_int_store_new (_("None"),                 V_NONE,
-                              _("Collect"),              V_COLLECT,
-                              _("Fill (top to bottom)"), TOP2BOTTOM,
-                              _("Fill (bottom to top)"), BOTTOM2TOP,
-                              _("Snap to grid"),         SNAP2VGRID,
-                              NULL);
-  gimp_procedure_dialog_get_int_combo (GIMP_PROCEDURE_DIALOG (dialog),
-                                       "vertical-style",
-                                       GIMP_INT_STORE (store));
-
-  store = gimp_int_store_new (_("Top edge"),    V_BASE_TOP,
-                              _("Center"),      V_BASE_CENTER,
-                              _("Bottom edge"), V_BASE_BOTTOM,
-                              NULL);
-  gimp_procedure_dialog_get_int_combo (GIMP_PROCEDURE_DIALOG (dialog),
-                                       "vertical-base",
-                                       GIMP_INT_STORE (store));
-
   gimp_procedure_dialog_get_scale_entry (GIMP_PROCEDURE_DIALOG (dialog),
                                          "grid-size", 1.0);
 
