@@ -41,6 +41,7 @@
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
+#include "libgimpbase/gimpversion-private.h"
 #include "libgimp/stdplugins-intl.h"
 
 
@@ -861,17 +862,13 @@ static GeglBuffer *
 get_buffer_with_filters (GimpLayer *layer)
 {
   GimpImage  *image = gimp_item_get_image (GIMP_ITEM (layer));
-  GimpImage  *tmp_image;
-  GimpLayer  *temp;
+  GimpLayer  *temp  = gimp_layer_copy (layer);
   GeglBuffer *src_buffer;
   GeglBuffer *dst_buffer;
 
-  tmp_image = gimp_image_new (gimp_image_get_width (image),
-                              gimp_image_get_height (image),
-                              gimp_image_get_base_type (image));
-  temp = gimp_layer_new_from_drawable (GIMP_DRAWABLE (layer), tmp_image);
-
-  gimp_image_insert_layer (tmp_image, temp, NULL, 0);
+  gimp_image_insert_layer (image, temp, NULL,
+                           gimp_image_get_item_position (image,
+                                                         GIMP_ITEM (layer)));
 
   gimp_drawable_merge_filters (GIMP_DRAWABLE (temp));
 
@@ -881,8 +878,8 @@ get_buffer_with_filters (GimpLayer *layer)
 
   gegl_buffer_copy (src_buffer, NULL, GEGL_ABYSS_NONE, dst_buffer, NULL);
 
+  gimp_image_remove_layer (image, temp);
   g_object_unref (src_buffer);
-  gimp_image_delete (tmp_image);
 
   return dst_buffer;
 }
@@ -1040,6 +1037,7 @@ compose (const gchar         *compose_type,
         }
     }
 
+  GIMP_WARNING_API_BREAK("Update 'decompose-type' choices? See discussion in MR !2424.")
   /* TODO: The strings used in decompose.c's "decompose-type" do not match
    * the values of compose_type for YCbCr values. We'll need to wait until
    * the next API break to fix. For now, we can do additional checks if the
