@@ -471,8 +471,6 @@ jp2_create_procedure (GimpPlugIn  *plug_in,
                                            FALSE,
                                            G_PARAM_READWRITE);
 #endif
-
-      gimp_export_procedure_set_support_comment (GIMP_EXPORT_PROCEDURE (procedure), TRUE);
     }
 
   return procedure;
@@ -1209,10 +1207,10 @@ open_dialog (GimpProcedure    *procedure,
 
   if (format == OPJ_CODEC_J2K)
     /* Not having color information is expected. */
-    title = "Opening JPEG 2000 codestream";
+    title = _("Opening JPEG 2000 codestream");
   else
     /* Unexpected, but let's be a bit flexible and ask. */
-    title = "JPEG 2000 image with no color space";
+    title = _("JPEG 2000 image with no color space");
 
   gimp_ui_init (PLUG_IN_BINARY);
 
@@ -1367,6 +1365,7 @@ load_image (GimpProcedure     *procedure,
   const Babl          *file_format;
   gint                 bpp;
   GimpPrecision        image_precision;
+  guint                signed_offset;
   gint                 precision_actual, precision_scaled;
   gint                 temp;
   gboolean             linear = FALSE;
@@ -1594,6 +1593,22 @@ load_image (GimpProcedure     *procedure,
   precision_scaled = get_valid_precision (precision_actual);
   image_precision = get_image_precision (precision_scaled, linear);
 
+  signed_offset = 0;
+  if (image->comps[0].sgnd)
+    {
+      switch (precision_scaled)
+        {
+          case 32:
+            signed_offset = G_MAXINT32 - 1;
+            break;
+          case 16:
+            signed_offset = G_MAXINT16 - 1;
+            break;
+          default:
+            signed_offset = G_MAXINT8 - 1;
+        }
+    }
+
   gimp_image = gimp_image_new_with_precision (width, height,
                                               base_type, image_precision);
 
@@ -1623,9 +1638,9 @@ load_image (GimpProcedure     *procedure,
           for (k = 0; k < width; k++)
             {
               if (shift >= 0)
-                temp = image->comps[j].data[i * width + k] << shift;
+                temp = (image->comps[j].data[i * width + k] + signed_offset) << shift;
               else /* precision_actual > 32 */
-                temp = image->comps[j].data[i * width + k] >> (- shift);
+                temp = (image->comps[j].data[i * width + k] + signed_offset) >> (- shift);
 
               c = (unsigned char *) &temp;
               for (it = 0; it < (precision_scaled / 8); it++)
@@ -1701,13 +1716,19 @@ export_image (GFile          *file,
                 "quality",         &quality,
                 "ict",             &ict,
                 "resolution",      &resolution,
-                "include-comment", &save_comment,
-                "gimp-comment",    &comment,
 #if ((OPJ_VERSION_MAJOR == 2 && OPJ_VERSION_MINOR == 5 && OPJ_VERSION_BUILD >= 3) || \
      (OPJ_VERSION_MAJOR == 2 && OPJ_VERSION_MINOR > 5) || OPJ_VERSION_MAJOR > 2)
                 "cmyk",            &cmyk,
 #endif
                 NULL);
+  if (! strcmp (gimp_procedure_get_name (procedure), EXPORT_JP2_PROC))
+    g_object_get (config,
+                  "include-comment", &save_comment,
+                  "gimp-comment",    &comment,
+                  NULL);
+  else
+    save_comment = FALSE;
+
   compliance =
     gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
                                          "compliance");
