@@ -1121,17 +1121,7 @@ read_creator_block (FILE      *f,
         }
       keyword = GUINT16_FROM_LE (keyword);
       length = GUINT32_FROM_LE (length);
-
-      if ((goffset) ftell (f) + length > (goffset) data_start + total_len)
-        {
-          /* FIXME: After string freeze is over, we should consider changing
-           * this error message to be a bit more descriptive. */
-          g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                        _("Error reading creator keyword data"));
-          return -1;
-        }
-
-        switch (keyword)
+      switch (keyword)
         {
         case PSP_CRTR_FLD_TITLE:
         case PSP_CRTR_FLD_ARTIST:
@@ -1623,14 +1613,9 @@ read_channel_data (FILE        *f,
                 {
                   guchar *p, *q;
 
-                  if (fread (buf, 1, width, f) != width)
-                    {
-                      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Error reading data. Most likely unexpected end of file."));
-                      return -1;
-                    }
+                  fread (buf, width, 1, f);
                   /* Contrary to what the PSP specification seems to suggest
-                     scanlines are not stored on a 4-byte boundary. */
+                    scanlines are not stored on a 4-byte boundary. */
                   p = buf;
                   q = pixels[y] + offset;
                   for (i = 0; i < width; i++)
@@ -1646,14 +1631,9 @@ read_channel_data (FILE        *f,
                 {
                   guint16 *p, *q;
 
-                  if (fread (buf, ia->bytes_per_sample, width, f) != width)
-                    {
-                      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Error reading data. Most likely unexpected end of file."));
-                      return -1;
-                    }
+                  fread (buf, width * ia->bytes_per_sample, 1, f);
                   /* Contrary to what the PSP specification seems to suggest
-                     scanlines are not stored on a 4-byte boundary. */
+                    scanlines are not stored on a 4-byte boundary. */
                   p = (guint16 *) buf;
                   q = (guint16 *) (pixels[y] + offset);
                   for (i = 0; i < width; i++)
@@ -2191,12 +2171,11 @@ read_layer_block (FILE      *f,
                 }
               else
                 {
-                  if ((ia->base_type == GIMP_RGB && channel_type > PSP_CHANNEL_BLUE) ||
-                      (ia->base_type != GIMP_RGB && channel_type >= PSP_CHANNEL_RED))
+                  if (channel_type > PSP_CHANNEL_BLUE)
                     {
                       g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Invalid channel type %d in channel information chunk"),
-                                   channel_type);
+                                  _("Invalid channel type %d in channel information chunk"),
+                                  channel_type);
                       return NULL;
                     }
 
