@@ -24,7 +24,6 @@ static GtkWidget   *appwin            = NULL;
 static GtkNotebook *options_note_book = NULL;
 
 static GtkWidget *pointlightwid;
-static GtkWidget *viewpointlightwid;
 static GtkWidget *dirlightwid;
 
 static GtkWidget *sphere_page    = NULL;
@@ -111,19 +110,16 @@ lightmenu_callback (GimpProcedureConfig *config)
     {
       gtk_widget_set_visible (dirlightwid, FALSE);
       gtk_widget_set_visible (pointlightwid, TRUE);
-      gtk_widget_set_visible (viewpointlightwid, TRUE);
     }
   else if (light_type == DIRECTIONAL_LIGHT)
     {
       gtk_widget_set_visible (dirlightwid, TRUE);
       gtk_widget_set_visible (pointlightwid, FALSE);
-      gtk_widget_set_visible (viewpointlightwid, FALSE);
     }
   else
     {
       gtk_widget_set_visible (dirlightwid, FALSE);
       gtk_widget_set_visible (pointlightwid, FALSE);
-      gtk_widget_set_visible (viewpointlightwid, FALSE);
     }
 
   if (mapvals.livepreview)
@@ -541,6 +537,7 @@ main_dialog (GimpProcedure       *procedure,
   g_signal_connect (config, "notify::light-position-z",
                     G_CALLBACK (update_preview),
                     config);
+  lightmenu_callback (config);
 
   /* Viewpoint Tab */
   gimp_procedure_dialog_get_label (GIMP_PROCEDURE_DIALOG (appwin),
@@ -554,10 +551,10 @@ main_dialog (GimpProcedure       *procedure,
                                          NULL);
   gtk_orientable_set_orientation (GTK_ORIENTABLE (hbox),
                                   GTK_ORIENTATION_HORIZONTAL);
-  viewpointlightwid = gimp_procedure_dialog_fill_frame (GIMP_PROCEDURE_DIALOG (appwin),
-                                                        "viewpoint-position-frame",
-                                                        "viewpoint-position-label", FALSE,
-                                                        "viewpoint-position-box");
+  pointlightwid = gimp_procedure_dialog_fill_frame (GIMP_PROCEDURE_DIALOG (appwin),
+                                                    "viewpoint-position-frame",
+                                                    "viewpoint-position-label", FALSE,
+                                                    "viewpoint-position-box");
 
   gimp_procedure_dialog_get_scale_entry (GIMP_PROCEDURE_DIALOG (appwin),
                                         "first-axis-x", 1.0);
@@ -639,7 +636,6 @@ main_dialog (GimpProcedure       *procedure,
   g_signal_connect (config, "notify::second-axis-z",
                     G_CALLBACK (update_preview),
                     config);
-  lightmenu_callback (config);
 
   /* Material Tab */
   gimp_procedure_dialog_get_label (GIMP_PROCEDURE_DIALOG (appwin),
